function COVAIN

scrSize  = get(0,'ScreenSize');                % array: [1 1 width height]
scrSize_standard  = [1,1,1920,1080];           % 1080p 16:9 widescreen
scrRatio  =  scrSize(3)/scrSize_standard(3);   % according to the width
ftSize = floor(scrRatio*10);                   % the font size


%  ********************************************************************
%  Construct the components
% Level: Figure - Panel - Group - Component - Property - CallBack

hMainCovain = figure('Position',scrRatio.*[100 100 1400 900],...
    'Interruptible','on',...
    'Name','COVAIN Toolbox (Version 2017-Sept-5)',...
    'NextPlot','new',...
    'NumberTitle','off',...
    'Resize','on',...
    'MenuBar','none', ...
    'Toolbar','none', ...
    'Tag','covainPanel_TOP',...
    'HandleVisibility','callback',...
    'DeleteFcn',@COVAIN_exit);
% HandleVisibility is set to off to avoid adding figures in the main GUI !!

hPanel_Main = uipanel('Parent',hMainCovain,...
    'Title',[ ],...
    'Units','normalized',...
    'Position',[.01 .01 .98 .98],...
    'Tag','panel_Main');
hButton_load = uicontrol('Parent',hPanel_Main,...
    'Style','pushbutton',...
    'String','Load data ... ',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.87 .83 .10 .07],...
    'Interruptible','off',...
    'Tag','button_load',...
    'CallBack',@COVAIN_loadData);
%         hButton_loadExample = uicontrol('Parent',hPanel_Main,...
%                                  'Style','pushbutton',...
%                                  'String','Load example data ...',...
%                                  'Units','normalized',...
%                                  'Position',[.87 .73 .10 .07],...
%                                  'Interruptible','off',...
%                                  'Tag','button_loadExample',...
%                                  'Enable','on',...
%                                  'CallBack',@COVAIN_loadData);

% combine data
 hButton_combineData = uicontrol('Parent',hPanel_Main,...
                                   'Style','pushbutton',...
                                   'String','Combine data ...',...
                                   'FontSize',ftSize,...
                                   'Units','normalized',...
                                   'Position',[.87 .73 .10 .07],...
                                   'Interruptible','off',...
                                   'Tag','button_combineData',...
                                   'Enable','on','UserData',0,...
                                   'CallBack',@COVAIN_combineData);

hButton_note = uicontrol('Parent',hPanel_Main,...
    'Style','pushbutton',...
    'String','My notes ... ',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.87 .63 .10 .07],...
    'Interruptible','off',...
    'Tag','button_note',...
    'Enable','on',...
    'CallBack',@COVAIN_note);
hEdit_fileName = uicontrol('Parent',hPanel_Main,...
    'Style','edit',...
    'String','Name the results',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.87 .53 .10 .07],...
    'Max',1,...
    'Min',0,...  % allow single line only
    'Interruptible','off',...
    'Tag','edit_fileName');

hButton_save = uicontrol('Parent',hPanel_Main,...
    'Style','pushbutton',...
    'String','Save',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.87 .43 .10 .07],...
    'Interruptible','off',...
    'Tag','button_save',...
    'CallBack',@COVAIN_save);
if ismac
    set(hButton_save,'CallBack',@COVAIN_saveMac);
end
%         hButton_close = uicontrol('Parent',hPanel_Main,...
%                                  'Style','pushbutton',...
%                                  'String','Close',...
%                                  'Units','normalized',...
%                                  'Position',[.87 .33 .10 .07],...
%                                  'Interruptible','off',...
%                                  'Tag','button_close');
hButton_options = uicontrol('Parent',hPanel_Main,...
    'Style','pushbutton',...
    'String','Options',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.87 .23 .10 .07],...
    'Interruptible','off',...
    'Tag','button_options',...
    'CallBack',@COVAIN_options);
hButton_helpMain = uicontrol('Parent',hPanel_Main,...
    'Style','pushbutton',...
    'String','Help',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.87 .13 .10 .07],...
    'Interruptible','off',...
    'Tag','button_helpMain',...
    'CallBack',@COVAIN_help);



hPanel_dataInfo = uipanel('Parent',hPanel_Main,...
    'Title','Data information',...
    'FontWeight','bold',...
    'FontSize',floor(1.2*ftSize),...
    'BorderWidth',3,...
    'Units','normalized',...
    'Position',[.03 .48 .81 .48],...
    'Tag','panel_Info');
% Your sample have xx substances, xx measurements and xx conditions
% ------- PLEASE check the properties of static text ----
hText_dataInfo = uicontrol('Parent',hPanel_dataInfo,...
    'Style','text',...
    'String',[],...
    'FontSize',floor(.9*ftSize),...
    'Units','normalized',...
    'Position',[.01 .46 .39 .12 ],...
    'Max',2,...
    'Min',0,...
    'Interruptible','off',...
    'Tag','text_info',...
    'Enable','inactive');
hPanel_dataSelect = uipanel('Parent',hPanel_dataInfo,...
    'Title','Choose data',...
    'FontSize',floor(1.1*ftSize),...
    'Units','normalized',...
    'Position',[.01 .59 .39 .40],...
    'Tag','panel_dataSelect');

% does not allow multiple selection!
hList_dataSelect = uicontrol('Parent',hPanel_dataSelect,...
    'Style','listbox',...
    'String',[],...
    'FontSize',ftSize,...
    'Value',[],...
    'Max',2,...
    'Min',1,...
    'Units','normalized',...
    'Position',[.01 .02 .98 .98],...
    'Tag','list_dataSelect',...
    'CallBack',@COVAIN_dataSelect);

hButton_dataTrans = uicontrol('Parent',hPanel_dataInfo,...
    'Style','togglebutton',...
    'String','Transpose',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.01 .36 .12 .06],...
    'Interruptible','off',...
    'Tag','button_trans',...
    'CallBack',@COVAIN_dataTranspose);
hPopup_dataNorm = uicontrol('Parent',hPanel_dataInfo,...
    'Style','popupmenu',...
    'String',{'Normalize','internal standard','fresh weight'},...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.15 .36 .12 .06],...
    'Interruptible','off',...
    'Tag','popup_norm',...
    'Value',1,...
    'CallBack',@COVAIN_preTrans);
hButton_reset = uicontrol('Parent',hPanel_dataInfo,...
    'Style','pushbutton',...
    'String','Reset (excl.Trans)',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.29 .36 .11 .06],...
    'Interruptible','off',...
    'Tag','button_reset',...
    'CallBack',@COVAIN_resetData);

hText_missValue = uicontrol('Parent',hPanel_dataInfo,...
    'Style','text',...
    'String',[],...
    'FontSize',floor(.9*ftSize),...
    'Units','normalized',...
    'Position',[.15 .28 .25 .06],...
    'Max',1,...
    'Min',0,...  % allow single line only
    'Interruptible','off',...
    'Tag','text_miss',...
    'Enable','inactive');

hButton_missValue = uicontrol('Parent',hPanel_dataInfo,...
    'Style','togglebutton',...  % Toggle button !!! ----
    'String','Fill missing values',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.01 .28 .12 .06 ],...
    'Interruptible','off',...
    'Tag','button_miss',...
    'CallBack',@COVAIN_missValueFill);

hText_outlier = uicontrol('Parent',hPanel_dataInfo,...
    'Style','text',...
    'String',[],...  % see above!!! ----
    'FontSize',floor(.9*ftSize),...
    'Units','normalized',...
    'Position',[.15 .20 .25 .06 ],...
    'Max',1,...
    'Min',0,...  % allow single line only
    'Interruptible','off',...
    'Enable','inactive',...
    'Tag','text_outlier'); % ------- no callback

hButton_outlier = uicontrol('Parent',hPanel_dataInfo,...
    'Style','togglebutton',...
    'String','Adjust outliers',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[ .01 .20 .12 .06 ],...
    'Interruptible','off',...
    'Tag','button_outlier',...
    'CallBack',@COVAIN_outlierValueFill);
hButton_anova = uicontrol('Parent',hPanel_dataInfo,...
    'Style','pushbutton',...
    'String','ANOVA',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.01 .12 .12 .06 ],...
    'Interruptible','off',...
    'Tag','button_anova',...
    'CallBack',@COVAIN_anova);

hButton_plotData = uicontrol('Parent',hPanel_dataInfo,...
    'Style','pushbutton',...
    'String','Bar plot (all)',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.15 .12 .12 .06 ],...
    'Interruptible','off',...
    'Tag','button_plotData',...
    'CallBack',@COVAIN_plotData);

hButton_log = uicontrol('Parent',hPanel_dataInfo,...
    'Style','pushbutton',...
    'String','Log',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.01 .04 .07 .06],...
    'Interruptible','off',...
    'Tag','button_log',...
    'CallBack',@COVAIN_preTrans);

hButton_Ztrans = uicontrol('Parent',hPanel_dataInfo,...
    'Style','pushbutton',...
    'String','Z-score Column-wise',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.09 .04 .09 .06],...
    'Interruptible','off',...
    'Tag','button_Ztrans',...
    'CallBack',@COVAIN_preTrans);
hButton_ZtransR = uicontrol('Parent',hPanel_dataInfo,...
    'Style','pushbutton',...
    'String','Z-score Row-wise',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.19 .04 .09 .06],...
    'Interruptible','off',...
    'Tag','button_ZtransR',...
    'CallBack',@COVAIN_preTrans);

% newly added buttons
hButton_evaluateData = uicontrol('Parent',hPanel_dataInfo,...
    'Style','pushbutton',...
    'String','Evaluation',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.29 .12 .11 .06 ],...
    'Interruptible','off',...
    'Tag','button_evaluateData',...
    'CallBack',@COVAIN_dataEvaluation);

hButton_normTrans = uicontrol('Parent',hPanel_dataInfo,...
    'Style','pushbutton',...
    'String','0-1 Range scaling',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.29 .04 .11 .06 ],...
    'Interruptible','off',...
    'Tag','button_normTrans',...
    'CallBack',@COVAIN_preTrans);

hButtonGroup_tableSelect = uibuttongroup('Parent',hPanel_dataInfo,...
    'Title',[],...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[ .42 .90 .57 .09],...
    'Tag','group_tableSelect',...
    'Interruptible','off',...
    'SelectionChangeFcn',@COVAIN_radioSelect);

hRadio_table1 = uicontrol('Parent',hButtonGroup_tableSelect,...
    'Style','radiobutton',...
    'String','full data preview',...
    'FontSize',floor(0.9*ftSize),...
    'Units','normalized',...
    'Position',[0 0 .20 1],...
    'Tag','radio_tableSelect_1',...
    'Value',0);
hRadio_table2 = uicontrol('Parent',hButtonGroup_tableSelect,...
    'Style','radiobutton',...
    'String','mean value preview',...
    'FontSize',floor(0.9*ftSize),...
    'Units','normalized',...
    'Position',[.20 0 .25 1],...
    'Tag','radio_tableSelect_2',...
    'Value',1);
hRadio_table3 = uicontrol('Parent',hButtonGroup_tableSelect,...
    'Style','radiobutton',...
    'String','transpose full preview',...
    'FontSize',floor(0.9*ftSize),...
    'Units','normalized',...
    'Position',[.45 0 .27 1],...
    'Tag','radio_tableSelect_3',...
    'Value',0);
hRadio_table4 = uicontrol('Parent',hButtonGroup_tableSelect,...
    'Style','radiobutton',...
    'String','transpose mean preview',...
    'FontSize',floor(0.9*ftSize),...
    'Units','normalized',...
    'Position',[.72 0 .27 1],...
    'Tag','radio_tableSelect_4',...
    'Value',0);

hTable_preview = uitable('Parent',hPanel_dataInfo,...
    'ColumnWidth','auto',...
    'ColumnName',[],...
    'RowName',[],...
    'Units','normalized',...
    'Position',[.42 .01 .57 .88],...
    'FontSize',floor(0.8*ftSize),...
    'Data',[],...
    'Tag','table_preview',...
    'Enable','inactive',...
    'RearrangeableColumns','off');


hPanel_dataAnalysis = uipanel('Parent',hPanel_Main,...
    'Title','Data Analysis',...
    'FontSize',floor(1.2*ftSize),...
    'FontWeight','bold',...
    'BorderWidth',3,...
    'Units','normalized',...
    'Position',[.03 .05 .81 .40],...
    'Tag','panel_analysis');
hPanel_stat = uipanel('Parent',hPanel_dataAnalysis,...
    'Title','Multivariate Statistics',...
    'FontSize',floor(1.1*ftSize),...
    'Units','normalized',...
    'Position',[.01 .00 .30 1],...
    'BorderWidth',2,...
    'Tag','panel_stat');

hPanel_Select_stat = uipanel('Parent',hPanel_stat,...
    'Title','Data selection',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.00 .75 1 .20],...
    'Tag','panel_stat_Select');

hEdit_stat = uicontrol('Parent',hPanel_Select_stat,...
    'String','Input index, such as 1,2,3 ',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.00 .00 .75 1],...
    'Style','edit',...
    'Tag','edit_indexStat',...
    'Max',1,'Min',0,...
    'CallBack',@COVAIN_indexStat);
hCheck_stat = uicontrol('Parent',hPanel_Select_stat,...
    'String','All',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.76 .00 .24 1],...
    'Tag','checkbox_Stat',...
    'Style','checkbox',...
    'Value',0,...
    'CallBack',@COVAIN_indexStat);
hPanel_PCA = uipanel('Parent',hPanel_stat,...
    'Title','PCA',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.00 .60 1 .15],...
    'Tag','panel_PCA');

hEdit_PCA = uicontrol('Parent',hPanel_PCA,...
    'Style','edit',...
    'String','PC number (max 5)',...
    'FontSize',ftSize-1,...
    'Units','normalized',...
    'Position',[.00 .00 .39 1],...
    'Style','edit',...
    'Tag','edit_PCnumber',...
    'Max',1,...
    'Min',0,...
    'CallBack',@COVAIN_PCnumber);
hButton_PCA = uicontrol('Parent',hPanel_PCA,...
    'Style','pushbutton',...
    'String','Plot',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.40 .00 .29 1],...
    'Tag','button_doPCA',...
    'CallBack',@COVAIN_PCA);
hButton_LabelPCA = uicontrol('Parent',hPanel_PCA,...
    'Style','pushbutton',...
    'String','Label',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.70 .00 .29 1],...
    'Tag','button_LabelPCA',...
    'CallBack',@COVAIN_labelPCA);
hPanel_ICA = uipanel('Parent',hPanel_stat,...
    'Title','ICA',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.00 .45 1 .15],...
    'Tag','panel_ICA');
hEdit_ICA = uicontrol('Parent',hPanel_ICA,...
    'Style','edit',...
    'String','IC number (max 5)',...
    'FontSize',ftSize-1,...
    'Units','normalized',...
    'Position',[.00 .00 .39 1],...
    'Style','edit',...
    'Tag','edit_ICnumber',...
    'Enable','on',...
    'Max',1,...
    'Min',0);
hButton_ICA = uicontrol('Parent',hPanel_ICA,...
    'Style','pushbutton',...
    'String','Plot',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.40 .00 .29 1],...
    'Tag','button_doICA',...
    'Enable','on',...
    'CallBack',@COVAIN_ICA);
hButton_LabelICA = uicontrol('Parent',hPanel_ICA,...
    'Style','pushbutton',...
    'String','Label',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.70 .00 .29 1],...
    'Tag','button_LabelICA',...
    'CallBack',@COVAIN_labelICA);
hPanel_Corr = uipanel('Parent',hPanel_stat,...
    'Title','Correlation',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.00 .30 .49 .15],...
    'Tag','panel_corr');
hButton_Corr = uicontrol('Parent',hPanel_Corr,...
    'Style','pushbutton',...
    'String','Calculate & View',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.00 .00 .99 1],...
    'Tag','button_doCorr',...
    'CallBack',@COVAIN_corrStat);
hPanel_Heatmap = uipanel('Parent',hPanel_stat,...
    'Title','Heatmap',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.50 .30 .49 .15],...
    'Tag','panel_heatStat');
hButton_Heatmap = uicontrol('Parent',hPanel_Heatmap,...
    'Style','pushbutton',...
    'String','View',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.00 .00 .99 1],...
    'Tag','button_heatStat',...
    'CallBack',@COVAIN_corrStat);
hPanel_clusterStat = uipanel('Parent',hPanel_stat,...
    'Title','Cluster',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.00 .15 1 .15],...
    'Tag','panel_clusterStat');

hButton_clusterStat0 = uicontrol('Parent',hPanel_clusterStat,...
    'Style','pushbutton',...
    'String','Normal analysis',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.00 .00 .49 1],...
    'Tag','button_clusterStat',...
    'CallBack',@COVAIN_clusterStatNormal);

hButton_clusterStat = uicontrol('Parent',hPanel_clusterStat,...
    'Style','pushbutton',...
    'String','Case-Control analysis',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.50 .00 .49 1],...
    'Tag','button_clusterStat',...
    'CallBack',@COVAIN_clusterStatPop);

% newly added @ 2017.09.02
hButton_reg = uicontrol('Parent',hPanel_stat,...
    'Style','pushbutton',...
    'String','Feature Selection Regression',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.00 .00 .49 .1],...
    'Tag','button_reg',...
    'CallBack',@COVAIN_reg);

% hButton_feaSel = uicontrol('Parent',hPanel_stat,...
%     'Style','pushbutton',...
%     'String','Feature Selection',...
%     'FontSize',ftSize,...
%     'Units','normalized',...
%     'Position',[.50 .00 .49 .1],...
%     'Tag','button_feaSel',...
%     'CallBack',@COVAIN_feaSel);


hPanel_ts = uipanel('Parent',hPanel_dataAnalysis,...
    'Title','Time Series',...
    'FontSize',floor(1.1*ftSize),...
    'Units','normalized',...
    'Position',[.35 .00 .30 1],...
    'BorderWidth',2,...
    'Tag','panel_TS');
hPanel_Select_TS = uipanel('Parent',hPanel_ts,...
    'Title','Time points selection',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.00 .75 1 .20],...
    'Tag','panel_TS_select');
hEdit_TS = uicontrol('Parent',hPanel_Select_TS,...
    'String','Input index, such as 4,2,3,1 ',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.00 .00 .75 1],...
    'Style','edit',...
    'Tag','edit_indexTS',...
    'Max',1,...
    'Min',0,...
    'CallBack',@COVAIN_indexTS);
hCheck_TS = uicontrol('Parent',hPanel_Select_TS,...
    'String','Default',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.76 .00 .24 1],...
    'Tag','checkbox_TS',...
    'Style','checkbox',...
    'Value',0,...
    'CallBack',@COVAIN_indexTS);
hPanel_Corr_TS = uipanel('Parent',hPanel_ts,...
    'Title','Correlation',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.00 .60 .49 .15],...
    'Tag','panel_corr_TS');
hButton_Corr_TS = uicontrol('Parent',hPanel_Corr_TS,...
    'Style','pushbutton',...
    'String','Calculate & View',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.00 .00 .99 .9],...
    'Tag','button_corrTS',...
    'CallBack',@COVAIN_corrTS);
hPanel_HeatmapTS = uipanel('Parent',hPanel_ts,...
    'Title','Heatmap',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.50 .60 .49 .15],...
    'Tag','panel_heatTS');
hButton_HeatmapTS = uicontrol('Parent',hPanel_HeatmapTS,...
    'Style','pushbutton',...
    'String','View',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.00 .00 .99 1],...
    'Tag','button_heatTS',...
    'CallBack',@COVAIN_corrTS);

hPanel_clustering = uipanel('Parent',hPanel_ts,...
    'Title','Clustering',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.00 .30 1 .3],...
    'Tag','panel_clustering');
hButtonGroup_clusterType = uibuttongroup('Parent',hPanel_clustering,...
    'Title',[],...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.00 .50 1 .50],...
    'Tag','group_cluster',...
    'Interruptible','off');
hRadio_cluster_TS1 = uicontrol('Parent',hButtonGroup_clusterType,...
    'Style','radiobutton',...
    'String','Hierarchical',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[0 0 .5 1],...
    'Tag','radio_cluster_1',...
    'Value',1);   
hRadio_clsuter_TS2 = uicontrol('Parent',hButtonGroup_clusterType,...
    'Style','radiobutton',...
    'String','K-Means',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.5 0 .5 1],...
    'Tag','radio_cluster_2',...
    'Value',0);   
hButton_cluster = uicontrol('Parent',hPanel_clustering,...
    'Style','pushbutton',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.00 .00 .50 .45],...
    'Tag','button_cluster',...
    'String','Cluster',...
    'CallBack',@COVAIN_cluster);

hPanel_Granger = uipanel('Parent',hPanel_ts,...
    'Title','Granger causation analysis',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.00 .15 1 .15],...
    'Tag','panel_Granger');

hButton_Granger = uicontrol('Parent',hPanel_Granger,...
    'Style','pushbutton',...
    'String','Calculate & View',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.00 .00 .50 1],...
    'Tag','button_Granger',...
    'CallBack',@COVAIN_Granger);

hPanel_PE = uipanel('Parent',hPanel_ts,...
    'Title','Permutation Entropy',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.00 .00 1 .15],...
    'Tag','panel_PE');

hButton_PE = uicontrol('Parent',hPanel_PE,...
    'Style','pushbutton',...
    'FontSize',ftSize,...
    'String','Calculate & View',...
    'Units','normalized',...
    'Position',[.00 .00 .5 1],...
    'Tag','button_PE',...
    'CallBack',@COVAIN_PE);

hcovainPanel_TOPo = uipanel('Parent',hPanel_dataAnalysis,...
    'Title','Network Analysis',...
    'FontSize',floor(1.1*ftSize),...
    'Units','normalized',...
    'Position',[.68 .00 .30 1],...
    'BorderWidth',2,...
    'Tag','covainPanel_TOPo');
hPanel_NetInfer = uipanel('Parent',hcovainPanel_TOPo,...
    'Title','Network Inferrence',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.00 .65 1 .35],...
    'Tag','panel_netInfer');
hList_Net = uicontrol('Parent',hPanel_NetInfer,...
    'Style','listbox',...
    'String',{'Correlation','Correlation (Time Series)','Granger analysis'},...
    'Value',1,...
    'FontSize',floor(.9*ftSize),...
    'Units','normalized',...
    'Position',[.00 .00 .50 1],...
    'Tag','list_Infer');
hButton_NetInfer = uicontrol('Parent',hPanel_NetInfer,...
    'Style','pushbutton',...
    'String','Visualize network',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.55 .50 .45 .5],...
    'Tag','button_netInfer',...
    'CallBack',@COVAIN_netInferrence);


hPanel_Jacobian = uipanel('Parent',hcovainPanel_TOPo,...
    'Title','Inverse Jacobian',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.00 .15 1 .45],...
    'Tag','panel_Jacobian');

hButton_covInput1 = uicontrol('Parent',hPanel_Jacobian,...
    'Style','pushbutton',...
    'String','Set condition A ...',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.00 .7 .49 .25],...
    'Interruptible','off',...
    'Tag','button_covInput1',...
    'CallBack',@COVAIN_loadCov);
hButton_covInput2 = uicontrol('Parent',hPanel_Jacobian,...
    'Style','pushbutton',...
    'String','Set condition B ...',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.00 .4 .49 .25],...
    'Interruptible','off',...
    'Tag','button_covInput2',...
    'CallBack',@COVAIN_loadCov);
hButton_Stoi = uicontrol('Parent',hPanel_Jacobian,...
    'Style','pushbutton',...
    'String','Input stoichiometric matrix ...',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.55 .7 .45 .25],...
    'Interruptible','off',...
    'Tag','button_Stoi',...
    'CallBack',@COVAIN_loadStoi);
hButton_Jacobian = uicontrol('Parent',hPanel_Jacobian,...
    'Style','pushbutton',...
    'String','Calculate differential Jacobian',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.55 .4 .45 .25],...
    'Interruptible','off',...
    'Tag','button_Jacobian',...
    'CallBack',@COVAIN_diffJac);

hPanel_KEGG = uipanel('Parent',hcovainPanel_TOPo,...
    'Title','KEGG Pathway',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.00 .15 1 .15],...
    'Tag','panel_KEGG');
hButton_keggCPD = uicontrol('Parent',hPanel_KEGG,...
    'Style','pushbutton',...
    'FontSize',ftSize,...
    'String','Compound mapping ...',...
    'Units','normalized',...
    'Position',[.00 .00 .50 1],...
    'Interruptible','off',...
    'Tag','button_keggCPD',...
    'CallBack',@COVAIN_cpd2pwy);

hPanel_mzGroup = uipanel('Parent',hcovainPanel_TOPo,...
    'Title','mzGroupAnalyzer',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.00 .00 1 .14],...
    'Tag','panel_mzGroup');
hButton_mzGroupAnalyzer = uicontrol('Parent',hPanel_mzGroup,...
    'Style','pushbutton',...
    'String','Load data & Analyze',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.00 .00 .49 1],...
    'Interruptible','off',...
    'Tag','button_mzGroup',...
    'CallBack',@COVAIN_mzGroupAnalyzer);
hButton_mzPathViewer = uicontrol('Parent',hPanel_mzGroup,...
    'Style','pushbutton',...
    'String','Pathway Viewer',...
    'FontSize',ftSize,...
    'Units','normalized',...
    'Position',[.55 .00 .44 1],...
    'Interruptible','off',...
    'Tag','button_mzViewer',...
    'CallBack',@COVAIN_mzPathViewer);

initialGuiData.loadNumber = 0;
initialGuiData.which = 1;
initialGuiData.close = 0;
initialGuiData.corrTS_OK = 0;
initialGuiData.corr_OK = 0;
initialGuiData.dataStat_Input = 0;
initialGuiData.dataStat_OK = 0;
initialGuiData.Granger_OK = 0;
initialGuiData.PE_OK = 0;
initialGuiData.rootPath = pwd;

% versions of parallel toolbox
mVer = double(version); mVer = mVer([1 3]);
% for very old versions, there may be problems
if mVer(1) <= 55 && mVer(2) <= 49 % version <= 7.12 (R2011a)
    parVer = 'X'; parNum = 1;
else
    tbox = arrayfun(@(x) x.Name, ver,'UniformOutput',0);
    t = ~isempty(strmatch('Parallel Computing Toolbox',tbox));
    parVer = 'X'; parNum = 1;
    if t==1
        P =  parcluster('local');
        parNum = P.NumWorkers; % physical cores, 50% cpu load
        parVer = 'Old';
        if mVer(1) >= 56 & mVer(2) >= 50 | mVer(1) >= 57 % version >= 8.2 (R2013b)
            parVer = 'New';
        end
    end
end
initialGuiData.parVer = parVer;
initialGuiData.parNum = parNum;
guidata(hMainCovain,initialGuiData);

    