function COVAIN_Granger(obj,evt)
% 
% using Benjamini-Hochberg false discovery rate (BHFDR)
% Last update: 2017.04.18

h = findobj('Tag','covainPanel_TOP');
h2 = findobj('Tag','button_Granger'); 
dataStruct = guidata(h);
if dataStruct.loadNumber == 0
    return;
end
currentData = dataStruct.dataset(dataStruct.current).dataInfo;
timeLag = currentData.options.granger;

if currentData.dataTS_OK == 1
    nameSub  = currentData.subs;
    nRow     = currentData.nRow;
    meanValue= currentData.dataTS; 
    pval = currentData.options.grangerP;
    warning off; %#ok<WNOFF>
    
    Gpval = ones(nRow,nRow); % square matrix
    probVec = ones(nRow*(nRow-1)/2,2);
    
    stateFinish = 1;
    count = 0;
    hWaitbar = waitbar(0,'Please wait ...','Name','Granger Analysis',...
        'CreateCancelBtn','setappdata(gcbf,''canceling'',1)');
    setappdata(hWaitbar,'canceling',0)
    for iseq = 1:nRow
        if getappdata(hWaitbar,'canceling')
            stateFinish = 0;
            break;
        end
        waitbar(iseq/nRow);
        for jseq = iseq+1:nRow
            count = count + 1;
            probVec(count,:) = grangerCause(meanValue([iseq,jseq],:),timeLag);
            Gpval(iseq,jseq) = probVec(count,2); % notice this!
            Gpval(jseq,iseq) = probVec(count,1); % notice this!
        end
    end
    delete(hWaitbar);
    
    % BH correction procedure
    for jseq = 1:nRow
        Gpval(:,jseq) = mafdr(Gpval(:,jseq),'BHFDR','true');
    end
        
    if stateFinish == 1
        Gstat = Gpval <= pval;  % 0-1 matrix

        % table data, significant causation
        idx = find(Gstat(:)); len = length(idx);
        Gstat2 = Gstat'; idx2 = find(Gstat2(:)); Gpval2 = Gpval';
        listCs = cell(len,4);
        listCd = cell(len,4);
        locMs = zeros(len,3);
        locMd = zeros(len,3);
        for i=1:len
            [locx,locy] = ind2sub(size(Gstat2),idx2(i));
            listCs{i,1} = nameSub{locy};
            listCs{i,2} = ' causes ';
            listCs{i,3} = nameSub{locx};
            listCs{i,4} = num2str(Gpval2(idx2(i)));
            locMs(i,1) = locy; locMs(i,2) = locx;
            locMs(i,3) = locy*100000+locx;
        end
        for i=1:len
            [locx,locy] = ind2sub(size(Gstat),idx(i));
            listCd{i,1} = nameSub{locy};
            listCd{i,2} = ' is caused by ';
            listCd{i,3} = nameSub{locx};
            listCd{i,4} = num2str(Gpval(idx(i)));
            locMd(i,1) = locy; locMd(i,2) = locx;
            locMd(i,3) = locy*100000+locx;
        end

        % overlapping parts, pairs
        [pairC,idxCs,idxCd] = intersect(locMs(:,3),locMd(:,3));

        % remove duplicate ones
        len2 = length(idxCs);
        idxTable = locMs(idxCs,1:2);
        flg = zeros(len2,1);
        for i=2:len2
            col_1 = idxTable(1:i-1,1);
            col_2 = idxTable(1:i-1,2);
            if any(col_2==idxTable(i,1)) && any(col_1==idxTable(i,2))
                flg(i) = 1;
            end
        end
        idxCs = idxCs(flg==0);
        idxCd = idxCd(flg==0);
        len2 = length(idxCs);

        listCp = cell(len2,5); % a, pairs, b, p(a->b), p(b->a)
        listCp(:,1) = nameSub(locMs(idxCs,1));
        listCp(:,2) = repmat({' pairs '},len2,1);
        listCp(:,3) = nameSub(locMs(idxCs,2));
        listCp(:,4) = listCs(idxCs,4);
        listCp(:,5) = listCd(idxCd,4);

        idxCs0 = (1:size(listCs,1))';
        idxCd0 = (1:size(listCd,1))';
        idxCp0 = (1:size(listCp,1))';
        idx0 = cell(1,3);
        idx0{1} = idxCs0; idx0{2} = idxCd0; idx0{3} = idxCp0;
        set(h2,'UserData',idx0);
        
        % pop up three tables: "causes" and "is caused by", and pairs 
        % when clicked, plot time series
        head1 = {'Variable A','Causes','Variable B','p-value'};
        head2 = {'Variable A','Is caused by','Variable B','p-value'};
        head3 = {'Variable A',' Pairs ','Variable B','p-value(AB)','p-value(BA)'};
        f1 = figure('Position',[100 100 500 600],...
                    'Name',['Granger analysis: ',num2str(len),' causes, at p-value <= ',num2str(pval)],...
                    'Resize','on',...
                    'NumberTitle','off',...
                    'MenuBar','none',...
                    'Tag','gcauseFig1');
        f2 = figure('Position',[300 100 500 600],...
                    'Name',['Granger analysis: ',num2str(len),' caused by, at p-value <= ',num2str(pval)],...
                    'Resize','on',...
                    'NumberTitle','off',...
                    'MenuBar','none',...
                    'Tag','gcauseFig2');
        f3 = figure('Position',[500 100 600 600],...
                    'Name',['Granger analysis: ',num2str(len2),' pair(s), at p-value <= ',num2str(pval)],...
                    'Resize','on',...
                    'NumberTitle','off',...
                    'MenuBar','none',...
                    'Tag','gcauseFig3');

        t1 = uitable('Parent',f1,'Units','normalized','Position',[.1 .15 .8 .8],...
                     'ColumnName',head1,'Data',listCs,'Tag','gcauseTab1',...
                     'CellSelectionCallback',@plotTable);          
        t2 = uitable('Parent',f2,'Units','normalized','Position',[.1 .15 .8 .8],...
                     'ColumnName',head2,'Data',listCd,'Tag','gcauseTab2',...
                     'CellSelectionCallback',@plotTable);
        t3 = uitable('Parent',f3,'Units','normalized','Position',[.06 .15 .84 .8],...
                     'ColumnName',head3,'Data',listCp,'Tag','gcauseTab3',...
                     'CellSelectionCallback',@plotTable);
        % buttons: sorted by name, sorted by p-value, export
        if ispc == 1
            exportStr = 'Exported as Excel table';
        else
            exportStr = 'Exported as txt table';
        end
        b11 = uicontrol('Parent',f1,'Units','normalized','Position',[.1 .05 .2 .07],...
                        'Style','pushbutton','String','Sorted by name',...
                        'Tag','button11','CallBack',@buttonTable);
        b12 = uicontrol('Parent',f1,'Units','normalized','Position',[.35 .05 .2 .07],...
                        'Style','pushbutton','String','Sorted by p-value',...
                        'Tag','button12','CallBack',@buttonTable);            
        b13 = uicontrol('Parent',f1,'Units','normalized','Position',[.6 .05 .25 .07],...
                        'Style','pushbutton','String',exportStr,...
                        'Tag','button13','CallBack',@buttonTable);
        b21 = uicontrol('Parent',f2,'Units','normalized','Position',[.1 .05 .2 .07],...
                        'Style','pushbutton','String','Sorted by name',...
                        'Tag','button21','CallBack',@buttonTable);
        b22 = uicontrol('Parent',f2,'Units','normalized','Position',[.35 .05 .2 .07],...
                        'Style','pushbutton','String','Sorted by p-value',...
                        'Tag','button22','CallBack',@buttonTable);            
        b23 = uicontrol('Parent',f2,'Units','normalized','Position',[.6 .05 .25 .07],...
                        'Style','pushbutton','String',exportStr,...
                        'Tag','button23','CallBack',@buttonTable);
        b31 = uicontrol('Parent',f3,'Units','normalized','Position',[.06 .05 .15 .07],...
                        'Style','pushbutton','String','Sorted by name',...
                        'Tag','button31','CallBack',@buttonTable);
        b32 = uicontrol('Parent',f3,'Units','normalized','Position',[.24 .05 .2 .07],...
                        'Style','pushbutton','String','Sorted by p-value(AB)',...
                        'Tag','button32','CallBack',@buttonTable);            
        b33 = uicontrol('Parent',f3,'Units','normalized','Position',[.47 .05 .2 .07],...
                        'Style','pushbutton','String','Sorted by p-value(BA)',...
                        'Tag','button33','CallBack',@buttonTable);
        b34 = uicontrol('Parent',f3,'Units','normalized','Position',[.7 .05 .2 .07],...
                        'Style','pushbutton','String',exportStr,...
                        'Tag','button34','CallBack',@buttonTable);

        % save results       
        currentData.Granger = Gstat;
        currentData.Granger_OK = 1;

        % update guidata
        dataStruct.dataset(dataStruct.current).dataInfo = currentData;
        guidata(h,dataStruct);
    end
      
else
    hWarn = warndlg('Please select time series!');
    uiwait(hWarn);
    uicontrol(findobj(h,'Tag','edit_indexTS'));
end

    function plotTable(objS,evtS)
        objTag = get(get(objS,'Parent'),'Tag'); % fig tag
        idxS0 = get(h2,'UserData');
        
        if strcmp(objTag,'gcauseFig1')
            idxS2 = idxS0{1};
            listS = listCs(idxS2,:);
            locS = locMs(idxS2,:); % for plotting
            figS = 'Causes';
        elseif strcmp(objTag,'gcauseFig2')
            idxS2 = idxS0{2};
            listS = listCd(idxS2,:);
            locS = locMd(idxS2,:);
            figS = 'Is caused by';
        else
            idxS2 = idxS0{3};
            listS = listCp(idxS2,:);
            locS = locMs(idxCs(idxS2,:),1:2);
            figS = ' Pairs ';
        end
        
        tmp = evtS.Indices;
        idxS = unique(tmp(:,1)); % rows
        locS = locS(idxS,:);     % row-by-col
        
        nrowS = ceil(sqrt(length(idxS)));
        ncolS = ceil(sqrt(length(idxS)));
        figure('Name',figS);
        for iS=1:size(idxS,1)
            subplot(nrowS,ncolS,iS);
            ts1 = meanValue(locS(iS,1),:);
            ts2 = meanValue(locS(iS,2),:);
            ts1 = detrend(ts1,'constant')./(max(ts1)-min(ts1));
            ts2 = detrend(ts2,'constant')./(max(ts2)-min(ts2)); % 0-1 normalization
            plot(ts1,'r-o','LineWidth',2);hold on;
            plot(ts2,'b-o','LineWidth',2);hold off;
            set(gca,'XTick',1:length(ts1));
            hleg = legend(listS{idxS(iS),1},listS{idxS(iS),3});
            set(hleg,'Interpreter','none');
            xlabel('Time Points'); ylabel('Normalized level');
        end
    end
    

    function buttonTable(objS,evtS)       
        objTag = get(objS,'Tag');
        whichFig = str2double(objTag(end-1));
        whichBut = str2double(objTag(end));
        hTable = findobj(get(objS,'Parent'),'Tag',['gcauseTab',objTag(end-1)]);
        oldTable = get(hTable,'Data');
        newTable = oldTable;
        savePath = currentData.savePath;
        if ispc == 1
            exportName = [savePath,'*.xlsx'];
        else
            exportName = [savePath,'*.txt'];
        end
        
        % get the old index
        idxS0 = get(h2,'UserData');
        idxOld = idxS0{whichFig};
        
        switch whichBut
            case 1           % sort name (column 1)
                [waste,idxS] = sort(oldTable(:,1));
                newTable = oldTable(idxS,:);
                set(hTable,'Data',newTable);
                idxS0{whichFig} = idxOld(idxS);
            case 2           % sort p-value (column 4)
                [waste,idxS] = sort(oldTable(:,4));
                newTable = oldTable(idxS,:);
                set(hTable,'Data',newTable);
                idxS0{whichFig} = idxOld(idxS);
            case 3
                if whichFig ~= 3
                    [fileName,pathName,flgStatus] = uiputfile(exportName,...
                        'Please specify the file name');
                else
                    flgStatus = 1;
                end
                if flgStatus == 1
                    if whichFig == 1      % export to excel or txt
                        if ispc == 1
                            try
                                xlswrite([pathName,fileName],newTable);
                                msgbox('  Done  !');
                            catch err
                                hWarnXLS = warndlg(['Writing to Excel table fails: ',err.message]);
                                uiwait(hWarnXLS);
                            end  
                        else
                            try
                                fid = fopen([pathName,fileName],'w');
                                for k = 1:size(newTable,1)
                                    fprintf(fid,'%s\t%s\t%s\t%s\n',...
                                        newTable{k,1},newTable{k,2},newTable{k,3},newTable{k,4});
                                end
                                fclose(fid); msgbox('  Done  !');
                            catch err
                                hWarnTxt = warndlg(['Writing to txt table fails: ',err.message]);
                                uiwait(hWarnTxt);
                            end
                        end         
                    elseif whichFig == 2  % export to excel or txt
                        if ispc == 1
                            try
                                xlswrite([pathName,fileName],newTable);
                                msgbox('  Done  !');
                            catch err
                                hWarnXLS = warndlg(['Writing to Excel table fails: ',err.message]);
                                uiwait(hWarnXLS);
                            end  
                        else
                            try
                                fid = fopen([pathName,fileName],'w');
                                for k = 1:size(newTable,1)
                                    fprintf(fid,'%s\t%s\t%s\t%s\n',...
                                        newTable{k,1},newTable{k,2},newTable{k,3},newTable{k,4});
                                end
                                fclose(fid); msgbox('  Done  !');
                            catch err
                                hWarnTxt = warndlg(['Writing to txt table fails: ',err.message]);
                                uiwait(hWarnTxt);
                            end
                        end 
                    else                  % sort p-values (column 5)
                        [waste,idxS] = sort(oldTable(:,5));
                        newTable = oldTable(idxS,:);
                        set(hTable,'Data',newTable);
                        idxS0{whichFig} = idxOld(idxS);
                    end
                end
            case 4                    % export to excel or txt
                [fileName,pathName,flgStatus] = uiputfile(exportName,...
                    'Please specify the file name');
                if flgStatus == 1
                    if ispc == 1
                        try
                            xlswrite([pathName,fileName],newTable);
                            msgbox('  Done  !');
                        catch err
                            hWarnXLS = warndlg(['Writing to Excel table fails: ',err.message]);
                            uiwait(hWarnXLS);
                        end
                    else
                        try
                            fid = fopen([pathName,fileName],'w');
                            for k = 1:size(newTable,1)
                                fprintf(fid,'%s\t%s\t%s\t%s\n',...
                                    newTable{k,1},newTable{k,2},newTable{k,3},newTable{k,4});
                            end
                            fclose(fid); msgbox('  Done  !');
                        catch err
                            hWarnTxt = warndlg(['Writing to txt table fails: ',err.message]);
                            uiwait(hWarnTxt);
                        end
                    end
                end
        end
        % update idxS
        set(h2,'UserData',idxS0);
    end
                
end
            

