function COVAIN_ICA(obj,evt)
%

h1 = get(obj,'Parent'); % hPanel_stat
h2 = get(h1,'Parent');  % hPanel_dataAnalysis
h3 = get(h2,'Parent');  % hMain

dataStruct = guidata(h3);
if dataStruct.loadNumber == 0
    return;
end
currentDataName = dataStruct.ID{dataStruct.current};
currentData = dataStruct.dataset(dataStruct.current).dataInfo;

if currentData.dataStat_OK == 1  % if stat seq available
    nameSub  = currentData.subs;
    ct = currentData.count;
    ind = currentData.ind1;
    if get(findobj(h3,'Tag','checkbox_Stat'),'Value')==1
        condNames = currentData.cond;
        data = currentData.data;
    else
        seq = str2num(get(findobj(h3,'Tag','edit_indexStat'),'String')); %#ok<ST2NM>
        ct = ct(seq);
        ind = ind(seq);
        dataAll = currentData.data;
        newIndex = [];
        condNames = currentData.cond;
        for i=1:length(seq)
            newIndex = [newIndex,ind(i):ind(i)+ct(i)-1]; %#ok<AGROW>
        end
        data = dataAll(:,newIndex);
        condNames(setdiff(1:length(currentData.count),seq)) = [];
  
        ind = [1,cumsum(ct(1:end-1))+1];  % ---------
        
    end
    clear i j;
    
    warning off;
    [icaScore,icaLoading,pc,V,kurt,numPC,kurtV] = pcaica(data,5,1);

    [pcaLoading,pcaScore,pcaVariance] = princomp(data');
    pcOccupancy = 100*pcaVariance(pcaVariance~=0)./sum(pcaVariance);
    
    figure('Name','ICA IC Kurtosis'); % kurt vakues
    bar(kurtV);
    xlabel('ICs','FontSize',12);
    ylabel('Kurtosis','FontSize',12);
    pos = get(gcf,'Position');
    
    % Seperation plot
    a = get(findobj(h3,'Tag','edit_ICnumber'),'String');
    if isempty(str2num(a))==1
        icNumber = 2;
        set(findobj(h3,'Tag','edit_ICnumber'),'String','2');
    else
        icNumber = str2num(a);
    end
    if icNumber < 2 || icNumber > 5
        hWarn2 = warndlg('IC number must be within [2,5]');
        uiwait(hWarn2);
        uicontrol(findobj(h3,'Tag','edit_ICnumber'));
    else
        figure('Name',['ICA loading: ',currentDataName],'Position',...
            [pos(1)+50 pos(2) pos(3) pos(4)],'NumberTitle','off'); % seperation
        if icNumber == 2
            plot(icaLoading(1,:),icaLoading(2,:),'o','MarkerSize',8);
            xlabel('IC 1','FontSize',12);
            ylabel('IC 2','FontSize',12);
            %gname(nameSub); % please use ESC to exit
        else
            for i=1:icNumber
                for j=1:icNumber
                    % subplot(icNumber,icNumber,(i-1)*icNumber + j)
                    if i ~= j
                        subplot(icNumber,icNumber,(i-1)*icNumber + j);
                        plot(icaLoading(i,:),icaLoading(j,:),'o',...
                            'MarkerSize',6);
                        xlabel(strcat('IC',num2str(i)),'FontSize',10);
                        ylabel(strcat('IC',num2str(j)),'FontSize',10);
                    end
                end
            end
            subplot(icNumber,icNumber,2)
            %gname(nameSub); % press ESC to exit
        end
        
        % allocate colors and markers to conditions, support 72 conditions!
        % colors  = ['b','r','k','g','c','m'];
        colors  = ['k','b','g','c','r','m'];
        markers = ['o','s','d','^','v','+','*','x','<','>','p','h'];
        markerList = cell(1,length(colors)*length(markers));
        for iM = 1:length(markers)
            for jM = 1:length(colors)
                markerList{(iM-1)*length(colors)+jM} = strcat(markers(iM),colors(jM));
            end
        end
        
        switch icNumber
            case 2
                plotLoc = '11';
            case 3
                plotLoc = '13';
            case 4
                plotLoc = '23';
            case 5
                plotLoc = '25';
        end
        
        
        figure('Name',['ICA score 2D: ',currentDataName],'Position',...
            [pos(1)+100 pos(2) pos(3) pos(4)],'NumberTitle','off');
        countK = 0;
        for k1 = 1:icNumber-1
            for k2 = k1+1:icNumber
                countK = countK + 1;
                if countK == 10
                    subplot(2,5,10); % Index must be a 3-digit number of the format mnp
                else
                    plotLocK = [plotLoc,num2str(countK)];
                    subplot(str2double(plotLocK));
                end
                for iData = 1:length(ct)
                    if iData == 1
                        plot(icaScore(k1,1:ct(1)),icaScore(k2,1:ct(1)),'o',...
                            'MarkerSize',8,'MarkerFaceColor',markerList{1}(2),...
                            'MarkerEdgeColor',markerList{1}(2));
                        hold on;
                    else
                        plot(icaScore(k1,ind(iData):ind(iData)+ct(iData)-1),...
                            icaScore(k2,ind(iData):ind(iData)+ct(iData)-1),...
                            markerList{iData},'MarkerSize',8,...
                            'MarkerFaceColor',markerList{iData}(2),...
                            'MarkerEdgeColor',markerList{iData}(2));
                        hold on;
                    end
                end
                hold off;
                hLegend = legend(condNames,'-1');
                set(hLegend,'Interpreter','none');
                xlabel(['IC ',num2str(k1)],'FontSize',12);
                ylabel(['IC ',num2str(k2)],'FontSize',12);
                grid on;
            end
        end
        
        % =========         3D ICA score plot          ============
        if size(icaScore,2) >= 3
            figure('Name',['ICA score 3D: ',currentDataName],'Position',...
                [pos(1)+150 pos(2) pos(3) pos(4)],'NumberTitle','off');
            for iData = 1:length(ct)
                if iData == 1
                    plot3(icaScore(1,1:ct(1)),icaScore(2,1:ct(1)),...
                        icaScore(3,1:ct(1)),'o',...
                        'MarkerSize',8,'MarkerFaceColor',markerList{1}(2),...
                        'MarkerEdgeColor',markerList{1}(2));
                    hold on;
                else
                    plot3(icaScore(1,ind(iData):ind(iData)+ct(iData)-1),...
                        icaScore(2,ind(iData):ind(iData)+ct(iData)-1),...
                        icaScore(3,ind(iData):ind(iData)+ct(iData)-1),'o',...
                        'MarkerSize',8,'MarkerFaceColor',markerList{iData}(2),...
                        'MarkerEdgeColor',markerList{iData}(2));
                    hold on;
                end
            end
            hold off;
            hLegend = legend(condNames,'Location','NorthEastOutside');
            set(hLegend,'Interpreter','none');
            xlabel('IC 1','FontSize',12);
            ylabel('IC 2','FontSize',12);
            zlabel('IC 3','FontSize',12);
            grid on;
        end
        % ==============================================================
        
        % update the gui data
        currentData.icaLoading = icaLoading';
        currentData.icaScore = icaScore;
        currentData.icNumber = icNumber;
        currentData.icaKurt = kurtV;
        dataStruct.dataset(dataStruct.current).dataInfo = currentData;
        guidata(h3,dataStruct);
    end
else
    hWarnX = warndlg('Please select the data!');
    uiwait(hWarnX);
    uicontrol(findobj(h3,'Tag','checkbox_Stat'));
end


