function COVAIN_PCA(obj,evt)

h1 = get(obj,'Parent'); % hPanel_stat
h2 = get(h1,'Parent');  % hPanel_dataAnalysis
h3 = get(h2,'Parent');  % hMain

warning off; 
dataStruct = guidata(h3);
if dataStruct.loadNumber == 0
    return;
end
currentDataName = dataStruct.ID{dataStruct.current};
currentData = dataStruct.dataset(dataStruct.current).dataInfo;

if currentData.dataStat_OK == 1  % if stat seq available
    nameSub  = currentData.subs;
    ct = currentData.count;
    ind = currentData.ind1;
    if get(findobj(h3,'Tag','checkbox_Stat'),'Value')==1
        condNames = currentData.cond;
        data = currentData.data;
    else
        seq = str2num(get(findobj(h3,'Tag','edit_indexStat'),'String')); %#ok<ST2NM>
        ct = ct(seq);
        ind = ind(seq);
        dataAll = currentData.data;
        newIndex = [];
        condNames = currentData.cond;
        for i=1:length(seq)
            newIndex = [newIndex,ind(i):ind(i)+ct(i)-1]; %#ok<AGROW>
        end
        data = dataAll(:,newIndex);
        condNames(setdiff(1:length(currentData.count),seq)) = [];
        
        ind = [1,cumsum(ct(1:end-1))+1];  % -----------
        
    end
    
    % then do PCA
    [pcaLoading,pcaScore,pcaVariance] = princomp(data');
    pcOccupancy = 100*pcaVariance(pcaVariance~=0)./sum(pcaVariance);
    figure('Name',['PCA variances occupancy: ',currentDataName],'NumberTitle','off');
    bar(pcOccupancy);
    xlabel('PCs','FontSize',12);
    ylabel('Variance occupancy (%)','FontSize',12);
    pos = get(gcf,'Position');
    
    currentData.PCnumber = str2num(get(findobj(h3,'Tag','edit_PCnumber'),'String'));
    
    if isempty(currentData.PCnumber)==1
        set(findobj(h3,'Tag','edit_PCnumber'),'String','2');
        pcNumber = 2;
    else
        pcNumber = currentData.PCnumber;
    end
    % The first plot
    figure('Name',['PCA loading: ',currentDataName],'Position',...
        [pos(1)+50 pos(2) pos(3) pos(4)],'NumberTitle','off');
    if pcNumber == 2
        plot(pcaLoading(:,1),pcaLoading(:,2),'o','MarkerSize',6);
        xlabel(['PC 1 (',num2str(pcOccupancy(1),'%5.2f'),'%)'],'FontSize',12);
        ylabel(['PC 2 (',num2str(pcOccupancy(2),'%5.2f'),'%)'],'FontSize',12);
        %gname(nameSub); % please use ESC to exit
    else
        for i=1:pcNumber
            for j=1:pcNumber
                subplot(pcNumber,pcNumber,(i-1)*pcNumber + j)
                if i ~= j
                    plot(pcaLoading(:,i),pcaLoading(:,j),'o',...
                        'MarkerSize',8);
                    xlabel(['PC ',num2str(i),' (',num2str(pcOccupancy(i),'%5.2f'),'%)'],'FontSize',10);
                    ylabel(['PC ',num2str(j),' (',num2str(pcOccupancy(j),'%5.2f'),'%)'],'FontSize',10);
                else
                    xValue = get(gca,'XTick');
                    yValue = get(gca,'YTick');
                    text(0.4*mean(xValue),mean(yValue),strcat('PC',num2str(i),...
                        ' = ',num2str(pcOccupancy(i),'%5.2f'),'%'),'FontSize',12);
                end
            end
        end
        subplot(pcNumber,pcNumber,2)
        %gname(nameSub); % press ESC to exit
    end
    
    % allocate colors and markers to conditions, support 72 conditions!
    colors  = ['k','b','g','c','r','m'];
    markers = ['o','s','d','^','v','+','*','x','<','>','p','h'];
    markerList = cell(1,length(colors)*length(markers));
    
    for iM = 1:length(markers)
        for jM = 1:length(colors)
            markerList{(iM-1)*length(colors)+jM} = strcat(markers(iM),colors(jM));
        end
    end
    
    switch pcNumber
        case 2
            plotLoc = '11';
        case 3
            plotLoc = '13';
        case 4
            plotLoc = '23';
        case 5
            plotLoc = '25';
    end
    
    % The second plot
    Fig_score2D = figure('Name',['PCA score 2D: ',currentDataName],'Position',...
        [pos(1)+100 pos(2) pos(3) pos(4)],'NumberTitle','off');
    countK = 0;
    for k1 = 1:pcNumber-1
        for k2 = k1+1:pcNumber
            countK = countK + 1;
            if countK == 10
                subplot(2,5,10); % Index must be a 3-digit number of the format mnp
            else
                plotLocK = [plotLoc,num2str(countK)];
                subplot(str2double(plotLocK));
            end
            for iData = 1:length(ct)
                if iData == 1
                    plot(pcaScore(1:ct(1),k1),pcaScore(1:ct(1),k2),'o',...
                        'MarkerSize',8,'MarkerFaceColor',markerList{1}(2),...
                        'MarkerEdgeColor',markerList{1}(2));
                    hold on;
                else
                    plot(pcaScore(ind(iData):ind(iData)+ct(iData)-1,k1),...
                        pcaScore(ind(iData):ind(iData)+ct(iData)-1,k2),...
                        markerList{iData},'MarkerSize',8,...
                        'MarkerFaceColor',markerList{iData}(2),...
                        'MarkerEdgeColor',markerList{iData}(2));
                    hold on;
                end
            end
            hold off; set(Fig_score2D,'Name',['PCA score 2D: ',currentDataName]);
            hLegend = legend(condNames,'-1');
            set(hLegend,'Interpreter','none');
            xlabel(['PC ',num2str(k1),' (',num2str(pcOccupancy(k1),'%5.2f'),'%)'],'FontSize',12);
            ylabel(['PC ',num2str(k2),' (',num2str(pcOccupancy(k2),'%5.2f'),'%)'],'FontSize',12);
            grid on;
        end
    end
    
    % =========           3D PCA score plot       ============
    if size(pcaScore,2) >= 3
        figure('Position',[pos(1)+150 pos(2) pos(3) pos(4)],'Name',...
            ['PCA score 3D: ',currentDataName],'NumberTitle','off');
        for iData = 1:length(ct)
            if iData == 1
                plot3(pcaScore(1:ct(1),1),pcaScore(1:ct(1),2),...
                    pcaScore(1:ct(1),3),'o',...
                    'MarkerSize',8,'MarkerFaceColor',markerList{1}(2),...
                    'MarkerEdgeColor',markerList{1}(2));
                hold on;
            else
                plot3(pcaScore(ind(iData):ind(iData)+ct(iData)-1,1),...
                    pcaScore(ind(iData):ind(iData)+ct(iData)-1,2),...
                    pcaScore(ind(iData):ind(iData)+ct(iData)-1,3),...
                    markerList{iData},...
                    'MarkerSize',8,'MarkerFaceColor',markerList{iData}(2),...
                    'MarkerEdgeColor',markerList{iData}(2));
                hold on;
            end
        end
        hold off;
        hLegend = legend(condNames,'Location','NorthEastOutside');
        set(hLegend,'Interpreter','none');
        xlabel(['PC 1 (',num2str(pcOccupancy(1),'%5.2f'),'%)'],'FontSize',12);
        ylabel(['PC 2 (',num2str(pcOccupancy(2),'%5.2f'),'%)'],'FontSize',12);
        zlabel(['PC 3 (',num2str(pcOccupancy(3),'%5.2f'),'%)'],'FontSize',12);
        grid on;
    end
    % ==============================================================
    
    % update guidata
    currentData.pcaLoading  = pcaLoading;
    currentData.pcaScore    = pcaScore;
    currentData.pcaVariance = pcOccupancy;
    dataStruct.dataset(dataStruct.current).dataInfo = currentData;
    guidata(h3,dataStruct);
    % set(h3,'HandleVisibility','callback');
else
    hWarnX = warndlg('Please select the data!');
    uiwait(hWarnX);
    uicontrol(findobj(h3,'Tag','checkbox_Stat'));
end
