function PE = COVAIN_PE(obj,evt)
%
% calculate PE for each time-series

h = findobj('Tag','covainPanel_TOP');
dataStruct = guidata(h);
if dataStruct.loadNumber == 0
    return;
end
currentDataName = dataStruct.ID{dataStruct.current};
currentData = dataStruct.dataset(dataStruct.current).dataInfo;

if currentData.dataTS_OK == 1
    
    nameSub  = currentData.subs;
    nRow     = currentData.nRow;
    meanValue= currentData.dataTS;
    
    PE = zeros(nRow,1);
    
    for iRow=1:nRow
        dataRow = meanValue(iRow,:);
        PE(iRow) = peRow(dataRow);
    end
    
    % plot according to the order
    figure('Name',['PE: ',currentDataName],'NumberTitle','off');
    [PE_sort,indSub] = sort(PE,'descend');
    nameSub_sort = nameSub(indSub);
    
    if nRow >= 40
        ftSize = 6;
    else
        ftSize = 8;
    end
    stem(1:nRow,PE_sort');
    set(gca,'XTick',1:nRow,'XTickLabel',[]);
    set(gca,'FontSize',ftSize);
    ylabel('Permutation entropy (PE)','FontSize',12);
    xTick = get(gca,'XTick');
    yTick = get(gca,'YTick');
    text(xTick,repmat(yTick(1)-.02,length(xTick),1),nameSub_sort,...
        'HorizontalAlignment','right','rotation',30,'FontSize',ftSize+1,'FontName','Arial');
    set(gca,'FontSize',11);
    currentData.PE = PE;
    currentData.PE_OK = 1;
    
    % update guidata
    dataStruct.dataset(dataStruct.current).dataInfo = currentData;
    guidata(h,dataStruct);
else
    warndlg('Please select time series!');
    % uicontrol(findobj(h,'Tag','edit_indexTS'));
    
end
%  ***********  using nested function peRow *****************
    function entropyX = peRow(rowdata)
        num = zeros(length(rowdata)-2,1);
        for i=1:length(rowdata)-2 % length(data) - n + 1, n is the number of dots
            dot3 = rowdata(i:i+2);
            
            if i==1
                pattern = tiedrank(dot3);
                count = 1;
                num(1) = 1;
            else
                pt = tiedrank(dot3);
                flg = zeros(count,1);
                for j=1:count
                    flg(j) = any(pt - pattern(j,:));
                end
                if all(flg)
                    count = count + 1;
                    pattern = [pattern;pt]; %#ok<AGROW>
                    num(count) = 1;
                else
                    inde = find(flg==0);
                    num(inde) = num(inde) + 1;
                end
            end
        end
        
        num(num==0) = [];
        numProb = num/sum(num);
        entropyX = sum(-numProb.*log2(numProb));
    end
% **************************************************************


end
