function COVAIN_anova(obj,evt)

% get guidata
h0 = findobj('Tag','covainPanel_TOP');
dataStruct = guidata(h0);
if dataStruct.loadNumber == 0
    return;
end
currentData = dataStruct.dataset(dataStruct.current).dataInfo;
meanValue = currentData.table;
data = currentData.data;
condName = currentData.cond;
subName = currentData.subs;
sampleName = currentData.sampleName;
ct = currentData.count;  
nRep = min(ct);
nCond = length(ct);
nRow = currentData.nRow;
ind1 = currentData.ind1;
savePath = currentData.savePath;
currentDataName = dataStruct.ID{dataStruct.current};

% reduce unbalanced problem by removing extra reps
if nRep < max(ct)
    indAll = [];
    for iCond = 1:nCond
        locIndex = ind1(iCond):ind1(iCond)+nRep-1;
        indAll = [indAll,locIndex];
        meanValue(:,iCond) = mean(data(:,locIndex),2);
    end
    data = data(:,indAll);
    sampleName = sampleName(indAll);
end

% a new window for one way anova
fig = figure('Position',[280 100 700 600],...
             'Name','One way ANOVA','Resize','on','NumberTitle','off',...
             'MenuBar','none','Tag','fig','HandleVisibility','callback');
pan = uipanel('Parent',fig,'Units','Normalized',...
              'Position',[.01 .8 .59 .17],'Title',' Settings ','Tag','pan',...
              'FontSize',12,'FontWeight','bold');
headText1 = uicontrol('Parent',pan,'Units','Normalized',...
               'Position',[.01 .75 .45 .22],'Style','text','FontSize',11,...
               'String','Comparing to','HorizontalAlignment','left');
% forbid multiple selections
listName = uicontrol('Parent',pan,'Units','Normalized',...
               'Position',[.01 .1 .45 .6],'Style','listbox',...
               'Max',1,'Min',0,'String',condName','Value',1,'Tag','list',...
               'Callback',@listCall);
headText2 = uicontrol('Parent',pan,'Units','Normalized',...
               'Position',[.5 .75 .2 .22],'Style','text','FontSize',11,...
               'String','p-value','HorizontalAlignment','left');
pvalEdit = uicontrol('Parent',pan,'Units','Normalized','FontSize',11,...
               'Position',[.5 .1 .2 .6],'Style','edit','String','0.01');
okButton = uicontrol('Parent',pan,'Units','Normalized',...
               'Position',[.75 .1 .2 .6],'Style','pushbutton',...
               'String','OK','FontSize',11,'Callback',@okCall,'Userdata',0.01);
showButton = uicontrol('Parent',fig,'Units','Normalized',...
               'Position',[.65 .8 .1 .1],'String','Show',...
               'Style','pushbutton','Tag','showButton',...
               'Callback',@showCall,'Enable','off','FontSize',11);
saveButton = uicontrol('Parent',fig,'Units','Normalized',...
               'Position',[.77 .8 .2 .1],'String','Save new dataset',...
               'Style','pushbutton','Tag','saveButton',...
               'Callback',@saveCall,'Enable','off','FontSize',11);
dataTable = uitable('Parent',fig,'Units','Normalized',...
               'Position',[.01 .05 .96 .7],'ColumnName',condName,...
               'Data',meanValue,'CellSelectionCallback',@plotTable,...
               'RearrangeableColumns','off','RowName',subName);
           
% color specification
colorDefault = '<font bgcolor=#FFFFFF>';    % white
color0 = '<font bgcolor=#C0C0C0>';          % silver for contr
color1 = '<font bgcolor=#99CCFF>';          % blue for down
color2 = '<font bgcolor=#FFCCFF>';          % pink for up

% set pan userdata
oldTable = cell(size(data)+1);
oldTable(1,2:end) = sampleName;
oldTable(2:end,1) = subName;
oldTable(2:end,2:end) = num2cell(data);
set(pan,'Userdata',oldTable);

% disable ok button if only one rep or one cond
if nCond == 1 || nRep == 1
    set(okButton,'Enable','off');
end

% ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
% ++++++++++++++++++++++   Nested functions   ++++++++++++++++++++++++++ 
    
    % choose comparisons and highlight cells
    function okCall(objS,evtS)
        % reset all colors
        set(dataTable,'Data',meanValue,'RowName',subName);
        % reset show and save button
        set(showButton,'Userdata',[],'Enable','off');
        set(saveButton,'Userdata',[],'Enable','off');
        % which to compare
        cond0 = get(listName,'Value');
        % get p-value
        pval = str2num(get(pvalEdit,'String'));
        if isempty(pval)
            pval = 0.01;
            set(pvalEdit,'String','0.01');
            set(objS,'Userdata',0.01);
        elseif length(pval) > 1
            pval = 0.01;
            set(pvalEdit,'String','0.01');
            set(objS,'Userdata',0.01);
        elseif pval <= 0 || pval >= 1
            pval = 0.01;
            set(pvalEdit,'String','0.01');
            set(objS,'Userdata',0.01);
        end
        % calculate if empty or new pval
        if isempty(get(fig,'Userdata')) || pval ~= get(objS,'Userdata')   
            sigTable = zeros(nRow,nCond,nCond);
            hWait = waitbar(0,'Calculating ... ');
            for i=1:nRow                  
                dataRow = data(i,:);
                dataMatrix = reshape(dataRow,nRep,nCond);
                [zp,zt,zs] = anova1(dataMatrix,[],'off');
                zc = multcompare(zs,'alpha',pval,'display','off');
                za = zeros(nCond^2,1);
                % signed table
                signsNeg = zc(:,5) < 0;  % max<0
                signsPos = zc(:,3) > 0;  % min>0
                signs = -signsNeg + signsPos;
                za(sub2ind([nCond,nCond],zc(:,1),zc(:,2))) =  signs;
                za(sub2ind([nCond,nCond],zc(:,2),zc(:,1))) =  -signs;          
                sigTableLocal = reshape(za,nCond,nCond);
                sigTable(i,:,:) = sigTableLocal;
                waitbar(i/nRow);
            end
            close(hWait);
            set(objS,'Userdata',pval);    % pval is saved in OK button
            set(fig,'UserData',sigTable); % sigTable is saved in fig
        else
            sigTable = get(fig,'Userdata');
        end
        % Highlight cells
        sigFlg = zeros(nRow,3); % both, neg, pos
        bgcolors = cell(nRow,nCond);
        hWait = waitbar(0,'Coloring ... ');
        for i=1:nRow
            sigLocal = reshape(sigTable(i,:,:),nCond,nCond);
            sigFlg(i,1) = any(sigLocal(:,cond0)~=0);  % col = t - c
            sigFlg(i,2) = sum(sigLocal(:,cond0)<0);
            sigFlg(i,3) = sum(sigLocal(:,cond0)>0);
            idxNeg = (find(sigLocal(:,cond0)<0))'; % row
            idxPos = (find(sigLocal(:,cond0)>0))'; % row
            idxEls = setdiff(1:nCond,[idxNeg,idxPos]);
            for j=1:length(idxEls)
                bgcolors{i,idxEls(j)} = ['<html>',colorDefault,...
                    num2str(meanValue(i,idxEls(j))),'</font></html>'];              
            end
            for j=1:length(idxNeg)
                bgcolors{i,idxNeg(j)} = ['<html>',color1,...
                    num2str(meanValue(i,idxNeg(j))),'</font></html>'];
            end
            for j=1:length(idxPos)
                bgcolors{i,idxPos(j)} = ['<html>',color2,...
                    num2str(meanValue(i,idxPos(j))),'</font></html>'];
            end
            bgcolors{i,cond0} = ['<html>',color0,...
                    num2str(meanValue(i,cond0)),'</font></html>'];
            waitbar(i/nRow);
        end
        set(dataTable,'Data',bgcolors,'Enable','on','RowName',subName);
        close(hWait);
        % Set showButton and saveButton on
        if any(sigFlg(:,1))   % at least one shows significance   
            set(showButton,'Enable','on','Userdata',sigFlg);  
            set(saveButton,'Userdata',bgcolors);
        end    
    end % this nested function ends
%     % unsigned table
%     signs = (sign(zc(:,3)).*sign(zc(:,5))) == 1;
%     za(sub2ind([nCond,nCond],zc(:,1),zc(:,2))) =  signs;
%     za(sub2ind([nCond,nCond],zc(:,2),zc(:,1))) =  signs;    

    % **********************************************

    % show variables with significance change
    function showCall(objS,evtS)
        sigFlg = get(objS,'Userdata');
        bgcolors = get(saveButton,'Userdata');
        if isempty(sigFlg) || isempty(bgcolors)
            set(objS,'Enable','off');
            set(saveButton,'Enable','off');
        else
            % display selected variables in ascending order (down -> up)
            idxNew = find(sigFlg(:,1)~=0);
            subNew = subName(idxNew);
            subNewS = subNew;
            for i=1:length(idxNew)
                s1 = num2str(99-sigFlg(idxNew(i),2));
                if nCond >= 10
                    s2 = num2str(sigFlg(idxNew(i),3));
                else
                    s2 = num2str(10*sigFlg(idxNew(i),3));
                end
                s3 = subNew{i};
                subNewS{i} = [s1,s2,s3];
            end
            [waste,idxNewX] = sort(subNewS);
            idxNew = idxNew(idxNewX);
            subNew = subNew(idxNewX);
            dataNew = data(idxNew,:);  % all data, not mean value
            bgcolorsNew = bgcolors(idxNew,:);
            set(dataTable,'Data',bgcolorsNew,'ColumnName',condName,...
                'RowName',subNew);
            % set save table data
            % recover original sample names
            sampleName2 = sampleName;
            for i = 1:size(dataNew,2)
                locRepStr = findstr(' -rep',sampleName2{i});
                sampleName2{i} = sampleName2{i}(1:locRepStr-1);
            end
            % then save
            set(saveButton,'Enable','on');
            newTable = cell(size(dataNew)+1);
            newTable(1,2:end) = sampleName2;
            newTable(2:end,1) = subNew;
            newTable(2:end,2:end) = num2cell(dataNew);
            set(pan,'Userdata',newTable);
        end 
    end % this nested function ends
    
    % **********************************************

    % save to guidata and save to Excel tables
    function saveCall(objS,evtS)
        newTable = get(pan,'Userdata');
        % guidata update
        currentData.anovaTable = get(fig,'Userdata');
        dataStruct.dataset(dataStruct.current).dataInfo = currentData;
        guidata(h0,dataStruct);
        % import new data
        if isempty(newTable)
            set(objS,'Enable','off');
        else
            rawFileName = dataStruct.ID{dataStruct.current};
            rawFileName = rawFileName(findstr('--',rawFileName)+2:end);
            rawFileName = [rawFileName,'-AnovaSelection'];
            try
                COVAIN_loadIntData(newTable,rawFileName,h0);
                msgbox(' Done!');
            catch err
                hWarn_Text = err.message;
                hWarn = warndlg(hWarn_Text);
                uiwait(hWarn);
            end
        end
    end % this nested function ends
    
    % **********************************************
    
    % plot table data (multiple selections allowed)
    function plotTable(objS,evtS)
        dataCell = get(pan,'Userdata');
        subNameCell = dataCell(2:end,1);
        if isempty(dataCell)
            % set(objS,'Enable','off');
            return;
        else
            dataNum = cell2mat(dataCell(2:end,2:end));
            idxS = evtS.Indices;
            idxS = unique(idxS(:,1)); % row
            dataRows = dataNum(idxS,:);
            % box plot
            nrowS = round(sqrt(length(idxS)));
            ncolS = ceil(sqrt(length(idxS)));
            f1 = figure('Name',['ANOVA box plot: ',currentDataName],'NumberTitle','off');
            for i=1:size(idxS,1)
                subplot(nrowS,ncolS,i);
                boxplot(reshape(dataRows(i,:),nRep,nCond));
                set(gca,'XTick',1:nCond,'XTickLabel',condName);
                title(subNameCell(idxS(i)),'FontSize',12,...
                    'Interpreter','none');
                xlabel('Conditions','FontSize',11); 
                ylabel('Levels','FontSize',11);
            end
            % remove selection after plotting ---- 
            % a stupid way to remove excessive figure
            if isempty(get(f1,'Children'))
                delete(f1);
            end 
        end
    end % this nested function ends
% %if using errbar
%             meanRows = zeros(size(idxS,1),nCond);
%             stdRows = meanRows;
%             for i=1:size(idxS,1)
%                 for j=1:nCond
%                     idxLoc = (j-1)*nRep+1:j*nRep;
%                     meanRows(i,j) = mean(dataRows(i,idxLoc));
%                     stdRows(i,j) = std(dataRows(i,idxLoc));
%                 end
%             end

    % **********************************************
    
    % listbox selection callback
    function listCall(objS,evtS)
        % reset show and save buttons, and table colors
        set(showButton,'Enable','off');
        set(saveButton,'Enable','off');
        set(dataTable,'Data',meanValue,'RowName',subName);
    end

% +++++++++++++++++++++    Nested functions end   ++++++++++++++++++++++
% ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

end  % end of main function
           
                   