function COVAIN_clusterStat(obj,evt)

dataStruct = guidata(findobj('Tag','covainPanel_TOP'));
currentData = dataStruct.dataset(dataStruct.current).dataInfo;
currentDataName = dataStruct.ID{dataStruct.current};

% meanValue = currentData.table;
meanValue = currentData.dataStat;
cond = currentData.condStat;
nameSub = currentData.subs;

% scan which is the control and which are treatments
flgContr = zeros(1,size(meanValue,2));
flgTreat = flgContr;
hclusFig = findobj('Name','Cluster analysis');
for i=1:size(meanValue,2)
    flgContr(i) = get(findobj(hclusFig,'Tag',['radio_clusterFig_cond',num2str(i)]),'Value');
    flgTreat(i) = get(findobj(hclusFig,'Tag',['checkbox_clusterFig_cond',num2str(i)]),'Value');
end

indexCond = find(flgTreat==1);
if length(indexCond) >= 2
    newCond = cond(indexCond);
    diffMean = zeros(size(meanValue,1),length(indexCond));
    for i=1:length(indexCond)
        diffMean(:,i) = meanValue(:,indexCond(i)) - meanValue(:,flgContr == 1);
    end
    if exist('clustergram','file') == 3 % clustergram function is available
        % add colorbar by user
        [nrow,ncol] = size(meanValue);
        r = 2*ncol/nrow;
        if nrow <= 40
            clustergram(diffMean,'RowLabels',nameSub,'ColumnLabels',newCond,...
                'Symmetric',false,'Standardize',3,'ColumnLabelsRotate',60,...
                'DisplayRatio',[r*.2,.2]);
        else
            clustergram(diffMean','RowLabels',newCond,'ColumnLabels',nameSub,...
                'Symmetric',false,'Standardize',3,'ColumnLabelsRotate',60,...
                'DisplayRatio',[.3,r*.3]);
        end
    else                % alternative method to realize clustering heatmap
        % standardize data and claculate distance
        diffMean = zscore(diffMean,[],2);
        x_pdist = pdist(diffMean); % NOT on correlation !!
        y_pdist = pdist(diffMean');
        x_link = linkage(x_pdist,'average');
        y_link = linkage(y_pdist,'average');
        x_order =  optimalleaforder(x_link,x_pdist);
        y_order =  optimalleaforder(y_link,y_pdist);
        minM = min(diffMean(:)); maxM = max(diffMean(:));
        diffMean = diffMean - (abs(maxM) - abs(minM))/2;
        diffMean = 2*diffMean./range(diffMean(:));

        % plot dendrogram for metabolites, set line color as black
        figure('Name',['Bi-clustering: ',currentDataName],'NumberTitle','off');
        a2 = axes('position',[.05 .15 .15 .7]);
        [~,~,d2] = dendrogram(x_link,0,'orientation','left','reorder',x_order);
        c2 = get(a2,'Children');
        for i=1:length(c2)
            set(c2(i),'Color',[0 0 0]);
        end
        set(a2,'XTick',[],'XTickLabel',[]);
        set(a2,'YTick',[],'YTickLabel',[]);
        axis off

        % plot dendrogram for conditions, set line color as black
        a3 = axes('position',[.2 .85 .5 .1]);
        [~,~,d3] = dendrogram(y_link,0,'reorder',y_order);
        c3 = get(a3,'Children');
        for i=1:length(c3)
            set(c3(i),'Color',[0 0 0]);
        end
        set(a3,'XTick',[],'XTickLabel',[]);
        set(a3,'YTick',[],'YTickLabel',[]);
        axis off
        
        % y-order is just upside down, stupid. @ 2016-01-02
        d2 = d2(end:-1:1);

        % plot heat map
        diffMean = diffMean(d2,:); diffMean = diffMean(:,d3);
        a1 = axes('position',[.2  .15  .5  .7]);
        imagesc(diffMean); colormap(redbluecmap);
        set(a1,'YAxisLocation','right');

        % finally, label the heat map using adaptive font size
        subsNew = nameSub(d2);
        condNew = newCond(d3);
        scSize = get(0,'ScreenSize');
        ftSize = min(floor(0.8*scSize(4)*0.7/size(diffMean,1)),12);
        set(a1,'YTick',1:size(diffMean,1),'YTickLabel',subsNew,'FontSize',ftSize);
        set(a1,'XTick',1:size(diffMean,2),'XTickLabel',condNew);
        xTick = get(a1,'XTick');
        yTick = get(a1,'YTick');
        text(xTick,repmat(yTick(end)+.8,length(xTick),1),condNew,...
            'HorizontalAlignment','right','rotation',30,'FontSize',12,'FontName','Helvetica');
        set(a1,'XTick',[],'XTicklabel',[]);
    end   
else
    warndlg('Needs at least two samples!');
end

