function COVAIN_clusterStatNormal(obj,evt)
%

h = findobj('Tag','covainPanel_TOP');
dataStruct = guidata(h);
if dataStruct.loadNumber == 0
    return;
end
currentDataName = dataStruct.ID{dataStruct.current};
currentData = dataStruct.dataset(dataStruct.current).dataInfo;

if currentData.dataStat_OK == 1  %
    nameSub  = currentData.subs;
    nRow     = currentData.nRow;
    % meanValue= currentData.table;
    meanValue= currentData.dataStat;
    nCol = size(meanValue,2);
    cond = currentData.condStat; 
    
    if exist('clustergram','file') == 3 % clustergram function is available
        r = 2*nCol/nRow;
        if nRow <= 100
            clustergram(meanValue,'RowLabels',nameSub,'ColumnLabels',cond,...
                'Symmetric',false,'Standardize',2,'ColumnLabelsRotate',60,...
                'DisplayRatio',[r*.2,.2],'Cluster',1);
        else
            clustergram(meanValue','RowLabels',cond,'ColumnLabels',nameSub,...
                'Symmetric',false,'Standardize',2,'ColumnLabelsRotate',60,...
                'DisplayRatio',[.3,r*.3],'Cluster',1);
        end
    else                % alternative method to realize clustering heatmap
        % standardize data and claculate distance
        % +++++  modified @ 2015-07-25  +++++
        meanValue = zscore(meanValue,[],2);
        minM = min(meanValue(:)); maxM = max(meanValue(:));
        meanValue = meanValue - (abs(maxM) - abs(minM))/2;
        meanValue = 2*meanValue./range(meanValue(:));
        
        x_pdist = pdist(meanValue);
        y_pdist = pdist(meanValue');
        x_link = linkage(x_pdist,'average');
        y_link = linkage(y_pdist,'average');
        x_order =  optimalleaforder(x_link,x_pdist);
        y_order =  optimalleaforder(y_link,y_pdist);
        
        % plot dendrogram for metabolites, set line color as black
        figure('Name',['Bi-clustering: ',currentDataName],'NumberTitle','off');
        a2 = axes('position',[.05 .15 .15 .7]);
        [~,~,d2] = dendrogram(x_link,0,'orientation','left','reorder',x_order);
        c2 = get(a2,'Children');
        for i=1:length(c2)
            set(c2(i),'Color',[0 0 0]);
        end
        set(a2,'XTick',[],'XTickLabel',[]);
        set(a2,'YTick',[],'YTickLabel',[]);
        axis off
        
        % plot dendrogram for conditions, set line color as black
        a3 = axes('position',[.2 .85 .5 .1]);
        [~,~,d3] = dendrogram(y_link,0,'reorder',y_order);
        c3 = get(a3,'Children');
        for i=1:length(c3)
            set(c3(i),'Color',[0 0 0]);
        end
        set(a3,'XTick',[],'XTickLabel',[]);
        set(a3,'YTick',[],'YTickLabel',[]);
        axis off
        
        % y-order is just upside down, stupid. @ 2016-01-02
        d2 = d2(end:-1:1);
        
        % plot heat map
        meanValue = meanValue(d2,:); meanValue = meanValue(:,d3);
        a1 = axes('position',[.2  .15  .5  .7]);
        imagesc(meanValue); 
        colormap(redbluecmap); 
        set(a1,'YAxisLocation','right');
        
        % finally, label the heat map using adaptive font size
        subsNew = nameSub(d2); 
        %condNew = cond;
        condNew = cond(d3);
        scSize = get(0,'ScreenSize');
        ftSize = min(floor(0.8*scSize(4)*0.7/size(meanValue,1)),12);
        set(a1,'YTick',1:size(meanValue,1),'YTickLabel',subsNew,'FontSize',ftSize);
        set(a1,'XTick',1:size(meanValue,2),'XTickLabel',condNew);
        xTick = get(a1,'XTick');
        yTick = get(a1,'YTick');
        text(xTick,repmat(yTick(end)+.8,length(xTick),1),condNew,...
            'HorizontalAlignment','right','rotation',30,'FontSize',12,'FontName','Helvetica');
        set(a1,'XTick',[],'XTicklabel',[]); 
    end
else
    hWarn = warndlg('Please select the data!');
    uiwait(hWarn);
    uicontrol(findobj(h,'Tag','checkbox_Stat'));
end