function COVAIN_cpd2pwy(obj,evt)
% retrieve KEGG pathway from the compounds and enrichment analysis
% use KEGG compound data(Cxxxxx) as April 2015
% Xiaoliang Sun @ 2015-06-18
%
% Plans @ 2015-11-09  -------------
%   1. Consider condition-specific enrichment  
%   2. Enlarge/pop-up CPD table
%   3. Save selected CPD as a library file
%   4. Download the pathway maps ---> added @ Jan.15,2016
%   5. Add updateFun which allows re-selection

%% obtaining GUI data
hTop = findobj('Tag','covainPanel_TOP');

dataStruct = guidata(hTop); 
if dataStruct.loadNumber == 0
    return;
end
currentData = dataStruct.dataset(dataStruct.current).dataInfo;
dataName = dataStruct.ID{dataStruct.current};
savePath = currentData.savePath;
parVer = dataStruct.parVer; parNum = dataStruct.parNum;
localName = currentData.subs; 

%% load KEGG DB
% extremely stupid, unfortunately!!!
CPD = load('KeggCPD','CPD'); CPD = CPD.CPD;
nameCPD = load('KeggCPD','nameCPD'); nameCPD = nameCPD.nameCPD;
PWY = load('KeggCPD','PWY'); PWY = PWY.PWY; % it is ATH pathway
PWY_ID_ATH = load('KeggCPD','PWY_ID_ATH'); PWY_ID_ATH = PWY_ID_ATH.PWY_ID_ATH;
annoNames = load('KeggCPD','annoNames'); annoNames = annoNames.annoNames;
anno_1 = load('KeggCPD','anno_1'); anno_1 = anno_1.anno_1;
anno_2 = load('KeggCPD','anno_2'); anno_2 = anno_2.anno_2;
anno_3 = load('KeggCPD','anno_3'); anno_3 = anno_3.anno_3;
anno_4 = load('KeggCPD','anno_4'); anno_4 = anno_4.anno_4;
anno_5 = load('KeggCPD','anno_5'); anno_5 = anno_5.anno_5;
anno_6 = load('KeggCPD','anno_6'); anno_6 = anno_6.anno_6;
anno_7 = load('KeggCPD','anno_7'); anno_7 = anno_7.anno_7;
anno_8 = load('KeggCPD','anno_8'); anno_8 = anno_8.anno_8;
listCPD = [];
for i=1:size(PWY,1)
    listCPD = [listCPD; PWY{i,2}];
end

%% Generate a panel for compound mapping
% get screen size and claculate panel position
siz = get(0,'MonitorPositions');
if size(siz,1) >= 2 % two or more screens
    idxSiz = find(siz(:,3)-siz(:,1)==max(siz(:,3)-siz(:,1)));
    siz = siz(idxSiz(end),:);
end
siz_width = siz(3) - siz(1) + 1; siz_height = siz(4) - siz(2) + 1;
fig_width = 0.96*siz_width; fig_height = 0.9*siz_height;
fig_pos = [siz(1)+0.02*fig_width, siz(2)+0.06*fig_height,fig_width,fig_height];
pwyTop = figure('Position',fig_pos,...
                'Interruptible','on',...
                'Name',['KEGG Pathway Analysis',dataName],...
                'NextPlot','new',...
                'NumberTitle','off',...
                'Resize','on',...
                'MenuBar','none', ...
                'Toolbar','none', ...
                'Tag','pwy_TOP',...
                'HandleVisibility','callback');
pwyPanel = uipanel('Parent',pwyTop,'Units','Normalized',...
    'Position',[.01 .01 .98 .98],'Tag','pwy_panel');
bgColorBlue = [204 229 255]/255; % RGB 256, light blue color
bgColorGreen = [153 204 153]/255; % light green, same as mzGA


%% mapping the compound names to KEGG --- can also be m/z, mass, etc
len = length(localName); lenAll = size(nameCPD,1);
tableData = cell(len,1);
tableFormat = {'char','char','char','numeric','numeric','numeric','logical'};

% estimate time
meanLenName = round(mean(cellfun(@length, localName))); 
testName =  char(48:90); testName = testName(1:meanLenName);
tic; distLocal = cellfun(@(x) COVAIN_strDist(testName,x), nameCPD(:,2));
timeEst = (toc*1.4*len)/(0.8*parNum*60);
hWait = waitbar(0.5,['Estimated time: ',num2str(timeEst,'%10.2f'),' min'],...
    'Name','Mapping compound names to KEGG');
parfor i=1:len
    distLocal = cellfun(@(x) COVAIN_strDist(localName{i},x), nameCPD(:,2));
    [~,idxDist] = sort(distLocal,'ascend');
    % select first five unique ones
    baseLen = 10;
    [~,idxU] = unique(nameCPD(idxDist(1:baseLen),1),'stable'); 
    while length(idxU) < 5
        [~,idxU] = unique(nameCPD(idxDist(1:baseLen+10),1),'stable');
    end
    kidU = nameCPD(idxDist(idxU(1:5)),1);
    tableUnit = cell(7,7); % last line is empty
    tableUnit(1,:) = [{'Selected','KEGG_ID'},localName(i),{'Formula','Exact_Mass',...
        'Mol_Weight','Score'}];
    for j=1:5
        tableUnit(j+1,2:6) = CPD(strcmp(kidU{j},CPD(:,1)),:);
        tableUnit{j+1,7} = 1 - distLocal(idxDist(idxU(j)))/length(localName{i});
        if j==1
            tableUnit{j+1,1} = true;
        else
            tableUnit{j+1,1} = false;
        end
    end
    tableData{i} = tableUnit;
end
delete(hWait);


%% display the table, one column layout (left side)
tableFull = cell(len*7,7);
% <HTML><FONT SIZE="+3">your original value</FONT></HTML>
for i=1:len
    tableFull((i-1)*7+2:i*7,:) = tableData{i}(2:end,:);
    for j=1:7
        tableFull{(i-1)*7+1,j} = ...
            ['<HTML><p style="font-weight: bold; color: black;">',...
            tableData{i}{1,j},'</p><HTML>'];
    end   
end
cpdTable = uitable('Parent',pwyPanel,'Units','Normalized','RowName',[],...
    'Position',[.01 .01 .38 .98],'Data',tableFull,'FontSize',9,...
    'ColumnEditable', [true false false false false false false]);

%% update button @ checked, 2017.05.23
hUpdate = uicontrol('Parent',pwyPanel,'Units','Normalized',...
    'Position',[.43 .94 .07 .05],'Style','pushbutton',...
    'Interruptible','off','String','Update','FontSize',12,'FontWeight',...
    'Bold','BackgroundColor',bgColorGreen,'CallBack',@pwyFun);
hDownload = uicontrol('Parent',pwyPanel,'Units','Normalized',...
    'Position',[.52 .94 .08 .05],'Style','pushbutton',...
    'Interruptible','off','String','Download maps','FontSize',12,'FontWeight',...
    'Bold','BackgroundColor',bgColorBlue,'UserData',[],'CallBack',@pwyDown);
hExport = uicontrol('Parent',pwyPanel,'Units','Normalized',...
    'Position',[.62 .94 .07 .05],'Style','pushbutton',...
    'Interruptible','off','String','Export tables','FontSize',12,'FontWeight',...
    'Bold','BackgroundColor',bgColorBlue,'CallBack',@exportFun);

    function exportFun(objB,evtB)
        % export enrichment results
        expPWY = get(hUpdate,'UserData');
        expCAT = get(hExport,'Userdata'); flgMsg1 = 0; flgMsg2 = 0;
        nHit = cell2mat(expPWY(2:end,3));
        if ~isempty(expPWY) & any(nHit>0)
            xlswrite([savePath,'_Kegg_Pathway_Enrichment.xlsx'],expPWY);
            flgMsg1 = 1;
        end
        if ~isempty(expCAT)
            xlswrite([savePath,'_Kegg_Compound_Enrichment.xlsx'],expCAT);
            flgMsg2 = 1;
        end
        % export cpd matching table ---- 
        
        if flgMsg1 == 1 & flgMsg2 == 1
            msgbox('  Pathway and Compound enrichment analysis are exported.  ');
        elseif flgMsg1 == -1 & flgMsg2 == 1
            msgbox(' Compound enrichment analysis are exported. ');
        elseif flgMsg1==1 & flgMsg2==-1
            msgbox(' Pathway enrichment analysis are exported. ');
        else
            msgbox(' No Pathway nor Compounds results available. ');
        end
            
    end
        
%% pwy analysis
    function pwyFun(objA,evtA)
        % get the updated table
        tableUpdated = get(cpdTable,'Data');
        idxSolidTable = 1:size(tableUpdated);  % size(matrix) = size(matrix,1)
        idxExTable = 1:7:size(tableUpdated,1); 
        idxExTable = [idxExTable,7:7:size(tableUpdated,1)];idxSolidTable(idxExTable) = []; 
        selectedID = tableUpdated(idxSolidTable(cell2mat(tableUpdated(idxSolidTable,1))==1),2);
        % export cpdTable
        % *** later ***
        % -------------------------
        if isempty(selectedID)
            return;
        end
        selectedID = unique(selectedID,'stable'); % **********
        set(pwyPanel,'UserData',selectedID);
        pval = ones(size(PWY,1),1); pvalSign = cell(length(pval),1);% X,M,K,N
        M = sum(cellfun(@length,PWY(:,2))); 
        K = sum(ismember(listCPD,selectedID));
        pwyCount = zeros(length(pval),2); flgSign = zeros(length(pval),1);
        cpdInPwy = cell(length(pval),3); % pwyID,pwyName,CPD
        cpdInPwy(:,1:2) = PWY_ID_ATH; flgPWY = ones(length(pval),1);
        for iPval=1:length(pval)
            N = size(PWY{iPval,2},1); 
            idxCPD = ismember(PWY{iPval,2},selectedID);
            cpds = PWY{iPval,2}(idxCPD);
            flgPWY(iPval) = any(idxCPD);
            if any(idxCPD)
                cpdInPwy{iPval,3} = cpds;
            end
            X = sum(idxCPD);
            pval(iPval) = hygepdf(X,M,K,N);   
            if X/N > K/M; pvalSign{iPval} = '        +'; flgSign(iPval) = 1;
            else pvalSign{iPval} = '        -'; flgSign(iPval) = -1; end
            pwyCount(iPval,1) = N; pwyCount(iPval,2) = X; 
        end
        pval = mafdr(pval,'BHFDR','true');
        pNum = flgSign.*(1000*(length(pval)+1-tiedrank(pval)) + pwyCount(:,2));
        [~,idxP] = sort(pNum,'descend');
        pwyTableData = cell(length(pval)+1,5); % name, total, hit, type, p-value
        pwyTableData(1,:) = ...
            {'Pathway Name','Total Compound','Hit Compound','Type','p-value'};
        for iHead = 1:size(pwyTableData,2)
            pwyTableData{1,iHead} =  ...
                ['<HTML><p style="font-weight: bold; color: black;">',...
                   pwyTableData{1,iHead},'</p><HTML>'];
        end
        pwyTableData(2:end,1) = PWY(idxP,1);
        pwyTableData(2:end,2:3) = num2cell(pwyCount(idxP,:));
        pwyTableData(2:end,4) = pvalSign(idxP);
        pwyTableData(2:end,5) = num2cell(pval(idxP));
        pwyTable = uitable('Parent',pwyPanel,'Units','Normalized','RowName',[],...
            'Position',[.72 .01 .27 .98],'Data',pwyTableData,'FontSize',9);
        pwyExport = [{'Pathway Name','Total Compound','Hit Compound','Type',...
            'p-value'}; pwyTableData(2:end,:)];
        set(hUpdate,'UserData',pwyExport);
        cpdFun;
        
        % ################################################################
        %                                                                %
        % Download the pathway maps by an added "download" button ------ %
        %                                                                %
        % ################################################################
        
        % get the solid pathways (contains at least one cpd)
        cpdInPwy = cpdInPwy(flgPWY==1,:);
        set(hDownload,'UserData',cpdInPwy);
        
    end

%% Download pathway maps @ 2017.05.23
    function pwyDown(objDown,evtDown)
        cpdInPwy = get(objDown,'UserData');
        cpdAll = [];
        for k=1:size(cpdInPwy,1)
            cpdAll = [cpdAll; cpdInPwy{k,3}];
        end
        cpdAll = unique(cpdAll);
        if isempty(cpdAll)
            warndlg('No KEGG compounds are identified!');
            return;
        end
        % add two global maps
        cpdInPwyAdd = [{'map01100','Metabolic Pathways'},{cpdAll}; 
            {'map01110','Biosynthesis of secondary metabolites'},{cpdAll}];
        cpdInPwy = [cpdInPwyAdd;cpdInPwy];
        % format url
        % like: http://www.kegg.jp/pathway/ath00010+C00022+C00668
        lenPath = size(cpdInPwy,1);
        if lenPath == 0
            return;
        end
        downOptions = weboptions('Timeout',60);
        if ~exist([savePath,'KeggMaps'],'dir')
            mkdir([savePath,'KeggMaps']);
        end
        hWaitDown = waitbar(0,'Downloading pathway maps ... it may take several minutes.');
        for k=1:lenPath
            flg = 1;
            fullName = cpdInPwy{k,1};
            for k2=1:length(cpdInPwy{k,3})
                fullName = [fullName,'+',cpdInPwy{k,3}{k2}];
            end
            
            downLink =  ['http://www.kegg.jp/pathway/',fullName];
            hWaitStr = ['Downloading Map ',cpdInPwy{k,1},' ', cpdInPwy{k,2}];
            waitbar(k/(lenPath+1),hWaitDown,hWaitStr);
            try
                textWeb = webread(downLink,downOptions);
            catch
                waitbar(k/(lenPath+1),hWaitDown,['Not sucessesful! Retry ',hWaitStr]);
                try
                    textWeb = webread(downLink,downOptions);
                catch
                    waitbar(k/(lenPath+1),hWaitDown,['Not sucessesful! ',hWaitStr]);
                    flg = 0;
                end
            end
            if flg == 0
                continue;
            end     
            locImage = regexp(textWeb,'(?<=<img src=")\S+(?=" name="pathwayimage")','match');
            if isempty(locImage)
                continue;
            end
            pwyName2 = strrep(cpdInPwy{k,2},'/','_');
            pwyName2 = strrep(pwyName2,'\','_');
            pwyName2 = strrep(pwyName2,':','_');
            websave([savePath,'KeggMaps/',cpdInPwy{k,1},'_',pwyName2,'.png'],['http://www.kegg.jp',locImage{1}],downOptions);
        end
        waitbar(1,hWaitDown,'All pathways have been downloaded.');
    end

%% cpd analysis
    function cpdFun
        catDisplay = cell(8,1); catExport = cell(8,1);
        selectedID = get(pwyPanel,'UserData');
        for idxCat=1:8
            eval(['anno = anno_',sprintf('%d',idxCat),';']);
            U = unique(anno(:,4),'stable');
            countU = zeros(length(U),2); pvalU = -ones(length(U),1);
            M = size(anno,1); K = sum(ismember(anno(:,1),selectedID));
            typeU = cell(length(U),1);
            for idxSub=1:length(U)
                idxSubU = find(strcmp(U{idxSub},anno(:,4)));
                N = length(idxSubU); X = sum(ismember(anno(idxSubU,1),selectedID));
                countU(idxSub,1) = N; countU(idxSub,2) = X;
                if X/N > K/M
                    pvalU(idxSub) = hygepdf(X,M,K,N);
                    typeU{idxSub} = '        +';
                end
            end
            idxPvalU = find(pvalU>=0); 
            if ~isempty(idxPvalU)
                pvalU2 = mafdr(pvalU(idxPvalU),'BHFDR','true');
                [~,idxPvalU2] = sort(pvalU2,'ascend');
                groupName = annoNames{idxCat}(9:end);
                tempTable = cell(length(idxPvalU),5);
                tempTable(:,1) = U(idxPvalU(idxPvalU2));
                tempTable(:,2:3) = num2cell(countU(idxPvalU(idxPvalU2),:));
                tempTable(:,4) = typeU(idxPvalU(idxPvalU2));
                tempTable(:,5) = num2cell(pvalU2(idxPvalU2));
                tempTable = [groupName, {'Total Compound','Hit Compound','Type',...
                    'p-value'}; tempTable; cell(1,5)];
                catExport{idxCat} = tempTable(1:end-1,:);
                for iHead = 1:size(tempTable,2)
                    tempTable{1,iHead} =  ...
                        ['<HTML><p style="font-weight: bold; color: black;">',...
                        tempTable{1,iHead},'</p><HTML>'];
                end
                catDisplay{idxCat} = tempTable;
            end
        end
        % display
        catExpAll = []; catDispAll = []; 
        for idxCat=1:8
            catExpAll = [catExpAll; catExport{idxCat}];
            catDispAll = [catDispAll; catDisplay{idxCat}];
        end
        catTable = uitable('parent',pwyPanel,'Units','Normalized','RowName',...
            [],'Position',[.42 .01 .27 .90],'Data',catDispAll,'FontSize',9);
        set(hExport,'UserData',catExpAll);
    end
end






