function COVAIN_dataEvaluation(obj,evt)
%

% get data
h1 = get(obj,'Parent'); % hPanel_dataInfo
h2 = get(h1,'Parent');  % hMain
dataStruct = guidata(h2);
if dataStruct.loadNumber == 0
    return;
end
currentData = dataStruct.dataset(dataStruct.current).dataInfo;
% check if missing values have been filled
if currentData.stateMiss == 1
    warndlg('Please fill missing values first!');
	return;
end

% initialization
evaOpt = currentData.evaOpt;

% layout
% pop up a new GUI window
figLoc = [100 50 1000 700]; 
figEva = figure('Position',figLoc,...
                'Name','Data Evaluation',...
                'Resize','on',...
                'NumberTitle','off',...
                'MenuBar','none',...
                'Tag','evaFig');
% Top half panel
panRep = uipanel('Parent',figEva,...
                 'Position',[.01 .5 .98 .45],...
                 'Title',' Replicates report ',...
                 'FontSize',12,...
                 'Tag','evaPan');
textRep = uicontrol('Parent',panRep,...
                    'Style','text',...
                    'String','Remove replicate ',...
                    'Units','normalized',...
                    'Position',[.75 .70 .20 .20],...
                    'Max',1,'Min',0,...
                    'FontSize',11,...
                    'Tag','repText',...
                    'Enable','off');
editRep = uicontrol('Parent',panRep,...
                    'Style','edit',...
                    'String','',...
                    'Units','normalized',...
                    'Position',[.80 .60 .15 .15],...
                    'FontSize',11,...
                    'Max',1,'Min',0,...
                    'Tag','repEdit',...
                    'Enable','off');
editOK = uicontrol('Parent',panRep,'Style','pushbutton',...
                   'String','OK','Units','normalized','Userdata',0,...
                   'Position',[.85 .35 .10 .15],'Tag','editButton',...
                   'FontSize',11,'Enable','off','CallBack',@editBox);    
           
               
% Bottom half panel
panVar = uipanel('Parent',figEva,...
                 'Position',[.01 .01 .98 .45],...
                 'Title',' Variables Selection ',...
                 'FontSize',12,'Tag','varPan'); 


% The middle parts
locBottom = .25; wid = .1;
hText = zeros(4,1); hList1 = zeros(3,1); hList2 = zeros(3,1);
hPerc = zeros(3,1); hAnd = zeros(3,1); 
for iText=1:4
    hText(iText) = uicontrol('Parent',panVar,'Units','normalized',...
       'Position',[.4+(iText-1)*wid, locBottom + 3*.2, .8*wid, .12],...
       'Style','text','String',evaOpt.head{iText},'FontSize',11,...
       'Max',1,'Min',0,'Tag',['hText_',num2str(iText)]);
end 
for iList = 1:3
    hList1(iList) = uicontrol('Parent',panVar,'Units','normalized',...
        'Position',[.4, locBottom + (3-iList)*.2-.02, .8*wid, .12],...
        'Style','popupmenu','String',evaOpt.chooseName,...
        'Value',evaOpt.chooseValue(iList),'FontSize',11,...
        'Tag',['hList1_',num2str(iList)]);
    hPerc(iList) = uicontrol('Parent',panVar,'Units','normalized',...
        'Position',[.4+wid, locBottom + (3-iList)*.2, .8*wid, .1],...
        'Style','edit','String',evaOpt.perc{iList},'FontSize',10.5,...
        'Tag',['hPerc_',num2str(iList)]);
    hAnd(iList) = uicontrol('Parent',panVar,'Units','normalized',...
        'Position',[.4+2*wid+.02, locBottom + (3-iList)*.2+.02, .8*wid, .10],...
        'Style','checkbox','String',evaOpt.andName{iList},...
        'Value', evaOpt.andValue(iList),'FontSize',10.5,...
        'ForegroundColor',evaOpt.colors{iList},'FontSize',11,...
        'Tag',['hAnd_',num2str(iList)]);
    hList2(iList) = uicontrol('Parent',panVar,'Units','normalized',...
        'Position',[.4+3*wid, locBottom + (3-iList)*.2-.02, .9*wid, .12],...
        'Style','popupmenu','String',evaOpt.condName,...
        'Value',evaOpt.condValue(iList),'FontSize',10.5,...
        'Tag',['hList2_',num2str(iList)]);
end
set(hList2(3),'String',[{'All others'},evaOpt.condName(2:end)]);
hContrText = uicontrol('Parent',panVar,'Units','normalized',...
        'Position',[.4+2*wid+.02, locBottom - .1, .9*wid .09],...
        'Style','text','String','Relative to','FontSize',10.5,...
        'Max',1,'Min',0,'Tag','hContr_Text');
hContrList = uicontrol('Parent',panVar,'Units','normalized',...
        'Position',[.4+2*wid+.02, locBottom - .2, .9*wid .09],...
        'Style','popupmenu','String',evaOpt.condName(2:end),'FontSize',10.5,...
        'Value',evaOpt.contrValue,'Tag','hContr_List');

% The Right figure (venn)
% Use a modified vennX.m to plot venn diagram. The original file link is:
% http://www.mathworks.com/matlabcentral/fileexchange/6116


% The Bottom buttons
hView = uicontrol('Parent',panVar,'Units','normalized',...
                  'Position',[.78 .05 .08 .1],'Style','pushbutton',...
                  'String','View','FontSize',11,'Tag','viewButton',...
                  'CallBack',@viewButton);
             
hAccept = uicontrol('Parent',panVar,'Units','normalized',...
                  'Position',[.9 .05 .08 .1],'Style','pushbutton',...
                  'String','Accept','FontSize',11,'Tag','acceptButton',...
                  'CallBack',@viewButton,'Userdata',0);
              
plotRep;   
plotVar;  % may need to get figures handle -----------
    
%  ================   nested functions start  ==============    

    function plotRep
        flagNewVar = get(hAccept,'Userdata');
        if flagNewVar == 1
            dataStructNew = guidata(h2);
            currentDataNew = dataStructNew.dataset(dataStruct.current).dataInfo;
        else
            currentDataNew = currentData;
        end
        count = currentDataNew.count; 
        ind1 = currentDataNew.ind1;
        data = currentDataNew.data; 
        count(count>min(count)) = min(count); % if count number is not equal
        nRep = count(1);
        nCond = length(count);
        idx = zeros(1,sum(count));
        for i=1:nCond
            idx((i-1)*nRep+1:i*nRep) = ind1(i):ind1(i)+nRep-1;
        end
        data = data(:,idx); % maybe not original data, only for replicates evaluation
        % if nRep <= 2
        if nRep <= 2
            flgEmpty = 1;
        else
            flgEmpty = 0;
        end
        % replicates correlation coefficient image
        if ~flgEmpty
            ccRep = zeros(nCond,nRep*(nRep-1)/2);
            for i=1:nCond
                if i==1
                    t = corr(data(:,(i-1)*nRep+1:i*nRep));
                    t = tril(t) - eye(nRep);
                    [locx,locy] = ind2sub([nRep nRep],find(t(:)~=0));
                end
                t = corr(data(:,(i-1)*nRep+1:i*nRep));
                t = tril(t) - eye(nRep);
                ccRep(i,:) = (t(t~=0))';
            end
            xStr = cell(1,length(locx));
            for i=1:length(locx)
                xStr{i} = ['R ',num2str(locy(i)),' vs ',num2str(locx(i))];
            end
            % a "sub-panel"
            axes('Parent',panRep,'Position',[.11  .11  .6  .8]);
            imagesc(ccRep);colormap(jet);colorbar;
            set(gca,'YTick',1:nCond,'YTickLabel',currentDataNew.cond);
            set(gca,'XTick',1:length(locx));
            text(get(gca,'XTick'),repmat(nCond+.7,length(locx),1),xStr,'rotation',30,...
                'HorizontalAlignment','right','FontName','Helvetica','FontSize',100/nRep);
            set(gca,'XTick',[],'XTickLabel',[]); % nCond = max(yTick)
        end
        % select replicates
        if ~flgEmpty
            set(textRep,'Enable','on');
            set(editRep,'Enable','on');
            set(editOK,'Enable','on');
        end
    end

% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++        

    function plotVar
        flagNewRep = get(editOK,'Userdata');
        if flagNewRep == 1
            dataStructNew = guidata(h2);
            currentDataNew = dataStructNew.dataset(dataStruct.current).dataInfo;
        else
            currentDataNew = currentData;
        end
        ctNew = currentDataNew.count;
        ncondNew = length(ctNew);
        condNew = currentDataNew.cond;
        meanNew = currentDataNew.table;
        snrNew = currentDataNew.snr;
        % up
        axes('Parent',panVar,'Position',[.05 .6 .33 .35]);
        snrLevel4 = zeros(4,ncondNew);
        label4 = {'r-o','g-o','b-o','k-o'};
        for iLevel = 1:4
            snrLevel4(iLevel,:) = prctile(snrNew,(100-iLevel*20));
            plot(1:ncondNew,snrLevel4(iLevel,:),label4{iLevel});hold on;
        end
        legend('top 20%','top 40%','top 60%','top 80%'); hold off;
        ylabel('Signal-to-noise ratio','FontSize',10);
        set(gca,'XTick',1:ncondNew); yTickMin = min(get(gca,'YTick'));
        text(get(gca,'XTick'),repmat(yTickMin,ncondNew,1),condNew,'rotation',60,...
            'HorizontalAlignment','right','FontName','Arial','FontSize',8);
        set(gca,'XTick',[],'XTickLabel',[]);
        % down
        axes('Parent',panVar,'Position',[.05 .03 .33 .35]);
        meanLevel4 = zeros(4,ncondNew);
        for iLevel = 1:4
            meanLevel4(iLevel,:) = prctile(meanNew,(100-iLevel*20));
            plot(1:ncondNew,meanLevel4(iLevel,:),label4{iLevel});hold on;
        end
        if abs(max(meanLevel4(:))/min(meanLevel4(:))) >= 20
            set(gca,'YScale','log');
        end
        legend('top 20%','top 40%','top 60%','top 80%'); hold off;
        ylabel('Level (concentration)','FontSize',10);
        set(gca,'XTick',[],'XTickLabel',[]);
    end
    
% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

    function [newOpt,warnState] = scanStatus
        newOpt = evaOpt;
        percValue = zeros(1,3);
        andValue = zeros(1,3);
        warnState = ones(1,5);
        for k=1:3
            % percentage
            percValue(k) = str2double(get(hPerc(k),'String'));
            if isempty(percValue(k))
                set(hPerc(k),'String',evaOpt.perc(k));
            elseif length(percValue(k)) > 1
                set(hPerc(k),'String',evaOpt.perc(k));
            elseif percValue(k) > 100 || percValue(k) <= 0
                set(hPerc(k),'String',evaOpt.perc(k));
            else
                warnState(k) = 0;
            end
            % and state
            andValue(k) = get(hAnd(k),'Value'); % double    
        end
        % change option: control condition
        whichContr = get(hContrList,'Value');
        % change option: treat conditions
        whichTreat = get(hList2(3),'Value');
        % check and state
        if all(andValue == 0)
            hWarnAll = warndlg('At least one rule has to be applied!');
            uiwait(hWarnAll);
            uicontrol(hAnd(1));
        else
            warnState(4) = 0;
        end
        % check control and treatment
        if whichTreat - whichContr == 1
            hWarnContr = warndlg('Control and Treatment can not be the same!');
            uiwait(hWarnContr);
            uicontrol(hList2(3));
        else
            warnState(5) = 0;
        end
        % check if to proceed
        if all(warnState==0)  % no warnings
            % update these newOpt
            newOpt.perc = num2cell(percValue);
            newOpt.andValue = andValue;
            newOpt.contrValue = whichContr;
            % update the other newOpt 
            for k=1:3
                newOpt.chooseValue(k) = get(hList1(k),'Value');
                newOpt.condValue(k) = get(hList2(k),'Value');
            end
        end
    end
        
% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

    function idxC = chooseData(dataX,ruleX,threshX) 
        % dataX: vector or matrix, can be mean, snr, diff data ...
        % ruleX: top, bottom, middle
        % threshX: threshold value
        % idxC is a column vector
        if ischar(threshX)
            threshX = str2num(threshX);
        end
        threshHigh = prctile(dataX,100-threshX);
        threshLow  = prctile(dataX,threshX);
        threshMidH = prctile(dataX,100-threshX/2);
        threshMidL = prctile(dataX,threshX/2);
        switch ruleX
            case 1     % top
               % idxC = find(dataX >= threshHigh);
               dataC = dataX - repmat(threshHigh,size(dataX,1),1);
               idxC  = find(all(dataC >= 0, 2)==1); 
            case 2     % bottom
                % idxC = find(dataX < threshLow);
               dataC = dataX - repmat(threshLow,size(dataX,1),1);
               idxC  = find(all(dataC < 0, 2)==1); 
            case 3     % middle
                % idxC = find(dataX >= threshMidL && dataX < threshMidH);
                dataC1 = dataX - repmat(threshMidL,size(dataX,1),1);
                dataC2 = dataX - repmat(threshMidH,size(dataX,1),1);
                idxC = find(all(dataC1>=0,2)==1 & all(dataC2<=0,2)==1);
        end
    end
        
% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

    function viewButton(objS,evtS)
        % either default or input, NOT empty
        [inputOpt,inputWarn] = scanStatus;
        flagUpdate = all(inputWarn==0); % 1: yes, 0: no
        % get data first
        meanValueZ = currentData.table;
        snrZ = currentData.snr;
        ncondZ = length(currentData.count);
        data0 = currentData.data;
        % get rawFileName from guidata
        current = dataStruct.current;
        rawFileName = dataStruct.ID{current};
        rawFileName = rawFileName(findstr('--',rawFileName)+2:end);
        rawFileName = [rawFileName,'-Filtered'];
        % get others from guidata
        sampleName = currentData.sampleName;
        subsName = currentData.subs;
        
        % recover original sample names
        for iSp = 1:size(data0,2)
            locRepStr = findstr(' -rep',sampleName{iSp});
            sampleName{iSp} = sampleName{iSp}(1:locRepStr-1);
        end
        
        % get index from each rule one by one
        % No.1
        if inputOpt.andValue(1) == 0
            idxZ1 = [];
        else
            idxCond = inputOpt.condValue(1);
            if idxCond == 1
                idxCond = 1:ncondZ;
            else
                idxCond = idxCond - 1;
            end
            idxZ1 = chooseData(snrZ(:,idxCond),inputOpt.chooseValue(1),inputOpt.perc{1});
        end
        % No.2
        if inputOpt.andValue(2) == 0
            idxZ2 = [];
        else
            idxCond = inputOpt.condValue(2);
            if idxCond == 1
                idxCond = 1:ncondZ;
            else
                idxCond = idxCond - 1;
            end
            idxZ2 = chooseData(meanValueZ(:,idxCond),inputOpt.chooseValue(2),inputOpt.perc{2});
        end
        % No.3
        if inputOpt.andValue(3) == 0
            idxZ3 = [];
        else
            idxCond1 = inputOpt.contrValue;
            idxCond2 = inputOpt.condValue(3);
            if idxCond2 == 1
                idxCond2 = setdiff(1:ncondZ,idxCond1);
                dataDiff = meanValueZ(:,idxCond2) - repmat(meanValueZ(:,idxCond1),1,ncondZ-1);
            else
                idxCond2 = idxCond2 - 1;
                dataDiff = meanValueZ(:,idxCond2) - meanValueZ(:,idxCond1);
            end
            idxZ3 = chooseData(dataDiff,inputOpt.chooseValue(3),inputOpt.perc{3});
        end
         
        % calculate the overlapping part between idxZ1, idxZ2 and idxZ3
        idxZ12 = intersect(idxZ1,idxZ2);
        idxZ13 = intersect(idxZ1,idxZ3);
        idxZ23 = intersect(idxZ2,idxZ3);
        idxZ123 = intersect(idxZ12,idxZ23);
        
        X1 = length(idxZ1); X2 = length(idxZ2); X3 = length(idxZ3);
        X12 = length(idxZ12); X13 = length(idxZ13);
        X23 = length(idxZ23); X123 = length(idxZ123);
        
        X1 = X1 - X12 - X13 + X123;
        X2 = X2 - X12 - X23 + X123;
        X3 = X3 - X13 - X23 + X123;
        
        X12 = X12 - X123;
        X13 = X13 - X123;
        X23 = X23 - X123; 
        
        % may need to get the colors of circles 
        % then set the text "BackgroundColor" -----------
        if strcmp(get(objS,'Tag'),'viewButton')       % View Button
            % shows the venn plot, need some cleaning --------
            axes('Parent',panVar,'Position',[.82, locBottom, .16, .6]);
            axis off;
            if X1 > 0 && X2 > 0 && X3 > 0
                figure;
                [hVenn,tVenn] = vennXm([X1,X12,X2,X23,X3,X13,X123],0.1);   
                axis off;
            elseif X1 > 0 && X2 > 0 && X3 == 0
                [hVenn,tVenn] = vennXm([X1,X12,X2],0.03); axis off;
            elseif X1 > 0 && X2 == 0 && X3 > 0
                [hVenn,tVenn] = vennXm([X1 X13 X3],0.03); axis off;
            elseif X1 == 0 && X2 > 0 && X3 > 0
                [hVenn,tVenn] = vennXm([X2 X23 X3],0.03); axis off;
            else
                imagesc([1 1 1]);
                xValue = get(gca,'XTick');
                yValue = get(gca,'YTick');
                hVennText = text(0.4*mean(xValue),mean(yValue),'No overlapping part!','FontSize',12);
                axis off;
            end              
        else                                           % Accept Button
            if flagUpdate == 1
            % check if to update the guidata
                a = inputOpt.andValue;
                XX = [X1,X12,X2,X23,X3,X13,X123];
                YY = zeros(1,7); YY([1 3 5]) = a;
                YY(2) = and(a(1),a(2)); YY(4) = and(a(2),a(3));
                YY(6) = and(a(1),a(3)); YY(7) = and(a(1),YY(4));
                if any(xor(XX,YY))  % do not update data
                    hWarnZ = warndlg('No data satisfies all rules. Do nothing!');
                    uiwait(hWarnZ);
                else              % update the guidata
                    if X123 > 0
                        dataZ = data0(idxZ123,:);
                        idxZZ = idxZ123;
                    else          % ----------
                        if X12 > 0
                            dataZ = data0(idxZ12,:);
                            idxZZ = idxZ12;
                        elseif X13 > 0
                            dataZ = data0(idxZ13,:);
                            idxZZ = idxZ13;
                        elseif X23 > 0
                            dataZ = data0(idxZ23,:);
                            idxZZ = idxZ23;
                        elseif X1 > 0
                            dataZ = data0(idxZ1,:);
                            idxZZ = idxZ1;
                        elseif X2 > 0
                            dataZ = data0(idxZ2,:);
                            idxZZ = idxZ2;
                        end
                    end
                    % formulate a new dataset as cell format
                    dataRaw = cell(size(dataZ)+1);
                    dataRaw(1,2:end) = sampleName;
                    dataRaw(2:size(dataRaw,1)) = subsName(idxZZ);
                    dataRaw{1} = 'CPD';
                    dataRaw(2:end,2:end) = num2cell(dataZ);
                    % OK, update the guidata
                    try
                        COVAIN_loadIntData(dataRaw,rawFileName,h2);
                        set(hAccept,'userdata',1);
                    catch err
                        hWarn2_Text = err.message;
                        hWarn2 = warndlg(hWarn2_Text);
                        uiwait(hWarn2);
                    end
                end  % check warning state
            end % update data end
        end % if to view or update           
    end % this nested function end

% +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++        

    function editBox(objS,evtS)
        % get the handle of the edit text
        objEdit = findobj(get(objS,'Parent'),'Tag','repEdit');
        idxEdit = str2num(get(objEdit,'String')); % must use "str2num", maybe a row vector
        count = currentData.count;  count0 = count;
        data = currentData.data;  data0 = data;
        count(count>min(count)) = min(count); % if count number is not equal
        nRep = count(1);
        idx = zeros(1,sum(count));
        if ~isempty(idxEdit)
            if max(idxEdit) > nRep || min(idxEdit) <= 0 || ...
                    max(idxEdit) - min(idxEdit) == length(idxEdit)
                hWarn = errordlg('Invalid input!');
                uiwait(hWarn);
                uicontrol(objEdit);
            else % add as a new data
                idxEdit = sort(idxEdit);
                idxCut = idxEdit(1):nRep:length(idx);
                for iCut = 2:length(idxEdit)
                    idxCut = [idxCut,idxEdit(iCut):nRep:length(idx)];
                end
                idxNew = setdiff(1:sum(count0),idxCut); % sorted indices
                % recover original sample names
                sampleNameNew = currentData.sampleName(idxNew);
                for iN = 1:length(idxNew)
                    locRepStr = findstr(' -rep',sampleNameNew{iN});
                    sampleNameNew{iN} = sampleNameNew{iN}(1:locRepStr-1);
                end
                % name the new dataset
                rawFileNameAppend = '-Remove-';
                for iA = 1:length(idxEdit)
                    rawFileNameAppend = [rawFileNameAppend,'Rep',num2str(idxEdit(iA)),'_'];
                end
                rawFileNameAppend(end) = []; % remove last "_"
                current = dataStruct.current;
                % get rawFileName from guidata
                rawFileName = dataStruct.ID{current};
                rawFileName = rawFileName(findstr('--',rawFileName)+2:end);
                rawFileName = [rawFileName,rawFileNameAppend];
                % formulate a new dataset as cell format
                dataRaw = cell(size(data,1)+1,length(idxNew)+1);
                dataRaw(1,2:end) = sampleNameNew;
                dataRaw(2:size(dataRaw,1)) = currentData.subs;
                dataRaw{1} = 'CPD';
                dataRaw(2:end,2:end) = num2cell(data0(:,idxNew));               
                % OK, update the guidata
                try
                    COVAIN_loadIntData(dataRaw,rawFileName,h2); 
                    set(editOK,'Userdata',1);
                    set(editOK,'BackGroundColor',[1 0 1]);
                catch err
                    hWarn2_Text = err.message;
                    hWarn2 = warndlg(hWarn2_Text);
                    uiwait(hWarn2);
                end
            end
        end
    end % end of nexted function editBox


% ================   nested functions end  ==============
end
                
                
          




