function dataSumma = COVAIN_dataSummary(dataInput,dataInputNames,preprocessLabel)
% pure calculation, no relation with GUI component handles
%

%dataInput

status_g = 1;

switch preprocessLabel
    case 'trans'
        dataInput = dataInput';
        dataInputNames = dataInputNames';
end

[dataRaw_row,dataRaw_col] = size(dataInput);

if size(dataInputNames,2)==1
    warndlg('All condition names missing. COVAIN will automatically name them!');
    dataInputNames = [' ';dataInputNames];
    dataNames_obs = cell(1,dataRaw_col);
    for i=1:dataRaw_col
        dataNames_obs{i} = ['Special Condition ',num2str(i)];
    end
elseif any(strcmp(' ',dataInputNames(1,2:dataRaw_col+1)))
    warndlg('Some condition names missing. COVAIN will automatically name them!');
    locEmpty = find(strcmp(' ',dataInputNames(1,2:dataRaw_col+1))==1);
    dataNames_obs = dataInputNames(1,2:dataRaw_col+1);
    for i=1:length(locEmpty)
        dataNames_obs{locEmpty(i)} = ['Special Condition ',num2str(i)];
    end
elseif size(dataInputNames,1)==1
    warndlg('All substance names missing. COVAIN will automatically name them!');
    dataInputNames = [' ',dataInputNames];
    dataNames_subs = cell(1,dataRaw_row);
    for i=1:dataRaw_row
        dataNames_subs{i} = ['Special Substance ',num2str(i)];
    end
elseif any(strcmp(' ',dataInputNames(2:dataRaw_row+1,1)))
    warndlg('Substance names missing. COVAIN will automatically name them!');
    locEmpty = find(strcmp(' ',dataInputNames(2:dataRaw_row+1,1))==1);
    dataNames_subs = dataInputNames(2:dataRaw_row+1,1);
    for i=1:length(locEmpty)
        dataNames_subs{locEmpty(i)} = ['Special Substance ',num2str(i)];
    end
end
if exist('dataNames_obs') ~= 1
    dataNames_obs = dataInputNames(1,2:dataRaw_col+1);  % columns are observations
end
if exist('dataNames_subs') ~= 1
    dataNames_subs = dataInputNames(2:dataRaw_row+1,1); % rows are substances
end

% === a small update ===
% Warning @ Mar.21,2011: if cond is not arranged continuously, e.g.,
% A, A, B, B, A, A ...the old codes(released on Mar.6, 2011) are wrong!
% Fix it:
% Method 1: Using Dichotomy to detect the "unorderly ones"
% Method 2: Sort the names: faster and clearer
% Follow-up: should use "sort" as an option!!!
% Correspond to unique(dataNames_obs...) 
% +++++
% if isnumeric(dataNames_obs{1})  % assume all names have the same format ---
%     [numNames,idx_obs] = sort(cell2mat(dataNames_obs));
%     dataNames_obs = num2cell(numNames); 
% else
%     [dataNames_obs,idx_obs] = sort(dataNames_obs);
% end
% [waste,indexCond1] = unique(dataNames_obs,'first');
% [condNames,indexCond2] = unique(dataNames_obs,'last');
% dataInput = dataInput(:,idx_obs);
% ++++++
% NEW update 2012m
% if names are all numbers; letter + numbers, other names
% names cannot start with numbers?
if all(cellfun(@(x) ~isnan(str2double(x)), dataNames_obs)==1)
    lenx = length(dataNames_obs);
    namex = zeros(1,lenx);
    for i=1:lenx
        namex(i) = str2double(dataNames_obs{i});
    end
    [numNames,idx_obs] = sort(namex);
    dataInput = dataInput(:,idx_obs);
    for i=1:lenx
        dataNames_obs{i} = num2str(numNames(i));
    end
    
    [waste,indexCond1] = unique(numNames,'first');
    [waste,indexCond2] = unique(numNames,'last');
    condNames = dataNames_obs(indexCond2); 

elseif all(cellfun(@(x) ~isempty(regexp(x,'[0-9]','once')), dataNames_obs)==1)     
    lenx = length(dataNames_obs);
    prefix = cell(lenx,1); % letters
    suffix = cell(lenx,1); % letters
    namex = zeros(lenx,1); % numbers
    for i=1:lenx
        locx = regexp(dataNames_obs{i},'[0-9]');
        if locx(1) > 1
            prefix{i} = dataNames_obs{i}(1:locx(1)-1);
            while strcmp(prefix{i}(end),' ') == 1 % remove blanks
                prefix{i}(end) = [];
            end
        else
            prefix{i} = ' ';
        end
        % use loc(1):loc(end) instead of loc(1:end) to avoid missing dots
        namex(i) = str2double(dataNames_obs{i}(locx(1):locx(end)));
        if locx(end) < length(dataNames_obs{i})
            suffix{i} = dataNames_obs{i}(locx(end)+1:end);
            while strcmp(suffix{i}(end),' ') == 1 % remove blanks
                suffix{i}(end) = [];
            end
        else
            suffix{i} = ' '; % uniform suffix
        end
    end
    % firstly, sort prefix and numbers
    [waste1,waste2,idx1] = unique(prefix);
    [waste1,waste2,idx2] = unique(namex);
    [waste1,waste2,idx3] = unique(suffix);
    
    % secondly, calculate weighted index
    % remind user to select weights -- undone
    idx123 = 10^(ceil(log10(lenx))) * idx1 + idx3 + idx2/(10^(ceil(log10(lenx))));
    
    % finally, sort idx12
    [idx123s,idx_obs] = sort(idx123);
    dataInput = dataInput(:,idx_obs);
    dataNames_obs = dataNames_obs(idx_obs);
    
    [waste,indexCond1] = unique(idx123s,'first');
    [waste,indexCond2] = unique(idx123s,'last');
    condNames = dataNames_obs(indexCond2);
    
else
    [dataNames_obs,idx_obs] = sort(dataNames_obs);
    [waste,indexCond1] = unique(dataNames_obs,'first');
    [condNames,indexCond2] = unique(dataNames_obs,'last');
    dataInput = dataInput(:,idx_obs);
end
% ++++++    


countCond = indexCond2 - indexCond1 + 1;
data_lengthCond = length(indexCond1);


% check if the data matrix contains full non-numeric data or full zero data
nanCol = sum(isnan(dataInput));   % row vector
nanRow = sum(isnan(dataInput),2); % col vector
zeroCol = sum(dataInput == 0);    % row vector
zeroRow = sum(dataInput == 0,2);  % col vector

% if only one replicate for some condition
if min(countCond) < 2
    status_g = 0;
end

% if only one condition, no analysis
if any(countCond == 1)
    status_g = -1;
end

% ++++++++++  New update +++++++++++++
% if too many non-numeric data or zeros (larger than half), do not analyse
if (sum(nanCol) >= 1.5*dataRaw_row*dataRaw_col) || (sum(zeroCol) >= ...
        1.5*dataRaw_row*dataRaw_col)
    warndlg('Your data contains too many non-numeric data or zeros! No analysis will be done!');
    status_g = -2;
end

% add fresh weight identification "Fresh Weight", using strcmpi
locFreshWeight = find(strcmpi('Fresh Weight',dataNames_subs)==1);
if ~isempty(locFreshWeight)
    dataSumma.freshOK = 1; 
    dataSumma.freshValue = dataInput(locFreshWeight,1:end);  
    dataInput(locFreshWeight,:) = [];
    dataRaw_row = dataRaw_row - 1;
    dataNames_subs(locFreshWeight) = [];
else
    dataSumma.freshOK = 0;
    dataSumma.freshValue = ones(1,dataRaw_col);
end

% data mapping, @COVAIN_dataMapping, seems no use if the 4th para is not set
dataInput(isnan(dataInput(:))) = 0;  % set NaN values as zeroes
[dataRawNew,indexNew,countNew] = COVAIN_dataMapping(dataInput,indexCond1,countCond);


% Full table data
% 1. replicate marker
% Note: in the future, a naming system must be established, such as:
%       condName_repName, using "_" as the seperator.
%       Currently, I name the replicates as "rep1,rep2,rep3,..."

sampleName = cell(1,dataRaw_col);
for i=1:data_lengthCond
    if countNew(i) == 1
        sampleName{indexNew(i)} = condNames{i};
    else
        for j=1:countNew(i)
            sampleName{indexNew(i)+j-1} = ...
                strcat(condNames{i},' - ','rep_',num2str(j));
        end
    end
end

% 2. full table
% fullTable = dataRawNew


% generate mean table data and snr as a strcture
tableData = zeros(dataRaw_row,data_lengthCond);
snr = tableData;
for i=1:dataRaw_row
    for j=1:data_lengthCond
        tableData(i,j) = mean(dataRawNew(i,indexNew(j):indexNew(j)...
            +countNew(j)-1));
        stdTemp = std(dataRawNew(i,indexNew(j):indexNew(j)+countNew(j)-1));
        snr(i,j) = tableData(i,j)/stdTemp;
    end
end

% initializing the currentData
% data evaluation option as structures
evaOpt.head = {'Choose','Percentage (%)','AND','Conditions'};
evaOpt.chooseName = {'Top','Bottom','Middle'};
evaOpt.chooseValue = [ 1 1 1];
evaOpt.perc = {'50','50','50'};
evaOpt.andName  = {'SNR','Level','Change'};
evaOpt.andValue = [1 1 0];
evaOpt.colors = {'b','c','g'}; % blue, cyan, green
evaOpt.condName = [{'All'},condNames];
evaOpt.condValue = [ 1 1 1];
evaOpt.contrValue = 1;

% options in the side bar
options.corr = 'Pearson';
options.corrThresh = 0.50;
options.log = 'Log10';
options.fillMissing = 'minimal';
options.granger = 1;
options.grangerP = 0.1;
options.cluster = 4;
options.sigma = 1;
options.noiseType = 'Same';
options.revMethod = 'TLS'; % RevJac Method(TLS or Ridge)
options.shrinkage = 0.2;   % ridge regression shrinkage coefficient

% other items
dataSumma.nRow = dataRaw_row;
dataSumma.nCol = dataRaw_col;
dataSumma.subs = dataNames_subs;
dataSumma.cond = condNames;
dataSumma.condStat = dataSumma.cond;
dataSumma.next = status_g;
dataSumma.data = (status_g > -2)*dataRawNew + (status_g == -2)*dataInput;
dataSumma.oldData = dataSumma.data;
dataSumma.ind1  = indexNew;
dataSumma.count = countNew; % count of replicates in each condition
dataSumma.table = tableData;
dataSumma.tableOld = tableData;
dataSumma.snr = snr;
dataSumma.snrOld = snr;
dataSumma.sample = (status_g > -2)*dataRawNew + (status_g == -2)*dataInput;
dataSumma.sampleName = sampleName;
dataSumma.which = 1;
dataSumma.anovaTable = [];
dataSumma.stateTrans = 0;
dataSumma.dataTS_OK = 0;
dataSumma.corrTS = [];
dataSumma.corrTS_pval = [];
dataSumma.pcaLoading = [];
dataSumma.pcaScore = [];
dataSumma.pcaVariance = [];
dataSumma.icaLoading = [];
dataSumma.icaKurt = [];
dataSumma.icNumber = [];
dataSumma.dataStat_OK = 0;
dataSumma.dataStat_Input = 0;
dataSumma.corrStat = tableData;
dataSumma.corrStat_pval = [];
dataSumma.dataStat = tableData;
dataSumma.Granger_OK = 0;
dataSumma.PE = [];
dataSumma.Granger = [];
dataSumma.PCnumber = [];
dataSumma.SparseMatrix = [];
dataSumma.note = '';
dataSumma.whichTable = 2;
dataSumma.historyTrans = 0; % record the process history
dataSumma.historyMiss = 0;
dataSumma.historyOut = 0;
dataSumma.historyNorm = 0;
dataSumma.historyLog = 0;
dataSumma.historyZc = 0;
dataSumma.historyZr = 0;
dataSumma.history01 = 0;
dataSumma.historyFW = 0;
dataSumma.historyIS = 0;
dataSumma.idxSpl = idx_obs;
dataSumma.keggCPD = [];
dataSumma.options = options;
dataSumma.evaOpt = evaOpt;
dataSumma.stoi_OK = 0;
dataSumma.cov1_OK = 0;
dataSumma.cov2_OK = 0;
dataSumma.Jac = [];
dataSumma.Stoi = [];
dataSumma.isLarge = dataSumma.nRow >= 500;

% === temporal usage ! ===
dataSumma.glyData1 = [];
dataSumma.glyData2 = [];
dataSumma.glyCov1 = [];
dataSumma.glyCov2 = [];

if status_g > -2
    % identify missing values
    flag_miss = COVAIN_missValueReport(dataRawNew,indexNew,countNew);
    if max(size(flag_miss)) == 1
        missTotal = 0;
        missFlagState = 0;
    else
        %missTotal = sum(flag_miss(:));
        missTotal = sum(dataSumma.data(:)==0);
        missFlagState = 1;
    end
    
    % identify outlier values
    flag_outlier = COVAIN_outlierValueReport(dataRawNew,indexNew,countNew);
    if max(size(flag_outlier)) == 1
        outlierTotal = 0;
        outlierFlagState = 0;
    else
        outlierTotal = sum(sum(flag_outlier,2));
        outlierFlagState = 1;
    end
    
    
    % display information in the dataInfo panel
    text_dataInfo = ['Your data contains ',...
        num2str(dataRaw_row),...
        ' substances, ',...
        num2str(dataRaw_col),...
        ' samples, and ',...
        num2str(data_lengthCond),...
        ' conditions'];
    
    
    text_dataMissing = ['There are ',num2str(missTotal),' missing values across all samples.'];    
    text_dataOutlier = ['There are ',num2str(outlierTotal),' outlier values across all samples.'];
    
    
    % initializing the currentData    
    dataSumma.textInfo = text_dataInfo;
    dataSumma.textMiss = text_dataMissing;
    dataSumma.textMissOld = text_dataMissing;
    dataSumma.textOut = text_dataOutlier;
    dataSumma.textOutOld = text_dataOutlier;
    dataSumma.stateMiss = missFlagState;
    dataSumma.matrixMiss = flag_miss;
    dataSumma.stateOutlier = outlierFlagState;
    dataSumma.stateOutlierOld = outlierFlagState;
    dataSumma.stateMissOld = missFlagState;
    dataSumma.matrixOutlier = flag_outlier;
    
end


% ************** Nested Functions **********************************

% nested function: missing vaue report
% do not need to access graphic handles!
    function flag_miss = COVAIN_missValueReport(dataOld,ind,ct)
        if isempty(dataOld)
            errordlg('empty data. only for debugging');
        end
        flag_miss = zeros(size(dataOld,1),length(ind));
        for jMiss=1:length(ind)
            dataBlock = dataOld(:,ind(jMiss):ind(jMiss)+ct(jMiss)-1);
            for iMiss=1:size(dataBlock,1)
                if any(dataBlock(iMiss,:)==0)
                    flag_miss(iMiss,jMiss) = 1;
                end
            end
        end
        if all(flag_miss(:)==0)
            flag_miss = 0;
        end
    end  % now flag_miss is a matrix


% nested function: missing vaue report
% do not need to access graphic handles!
    function flag_outlier = COVAIN_outlierValueReport(dataOld,ind,ct)
        flag_outlier = zeros(size(dataOld,1),length(ind));
        for jOut = 1:length(ind)
            dataOldBlock = dataOld(:,ind(jOut):ind(jOut)+ct(jOut)-1);
            for iOut=1:size(dataOld,1)
                dataRow = dataOldBlock(iOut,:);
                mean_dataRow = mean(dataRow);
                std_dataRow = std(dataRow);
                indexOutlier = find(dataRow > mean_dataRow + ...
                    2*std_dataRow | dataRow < mean_dataRow -2*std_dataRow);
                flag_outlier(iOut,jOut) = ~isempty(indexOutlier);
            end
        end
        if all(flag_outlier(:)==0)
            flag_outlier = 0;
        end
    end

% ************** Nested functions complete *************************

end
