function COVAIN_dataTranspose(obj,evt)
%
% can transpose back and forth

h1 = get(obj,'Parent'); % hPanel_dataInfo
hTop = get(h1,'Parent');  % hMain

dataStruct = guidata(hTop);
if dataStruct.loadNumber == 0
    return;
end
currentData = dataStruct.dataset(dataStruct.current).dataInfo;
path1 = currentData.savePath;
path2 = currentData.openPath;
color_default = get(findobj(hTop,'Tag','button_load'),'BackgroundColor');
color_new = [1 0 1];

if currentData.historyTrans == 1
    repeat = 1;
else
    repeat = 0;
end

ct = currentData.count;
dataRaw = currentData.data;
dataInputNames = cell(size(currentData.data')+1);
dataInputNames(1,:) = ['s',currentData.subs'];
for i = 1:length(ct)
    if i==1
        dataInputNames(2:ct(1)+1,1) = repmat(currentData.cond(1),ct(1),1);
    else
        loc = sum(ct(1:i-1)) + 1;
        dataInputNames(loc+1 : loc + ct(i),1) = repmat(currentData.cond(i),ct(i),1);
    end
end
dataInputNames = dataInputNames'; 
currentData = COVAIN_dataSummary(dataRaw,dataInputNames,'trans');
% highlight the Transpose button
if repeat==0
    currentData.historyTrans = 1;
    set(obj,'BackgroundColor',color_new);
else
    currentData.historyTrans = 0;
    set(obj,'BackgroundColor',color_default);
end
% update guidata
currentData.savePath = path1;
currentData.openPath = path2;
dataStruct.dataset(dataStruct.current).dataInfo = currentData;
guidata(hTop,dataStruct);

% display data information
infoStr = currentData.textInfo;
infoStr = strcat('COVAIN assumes rows are substances and columns are samples. ',infoStr);
missStr = currentData.textMiss;
outStr  = currentData.textOut;


% update the data info
set(findobj(hTop,'Tag','text_info'),'String',infoStr,...
    'Enable','on');
set(findobj(hTop,'Tag','text_miss'),'String',missStr,...
    'Enable','on');
set(findobj(hTop,'Tag','text_outlier'),'String',outStr,...
    'Enable','on');

% update table preview
if currentData.whichTable == 1
    currentTable = currentData.sample;
    currentTableColName = currentData.sampleName;
    currentTableRowName = currentData.subs;
    set(findobj(hTop,'Tag','table_preview'),'Data',currentTable,...
        'ColumnName',currentTableColName,'RowName',currentTableRowName,...
        'Enable','on');
elseif currentData.whichTable == 2
    currentTable = currentData.table;
    currentTableColName = currentData.cond;
    currentTableRowName = currentData.subs;
    set(findobj(hTop,'Tag','table_preview'),'Data',currentTable,...
        'ColumnName',currentTableColName,'RowName',currentTableRowName,...
        'Enable','on');
elseif currentData.whichTable == 3
    currentTable = (currentData.sample)';
    currentTableColName = currentData.subs;
    currentTableRowName = currentData.sampleName;
    set(findobj(h2,'Tag','table_preview'),'Data',currentTable,...
        'ColumnName',currentTableColName,'RowName',currentTableRowName,...
        'Enable','on');
elseif currentData.whichTable == 4
    currentTable = (currentData.table)';
    currentTableColName = currentData.subs;
    currentTableRowName = currentData.cond;
    set(findobj(h2,'Tag','table_preview'),'Data',currentTable,...
        'ColumnName',currentTableColName,'RowName',currentTableRowName,...
        'Enable','on');
end

