function COVAIN_diffJac(obj,evt)

h1 = get(obj,'Parent'); % hPanel_Jacobian
h2 = get(h1,'Parent'); % hPanel_topo
h3 = get(h2,'Parent'); % hPanel_dataAnalysis
h4 = get(h3,'Parent'); % hPanel_Main

dataStruct = guidata(h4);
if dataStruct.loadNumber == 0
    return;
end
currentDataName = dataStruct.ID{dataStruct.current};
currentData = dataStruct.dataset(dataStruct.current).dataInfo;
if currentData.cov1_OK == 0 || currentData.cov2_OK == 0
    warndlg('Please load two datasets!');
elseif currentData.stoi_OK == 0
    warndlg('Please load the stoichiometric matrix!');
else
    cov1 = currentData.covInput1;
    cov2 = currentData.covInput2;
    stoiNew = currentData.StoiNew;
    method = currentData.options.revMethod;
    mName = currentData.mName;
    if strcmp(currentData.options.noiseType,'Same')
        sigma = repmat(currentData.options.sigma,currentData.nRow,1);
    else
        sigma = currentData.options.sigma*randn(currentData.nRow,1);
    end
    if strcmp(method,'Ridge')
        r = currentData.options.shrinkage;
    else
        r = 0;
    end
    if any(size(cov1) - size(cov2) ~= 0)
        error('The two covariances are not the same size!');
    elseif any(size(cov1) - size(stoiNew) ~= 0)
        errMsg = 'The stoichiometric matrix should have the same number of variables with that in the covariance!';
        error(errMsg);
    end
    jac1 = Cova2Jac(cov1,method,r);
    jac2 = Cova2Jac(cov2,method,r);
    
    figure('Name',['Differential Jacobian: ',currentDataName],'NumberTitle','off');
    imagescnan(log2(abs(jac2./jac1))); colorbar; colormap redbluecmap;
    title('Inverse Jacobian','FontSize',16);
    nRow = size(cov1,1); nameSub = mName; ftSize = 8;
    set(gca,'XTick',1:nRow,'XTickLabel',[]);
    set(gca,'YTick',1:nRow,'YTickLabel',nameSub');
    set(gca,'FontSize',ftSize);
    xTick = get(gca,'XTick');
    yTick = get(gca,'YTick');
    text(xTick,repmat(yTick(end)+.9,length(xTick),1),nameSub,...
        'HorizontalAlignment','right','rotation',30,'FontSize',ftSize+1,'FontName','Arial');
    
    currentData.Jac.jac1 = jac1;
    currentData.Jac.jac2 = jac2;
    dataStruct.dataset(dataStruct.current).dataInfo = currentData;
    guidata(h4,dataStruct);
end
% ------- nested function to calculate Jacobian from covariance ----
    function J = Cova2Jac(C,revMethod,rValue)
        % define the D matrix
        sigmaX = sigma;
        N = size(C,1);
        D = zeros(N);
        for iD = 1:N
            for jD = 1:N
                if iD == jD
                    D(iD,jD) = -0.5*(sigmaX(iD))^2;
                end
            end
        end
        
        %-------- forming left side of AX = B --------------
        Aleft = zeros(N^2);Aright = zeros(N^2);
        for i1=1:N
            Aleft((i1-1)*N+1:i1*N,(i1-1)*N+1:i1*N) = C';
        end
        for i1=1:N
            for j1=1:N
                Aright((i1-1)*N+j1,(j1-1)*N+1:j1*N) = C(i1,:);
            end
        end
        A = Aleft + Aright;

        % ------ vectorize D matrix ---------
        Dt = D'; % transpose D
        Dvec = Dt(:); % vectorized

        % ------ determine zero-entries in Jacobian -------
        indnotzero = stoiNew'~=0;  % notice it! -----
        A2 = A(:,indnotzero);
      
        % ---- solve the over-determined problem (Cov to Jac) ----
        if strcmp(revMethod,'TLS')
            [~,~,V] = svd([A2 Dvec],0);
            Jvec2 = -V(1:end-1,end)/V(end,end);
        else
            Jvec2 = inv((A2'*A2 + rValue*eye(size(A2,2))))*A2'*Dvec;
        end

        % ---- Finally transform the Jacobian vector to a matrix -----
        Jvec = zeros(N^2,1);
        Jvec(indnotzero) = Jvec2;
        J = zeros(N);
        for i2=1:N
            J(i2,:) = Jvec((i2-1)*N+1:i2*N);
        end
    end
% ------------ nested function ends -----------

end

