function COVAIN_help(helpObj,evt)
% show the help documentation
% helpObj is a handel


helpTitle = 'COVAIN Toolbox: general usage help';
helpText = [ ...
    '***************************************************************************'
    '                                                                           '
    'Note: this Help document has been replaced by Users Manual - Feb.12, 2014  '
    '                                                                           '
    '***************************************************************************'
    '                                                                           '
    'The Metabolomics Analysis Toolbox (COVAIN) is a compact data analysis tool.'
    'To start the toolbox, please input "COVAIN" in MATLAB command window.      '
    '                                                                           '
    '==== The main features are: =====                                          '
    '                                                                           '
    '1. Load data from EXCEL worksheets or text format files.                   '
    '                                                                           '
    '2. Display the data information, including:                                '
    '   1) number of susbtances (metabolites or others)                         '
    '   2) number of conditions                                                 '
    '   3) if there are missing values or outliers                              '
    '   4) previewing mean or full data in different conditions                 '
    '   5) box plot and error bar plot of all data in all conditions            '
    '                                                                           '
    '3. Pre-process the data:                                                   '
    '   1) transpose the data if the rows are NOT substances                    '
    '   2) fill the missing values                                              '
    '   3) adjust the outliers                                                  '
    '   4) transform the data by log 10 or log2 and z-score                     '
    '                                                                           '
    '4. Do three kinds of data analysis work                                    '
    '   1) Statistics                                                           '
    '      a. Correlation                                                       '
    '      b. Pincipal component analysis (PCA)                                 '
    '      c. Independent Component analysis (ICA)                              '
    '      d. Clustering control-treatment data                                 '
    '   2) Time-series analysis                                                 '
    '      a. Correlation                                                       '
    '      b. Clustering                                                        '
    '      c. Granger causality inferrence                                      '
    '      d. Permutation Entropy (PE)                                          '
    '   3) Network inference and topology analysis                              '
    '      a. Network inference by different methods                            '
    '      b. Network visualization                                             '
    '      c. Network topology property analysis                                '
    '      d. Infer Jacobian of the network dynamics                            '
    '      e. Mapping compouds to KEGG and color pathways by concentration      '
    '                                                                           '
    'In the main panel, please start from Load, then do analysis step by step.  '
    'Finally, please input the Name of the files when you Save the results.     '
    '                                                                           '
    '==== Data Information Panel ====                                           '
    '                                                                           '
    'After loading your data, the data information will be shown in this panel. '
    'It lists the number of sustances and conditions. If the data is NOT        '
    'arranged in the format that rows are substances and colums are conditions, '
    'please click the Transpose button.                                         '
    '                                                                           '
    'Next, if your data contains missing values or outliers, you can click the  '
    'Fill or Remove to adjust these values.                                     '
    '                                                                           '
    'The button Plot generates the errorbar plot of all substances across all   '
    'conditions.                                                                '
    '                                                                           '
    '==== Data Analysis Panel ====                                              '
    '                                                                           '
    'Before doing any analysis, please specify which condition to be analyzed.  '
    'If you select All(default), all the conditions will be analyzed; otherwise,'
    'input the indices of the conditions. The length of indices must be >= 2.   '
    '                                                                           '
    'Correlation is a pair-wise dependence measurement of variables. A larger   '
    'value indicates there is strong dependence between the pairs of data, such '
    'as metabolite(1) and metabolite(2). An zero correlation indicates there is '
    'no relationship between the pair. Generally, the value is neither 1(-1) nor'
    '0, but others in between. In metabolomics analysis, correlation is used to '
    'study the fingerprint of the metabolic pathway under different conditions, '
    'used as the distance metric of clustering, and used as the naive method of '
    'inferring network topology. In the current MA toolbox, Pearson and Spearman'
    'correlation are implemented. Use "Options" button to select the method     '
    '                                                                           '
    'Principal Component Analysis (PCA) and Indenpendent Component Analysis(ICA)'
    'are generally used as classifying samples into different groups. They can  '
    'identify the most influecing variables by calculating the varainces of each'
    'PC or IC has. The 1st PC/IC has the largest varaince and followed by the   '
    '2nd, the 3rd, and so on. Frequently, the first several PC/IC(s) have over  '
    '50% variances, therefore typical PCA/ICA plot only contains MAX 5 PC/IC(s).'
    'Therefore, please select the number of PC/IC(s) for plotting. The maximal  '
    'number of PC/IC(s) is limited to 5.                                        '
    '                                                                           '
    'Time-series (or, time course) analysis is to analyze the time-evolving     '
    'dynamics of substances/pathway/network. There are many kinds of time-      '
    'series in everyday life, such as weather forcast, stock change, etc.       '
    'As a result, there are many time-series analysis methods. However, due to  '
    'the prerequisites of most methods are 1)the series is longer than 1000     '
    'time points; 2)the series is stationary, which means statistical metrics   '
    'such as mean/std/variance/ do not change over time; 3)the series is equal- '
    'distant measured, such as [1h,2h,3h,...]. Most molecular data do not       '
    'satisfy there requirememts. Hence, the available time-series methods that  '
    'can be applied in metabolomics/transcriptomics data are very limited. NOTE:'
    'Before doing any analysis, please define the time-series sequence by using '
    'the labels of conditions, such as [1,3,4,2,5,6] - VERY IMPORTANT !!!       '
    '                                                                           '
    'Correlation analysis regards each time-series as a data. You can correlate '
    'different series of metabolites, or associate time-series of metabolites   '
    'and other substances, such as proteins/mRNA, etc, to study the response.   '
    '                                                                           '
    'Clustering is to classify the time-series into different groups according  '
    'to the distance or similarity of the time-series. It is useful in studying '
    'and visualizing the different response behaviors under some conditions.    '
    'Reference:                                                                 '
    'Cluster analysis and display of genome-wide expression patterns            '
    'Eisen MB, Spellman PT, Brown PO, Botstein D.,                              '
    'Proc Natl Acad Sci U S A. 1998 Dec 8, 95(25):14863-8                       '
    'http://www.ncbi.nlm.nih.gov/pubmed/9843981                                 '
    '                                                                           '
    'Granger causality is to infer which substance(s) cause others behavior.    '
    'The algorithm is to introduce a delay of the series of substance i, then   '
    'regress this series with other substances. The p-values are calculated by  '
    'F-test of regression coefficients. After calculating all the p-values,     '
    'the Benjamini-Hochberg false discovery rate (BH-FDR) is applied to adjust  '
    'the p-values. A small BH-FDR p-value indicates substance i is the cause    '
    'of other substances.                                                       '
    'Reference:                                                                 '
    'Metabolic pathway relationships revealed by an integrative analysis of the '
    'transcriptional and metabolic temperature stress-response dynamics in      '
    'yeast                                                                      '
    'Walther D, Strassburg K, Durek P, Kopka J., OMICS. 2010 Jun 14(3):261-74   '
    'http://www.ncbi.nlm.nih.gov/pubmed/20455750                                '
    '                                                                           '
    'Permutation Entropy (PE) is originated from dynamic systems theory (See    '
    'Ref1). It calculates the entropy of orderly patterns of time-series. A     '
    'high entropy indicates the time-series have many response actions, thereby '
    'more complex or likely more unstable. Recently we (see Ref2) applied PE to '
    'gene expression data of AtGenExpress and found house-keeping genes have    '
    'lower PE and abiotic response genes have higher PE. Therefore, PE can be   '
    'used as predicting the functions of unknown genes. Here, the PE is tried   '
    'in metabolomics data analysis.                                             '
    'References:                                                                '
    '1. Permutation entropy: a natural complexity measure for time series       '
    '   Bandt C, Pompe B., Phys Rev Lett. 2002 Apr 29, 88(17):174102            '
    '   http://www.ncbi.nlm.nih.gov/pubmed/12005759                             '
    '2. The Complexity of Gene Expression Dynamics Revealed by Permutation      '
    '   Entropy                                                                 '
    '   Sun X., Zou Y., Nikiforova V., Kurths J. and Walther D.,                '
    '   BMC Bioinformatics (2010) 11:607                                        '
    '   http://www.ncbi.nlm.nih.gov/pubmed/21176199                             '
    '                                                                           '
    'Network analysis is to associate the experimental data with the inferred   '
    'or manually curated network topology. Currently, the topology is inferred  '
    'from the experimental data by using correlation or Granger casuality. The  '
    'Matlab function biograph visualize the topology. The network properties,   '
    'such as degree and betweenness are calculated from the sparse matrix of    '
    'stoichiometric matrix, which, currently automatically calculated, should   '
    'be manually adjusted because different metabolites have different numbers  '
    'of carbon. For example, sucrose is a 12-C metabolite but glucose is 6-C.   '
    'The automatic calculation wrongly assigns 1 sucrose = 1 glucose.           '
    'Nevertheless, such wrong assignments do not significantly affect the       '
    'network proerties. NOTE: currently the Network Property button is set      '
    'inactive since COVAIN generates Cytoscape network file (.sif) and Pajek    '
    '.net file, therefore the network properties can be analyzed by Cytoscape or'
    'Pajek.                                                                     '
    '                                                                           '
    'Jacobian is the mathematical representation of network dynamics. Often,    '
    'Jacobian is calculated from the ordinary differential equation (ODE) based '
    'mathematical model of network. However, as many kinetic parameters are not '
    'available, building the ODE model is difficult. Here, we applied the van   '
    'Kampen equation to reconstruct the Jacobian from the covariance matrix of  '
    'experimental data. By associating PCA and Jacobian, we found a novel way   '
    'to infer the perturbation sites of a network under treatment conditions.   '
    'User needs to upload the stoichiometric matrix.                            '
    'References:                                                                '
    '1. Observing and interpreting correlations in metabolomic networks         '
    '   Steuer R, Kurths J, Fiehn O, Weckwerth W.,                              '
    '   Bioinformatics. 2003 May 22;19(8):1019-26.                              '
    '   http://www.ncbi.nlm.nih.gov/pubmed/12761066                             '
    '2. Inferring Biochemical Perturbation Sites from Metabolomics Covariance   '
    '   Data - A Mathematical Framework                                         '
    '   Sun X., Steinfath M., Walther D. and Weckwerth W., in preparation       '
    '                                                                           '
    'To map metabolites to KEGG, COVAIN uses the Levenshtein string distance to '
    'compare the names of metabolites to KEGG compound names and find the KEGG  '
    'compound ID, such as C00022. Then, COVAIN uses SOAP to access KEGG database'
    'and find all associated pathways. COVAIN uses red to label an increase in  '
    'concentration and blue for decrease, comparing with the control condition. '
    'All pathways are downloaded from KEGG.                                     '
    '                                                                           '
    '==== Save results ====                                                     '
    '                                                                           '
    'Please use "Save" button to save all results, which includes an Excel file '
    'consisting of the precessed dataset, the loadings of first five PCs and ICs'
    'of PCA and ICA analysis and the correlation coeffcients, a .txt file of    '
    'notes, a Matlab .mat workspace and one .sif Cytoscape file, one .net       '
    'Pajek file, as well as colored KEGG pathway folders.                       '
    '                                                                           '
    '                                                                           '
    'Xiaoliang Sun - June 20, 2011                                              '
    'Deptartment of Molecular Systems Biology, University of Vienna, Austria    '
    'Email: xiaoliang.sun@univie.ac.at   or   xiaoliangsun@gmail.com            '
    '                                                                           '
    '                                                                           '
    'Updated on Feb. 29, 2012:                                                  '
    'COVAIN citation information:                                               '
    '                                                                           '
    'COVAIN: a toolbox for uni- and multivariate statistics, time-series and    '
    'correlation network analysis and inverse estimation of the differential    '
    'Jacobian from metabolomics covariance data. Sun X and Weckwerth W,         '
    'Metabolomics (12 February 2012), pp. 1-13                                  '];



helpwin(helpText,helpTitle);


