function COVAIN_loadData(obj,evt)
%

% get the top handle
hTop = get(obj,'Parent');
dataStruct = guidata(hTop);
loadNumber = dataStruct.loadNumber;
color_default = get(obj,'BackgroundColor');

% if first load, open a folder; otherwise, remember this folder
if loadNumber == 0
    [rawFileName,rawFilePath] = uigetfile({'*.xlsx;*.xls','All Excel tables';...
            '*.txt;*.csv;*.dat','All tab-seperated text files';...
            '*.*','All Files'},'Load a dataset');
else
    rawFilePathOld = dataStruct.dataset(loadNumber).dataInfo.openPath;
    [rawFileName,rawFilePath] = uigetfile({'*.xlsx;*.xls','All Excel tables';...
            '*.txt;*.csv;*.dat','All tab-seperated text files';...
            '*.*','All Files'},'Load a dataset',rawFilePathOld);    
end

if rawFileName > 0
    %% reading excel files, assume Excel has been installed
    if ~isempty(findstr('.xls',rawFileName)) || ~isempty(findstr('.xlsx',rawFileName))
        try 
            [waste1,waste2,dataNames] = xlsread(strcat(rawFilePath,rawFileName),-1);
        catch err
            hErrIdx = warndlg(['Fails to open file: ',err.message]);
            uiwait(hErrIdx);
            return;
        end
        try
            idx1 = cellfun(@isempty,dataNames);
            dataNames(idx1)={NaN}; clear idx1; 
            dataRaw = cell2mat(dataNames(2:size(dataNames,1),2:size(dataNames,2)));
        catch err
            hErrIdx = warndlg(['Fails to open file: ',err.message]);
            uiwait(hErrIdx);
            return;
        end
        
        for iN = 2:size(dataNames,2)
            if isnumeric(dataNames{1,iN}) == 1
                dataNames{1,iN} = num2str(dataNames{1,iN}); % change num to str, NOT cell!
                % otherwise, problems in gname function
            end
        end
        for iN = 2:size(dataNames,1)
            if isnumeric(dataNames{iN}) == 1
                dataNames{iN} = num2str(dataNames{iN});
            end
        end
        clear iN
        
    %% read other formats (tab seperated text format)
    else
        dataS = importdata(strcat(rawFilePath,rawFileName));
        textdata = dataS.textdata;
        data = dataS.data;
        flgCol = 0; flgRow = 0;
        
        % collect dataNames (rows and cols)
        % if the names are numbers
        if all(isnumeric(data(1,1:size(data,2)))) && size(textdata,2) == 1
            colStr = cell(1,size(data,2));
            for iN = 1:size(data,2)
                colStr{iN} = num2str(data(1,iN)); % 1st row
            end
            flgCol = 1;
        else % if the names are characters
            colStr = dataS.textdata(1,2:end);
        end
        % if the names are numbers
        if all(isnumeric(data(1:size(data,1)))) && size(textdata,1) == 1
            rowStr = cell(size(data,1),1);
            for iN = 1:size(data,1)
                rowStr{iN} = num2str(data(iN));
            end
            % rowStr = num2cell(data(1:size(data,1))); % 1st col
            flgRow = 1;
        else % if the names are characters
            rowStr = dataS.textdata(2:end);
        end
        dataNames = cell(length(rowStr)+1,length(colStr)+1);
        dataNames(1,:) = [{' '},colStr];
        dataNames(2:end,1) = rowStr;
        
        % collect data
        if flgRow && flgCol
            dataRaw = dataS.data(2:end,2:end);
        elseif flgRow
            dataRaw = dataS.data(:,2:end);
        elseif flgCol
            dataRaw = dataS.data(2:end,:);
        else
            dataRaw = dataS.data;
        end
    end
    clear data iN;
    
    %% doing some names cleaning
    % -- is the unique label on MyData names
    if findstr('--',rawFileName) >= 1
        rawFileName(findstr('--',rawFileName)) = '-';
    end
    % __ is the unique label for MyData copies
    if findstr('__',rawFileName) >= 1
        rawFileName(findstr('__',rawFileName)) = '-';
    end
    % remove extension names (.xls, .txt, etc)
    locDot = findstr('.',rawFileName); 
    if ~isempty(locDot)
        locDot = locDot(end); % find the the last "." location
        rawFileName(locDot:end) = [];
    end
    
    %% naming the new dataset
    loadNumber = loadNumber + 1;
    if loadNumber == 1
        dataStruct.ID{loadNumber} = [num2str(loadNumber),'--',rawFileName]; % cell
        flg = 0;   choice = [];
    else % Compare with existing data
        existID = cell(length(dataStruct.ID),1);
        for i=1:length(dataStruct.ID)
            existID{i} = dataStruct.ID{i};
            existID{i}(1:findstr('--',existID{i})+1) = [];
            if ~isempty(findstr('__',existID{i}))
                existID{i}(findstr('__',existID{i}):end) = [];
            end
        end
        flg = strcmp(rawFileName,existID);
        if any(flg==1)  % data already exist
            locExist = find(flg==1); % may be several!!! ---- 
            if length(locExist)==1
                choice = questdlg('You have already imported this data!', ...
                    'Import data',...
                    'Overwrite','Keep both','Cancel','Cancel');
            else
                choice = questdlg('You have already imported this data!', ...
                    'Import data',...
                    'Keep all','Cancel','Cancel');
            end
            switch choice
                case 'Overwrite' % ID not changed, content deleted
                    loadNumber = loadNumber - 1;
                    dataStruct.dataset(locExist).dataInfo = [];
                    if isfield(dataStruct.dataset(locExist),'result')==1
                        dataStruct.dataset(locExist).result = [];
                    end
                    if isfield(dataStruct.dataset(locExist),'text')==1
                        dataStruct.dataset(locExist).text = [];
                    end
                case 'Keep both'
                    dataStruct.ID{loadNumber} = ...
                        [num2str(loadNumber),'--',rawFileName,'__2']; % cell
                case 'Keep all'
                    dataStruct.ID{loadNumber} = ...
                        [num2str(loadNumber),'--',rawFileName,'__',num2str(length(locExist)+1)];
                case 'Cancel'
                    loadNumber = loadNumber - 1;
            end
        else           % a new dataset
            dataStruct.ID{loadNumber} = [num2str(loadNumber),'--',rawFileName]; % cell
            choice = [];
        end
    end
    
    dataStruct.loadNumber = loadNumber;
    dataStruct.current = loadNumber;
    
    %% the real work
    if all(flg==0) || (   (any(flg==1) && strcmp(choice,'Cancel')~=1)   )
        try
            dataStruct.dataset(loadNumber).dataInfo = COVAIN_dataSummary(dataRaw,dataNames,'do');
        catch err
            ErrMSG = err.message;
            hErr = warndlg(['Fails to load data: ',ErrMSG]);
            uiwait(hErr);
            return;
        end
    end
    
    %% remember data's open folder and create saving folder
    % open path
    dataStruct.dataset(loadNumber).dataInfo.openPath = rawFilePath; 
    % save path
    path0 = [rawFilePath,'COVAIN_Results/'];
    if exist(path0,'dir') ~= 7        
        mkdirStatus = mkdir(path0);
        if mkdirStatus == 0  % if the user cannot create a folder
            path0 = pwd;
        end
    end
    dataStruct.dataset(loadNumber).dataInfo.savePath = path0;
    
%    % old codes
%     timeStr = ['COVAIN_Analysis-',datestr(now)];
%     timeStr = strrep(timeStr,' ','-');
%     timeStr = strrep(timeStr,':','-');
%     dataStruct.dataset(loadNumber).dataInfo.timeStr = timeStr;
%     path0 = [rawFilePath,'COVAIN_Results/'];
%     if exist(path0,'dir') ~= 7        
%         mkdir(path0);
%     end
%     mkdir( [path0,timeStr,'/']);
    
    
    %% display the data info
    % show the names of dataset at the left list (under "Choose data")
    guidata(hTop,dataStruct);
    if strcmp(choice,'Overwrite')~=1
        set(findobj(hTop,'Tag','list_dataSelect'),'String',dataStruct.ID,'Value',loadNumber);
    else
        set(findobj(hTop,'Tag','list_dataSelect'),'String',dataStruct.ID,'Value',locExist);
    end
    
    % create data preview
    currentData = dataStruct.dataset(loadNumber).dataInfo;
    infoStr = currentData.textInfo;
    infoStr = strcat('COVAIN assumes rows are substances and columns are samples. ',infoStr);
    missStr = currentData.textMiss;
    outStr  = currentData.textOut;
    dataTable = currentData.table;
    tabelColName = currentData.cond;
    tableRowName = currentData.subs;
    
    % update the data info
    set(findobj(hTop,'Tag','text_info'),'String',infoStr,...
        'Enable','on');
    set(findobj(hTop,'Tag','text_miss'),'String',missStr,...
        'Enable','on');
    set(findobj(hTop,'Tag','text_outlier'),'String',outStr,...
        'Enable','on');
    
    % reset check boxes' states
    set(findobj(hTop,'Tag','checkbox_Stat'),'Value',0);
    set(findobj(hTop,'Tag','checkbox_TS'),'Value',0);
    
    % update table preview: only show the mean value!
    set(findobj(hTop,'Tag','radio_tableSelect_2'),'Value',1);
    set(findobj(hTop,'Tag','table_preview'),'Data',dataTable,...
        'ColumnName',tabelColName,'RowName',tableRowName,...
        'Enable','on');
    
    % reset the button history (transpose,miss,out,norm,log10,z)
    set(findobj(hTop,'Tag','button_trans'),'BackgroundColor',color_default);
    set(findobj(hTop,'Tag','popup_norm'),'BackgroundColor',color_default);
    set(findobj(hTop,'Tag','popup_norm'),'Value',1);
    set(findobj(hTop,'Tag','button_miss'),'BackgroundColor',color_default);
    set(findobj(hTop,'Tag','button_outlier'),'BackgroundColor',color_default);
    set(findobj(hTop,'Tag','button_log'),'BackgroundColor',color_default);
    set(findobj(hTop,'Tag','button_Ztrans'),'BackgroundColor',color_default);
    set(findobj(hTop,'Tag','button_ZtransR'),'BackgroundColor',color_default);
    set(findobj(hTop,'Tag','normTrans'),'BackgroundColor',color_default);
    
else
    choiceClose = questdlg('Quit the toolbox?', ...
        'Quit confirmation',...
        'Yes','No','No');
    if strcmp(choiceClose,'Yes')
        delete(gcf);
    else
        uicontrol(obj);
    end
end



