function COVAIN_loadIntData(dataRawAll,rawFileName,hTop)
% function COVAIN_loadIntData(dataRaw,rawFileName,hTop)
% load internal data, not interact with any objs, 
% but need root handle (hTop)

% get the top handle
dataStruct = guidata(hTop);
loadNumber = dataStruct.loadNumber;
objLoad = findobj(hTop,'Tag','button_load');
color_default = get(objLoad,'BackgroundColor');
dataRaw = cell2mat(dataRawAll(2:end,2:end));
dataNames = dataRawAll;

%% naming the new dataset
loadNumber = loadNumber + 1;
if loadNumber == 1
    dataStruct.ID{loadNumber} = [num2str(loadNumber),'--',rawFileName]; % cell
    flg = 0;   choice = [];
else % Compare with existing data
    existID = cell(length(dataStruct.ID),1);
    for i=1:length(dataStruct.ID)
        existID{i} = dataStruct.ID{i};
        existID{i}(1:findstr('--',existID{i})+1) = [];
        if ~isempty(findstr('__',existID{i}))
            existID{i}(findstr('__',existID{i}):end) = [];
        end
    end
    flg = strcmp(rawFileName,existID);
    if any(flg==1)  % data already exist
        locExist = find(flg==1); % may be several!!! ----
        if length(locExist)==1
            choice = questdlg('You have already imported this data!', ...
                'Import data',...
                'Overwrite','Keep both','Cancel','Cancel');
        else
            choice = questdlg('You have already imported this data!', ...
                'Import data',...
                'Keep all','Cancel','Cancel');
        end
        switch choice
            case 'Overwrite' % ID not changed, content deleted
                loadNumber = loadNumber - 1;
                dataStruct.dataset(locExist).dataInfo = [];
                if isfield(dataStruct.dataset(locExist),'result')==1
                    dataStruct.dataset(locExist).result = [];
                end
                if isfield(dataStruct.dataset(locExist),'text')==1
                    dataStruct.dataset(locExist).text = [];
                end
            case 'Keep both'
                dataStruct.ID{loadNumber} = ...
                    [num2str(loadNumber),'--',rawFileName,'__2']; % cell
            case 'Keep all'
                dataStruct.ID{loadNumber} = ...
                    [num2str(loadNumber),'--',rawFileName,'__',num2str(length(locExist)+1)];
            case 'Cancel'
                loadNumber = loadNumber - 1;
        end
    else           % a new dataset
        dataStruct.ID{loadNumber} = [num2str(loadNumber),'--',rawFileName]; % cell
        choice = [];
    end
end

dataStruct.loadNumber = loadNumber;
dataStruct.current = loadNumber;

%% the real work
if all(flg==0) || (   (any(flg==1) && strcmp(choice,'Cancel')~=1)   )
    dataStruct.dataset(loadNumber).dataInfo = COVAIN_dataSummary(dataRaw,dataNames,'do');
end

%% create default saving folder
dataStruct.dataset(loadNumber).dataInfo.openPath = ...
    dataStruct.dataset(loadNumber-1).dataInfo.openPath;
dataStruct.dataset(loadNumber).dataInfo.savePath = ...
    dataStruct.dataset(loadNumber-1).dataInfo.savePath;

% if loadNumber == 1
%     timeStr = ['COVAIN_Analysis-',datestr(now)];
%     timeStr = strrep(timeStr,' ','-');
%     timeStr = strrep(timeStr,':','-');
%     dataStruct.dataset(loadNumber).dataInfo.timeStr = timeStr;
%     % if exist('COVAIN_Results','dir') == 7
%     locDir = strmatch('COVAIN_Results',ls(pwd),'exact');
%     if ~isempty(locDir)
%         path0 = './COVAIN_Results/';
%     else
%         path0 = './COVAIN_Results/';
%         mkdir(path0);
%     end
%     dataStruct.dataset(loadNumber).dataInfo.savePath = [path0,timeStr,'/'];
%     mkdir( [path0,timeStr,'/']);
% else
%     dataStruct.dataset(loadNumber).dataInfo.savePath = ...
%         dataStruct.dataset(1).dataInfo.savePath;
% end

%% display the data info
% show the names of dataset at the left list (under "Choose data")
guidata(hTop,dataStruct);
if strcmp(choice,'Overwrite')~=1
    set(findobj(hTop,'Tag','list_dataSelect'),'String',dataStruct.ID,'Value',loadNumber);
else
    set(findobj(hTop,'Tag','list_dataSelect'),'String',dataStruct.ID,'Value',locExist);
end

% create data preview
currentData = dataStruct.dataset(loadNumber).dataInfo;
infoStr = currentData.textInfo;
infoStr = strcat('COVAIN assumes rows are substances and columns are samples. ',infoStr);
missStr = currentData.textMiss;
outStr  = currentData.textOut;
dataTable = currentData.table;
tabelColName = currentData.cond;
tableRowName = currentData.subs;

% update the data info
set(findobj(hTop,'Tag','text_info'),'String',infoStr,...
    'Enable','on');
set(findobj(hTop,'Tag','text_miss'),'String',missStr,...
    'Enable','on');
set(findobj(hTop,'Tag','text_outlier'),'String',outStr,...
    'Enable','on');

% reset check boxes' states
set(findobj(hTop,'Tag','checkbox_Stat'),'Value',0);
set(findobj(hTop,'Tag','checkbox_TS'),'Value',0);

% update table preview: only show the mean value!
set(findobj(hTop,'Tag','radio_tableSelect_2'),'Value',1);
set(findobj(hTop,'Tag','table_preview'),'Data',dataTable,...
    'ColumnName',tabelColName,'RowName',tableRowName,...
    'Enable','on');

% reset the button history (transpose,miss,out,norm,log10,z)
set(findobj(hTop,'Tag','button_trans'),'BackgroundColor',color_default);
set(findobj(hTop,'Tag','popup_norm'),'BackgroundColor',color_default);
set(findobj(hTop,'Tag','popup_norm'),'Value',1);
set(findobj(hTop,'Tag','button_miss'),'BackgroundColor',color_default);
set(findobj(hTop,'Tag','button_outlier'),'BackgroundColor',color_default);
set(findobj(hTop,'Tag','button_log'),'BackgroundColor',color_default);
set(findobj(hTop,'Tag','button_Ztrans'),'BackgroundColor',color_default);
set(findobj(hTop,'Tag','button_ZtransR'),'BackgroundColor',color_default);

% ===== finished ====


