function COVAIN_mzPathViewer(obj,evt)
% search and plot paths between m/z features

% function COVAIN_mzPathViewer(dataType,dataPath,preSavePath)
% dataType: external -- mat; internal -- guidata
% dataPath: mzStruct.mat full path
% preSavePath: where to save Excel table

% get from button UserData
pathStruct = get(obj,'UserData');

% if data is available OR not available
if ~isempty(pathStruct)
    dataType = pathStruct.dataType;
    dataPath = pathStruct.dataPath;
    preSavePath = pathStruct.preSavePath;
else
    [mzFileName,mzFilePath] = uigetfile({'*.mat','mzStruct workspace'},...
        'MultiSelect','off','Load the existing pathway dataset');
    if isnumeric(mzFileName) % if nothing is loaded, exit
        return;
    else
        mzFullPath = [mzFilePath,mzFileName];
        dataType = 'external';
        dataPath = mzFullPath;
        preSavePath = pwd;
    end
end

% load the dataset
if strcmp(dataType,'internal')
    h = findobj('Tag','button_mzGroup');
    mzStruct = get(h,'UserData');
elseif strcmp(dataType,'external')
    warning off; A = load(dataPath,'mzStruct'); warning on; 
    if ~isempty(strcmp('mzStruct',fieldnames(A)))
        mzStruct = A.mzStruct;
    else
        warndlg('No correct mzStruct workspace has been loaded. Do nothing.');
        return;
    end
    % check if the data is the correct data by inspecting its fields
    flgCorrectData = 1;
    if ~isstruct(mzStruct)
        flgCorrectData = 0;
    else
        fieldName = fieldnames(mzStruct);
        if length(intersect({'data','mmNet','allPath'},fieldName)) ~= 3
            flgCorrectData = 0;
        end
    end
    if ~flgCorrectData
        warndlg('The loaded dataset is not mzStruct data');
        return;
    end
end

% ruleList, TS points, names, 

ruleList = mzStruct.ruleList;
dataAll  = mzStruct.dataAll;
data     = mzStruct.data;
mzList   = mzStruct.mzList;
mzName   = mzStruct.mzName; 
x_final  = mzStruct.x_final;
y_final  = mzStruct.y_final;
mmNetPattern  = mzStruct.mmNetPattern;
allPath  = mzStruct.allPath;
compReal = mzStruct.compReal;
rulePath = arrayfun(@(x) x.rulePath,allPath,'UniformOutput',0); % cell

finalTimedPath   = mzStruct.finalTimedPath;
finalCorrectPath = mzStruct.finalCorrectPath;
mmNet   = mzStruct.mmNet;
mmNetS  = mzStruct.mmNetS;

% ==================================================================

% left screen for window, right for plot
scrSize = get(0,'ScreenSize');
midPos  = scrSize(3)*2/3; 
wdPos   = [0.02*midPos 0.1*scrSize(4) 0.9*midPos 0.8*scrSize(4)];
ftSize  = floor(12 * sqrt(scrSize(3)/1920)); % size 12 for 1920*1080 screen
bgColor = [153 204 153]/255; bgButton = [255 204 153]/255;

% generate the window
mzWindow = figure('Position',wdPos,'Interruptible','on',...
            'Name','mzGroupAnalyzer Pathway Viewer',...
            'NextPlot','new','NumberTitle','off',...
            'Resize','on','MenuBar','none', 'Toolbar','none', ...
            'Tag','mzWindow','HandleVisibility','callback');
% the main panel
mzPanel = uipanel('Parent',mzWindow,'Title',[],'Units','Normalized',...
            'Position', [0.01 0.01 0.98 0.98],'BackgroundColor',bgColor);
% the title
uicontrol('Parent',mzPanel,'Style','text','Units','Normalized',...
    'Position',[.35 .96 .30 .03],'String','Select & List','BackgroundColor',...
    bgColor,'FontSize',round(ftSize*1.2),'FontWeight','bold');
% the separater
uicontrol('Parent',mzPanel,'Style','text','Units','Normalized','BackgroundColor',...
    bgColor,'Position',[0 .94 1 .01],'String',repmat(char(43),1,1000));


% the composition text
uicontrol('Parent',mzPanel,'Style','text','Units','Normalized',...
    'Position',[.02 .9 .4 .03],'String','Composition','FontSize',ftSize,...
    'FontWeight','bold','BackgroundColor',bgColor);
% the C/H/O, etc.
CHO = compReal(1:min(length(compReal),6));  % maximal six elements
choPos = linspace(.1, .4, length(CHO));
choWid = 0.8 * (0.3/length(CHO));
for i=1:length(CHO)
    uicontrol('Parent',mzPanel,'Style','text','Units','Normalized',...
        'Position',[choPos(i) .87 choWid .025],'String',CHO{i},'FontSize',...
        ftSize,'BackgroundColor',bgColor);
end
% the From and To
uicontrol('Parent',mzPanel,'Style','text','Units','Normalized','BackgroundColor',...
     bgColor,'Position',[.02 .84 .06 .025],'String','From','FontSize',ftSize);
for i=1:length(CHO)
    uicontrol('Parent',mzPanel,'Style','edit','Units','Normalized',...
        'Position',[choPos(i) .84 choWid .025],'FontSize',ftSize,...
        'Tag',['CHO_From_',num2str(i)]);
end
uicontrol('Parent',mzPanel,'Style','text','Units','Normalized','BackgroundColor',...
     bgColor,'Position',[.02 .81 .06 .025],'String','To','FontSize',ftSize);
for i=1:length(CHO)
    uicontrol('Parent',mzPanel,'Style','edit','Units','Normalized',...
        'Position',[choPos(i) .81 choWid .025],'FontSize',ftSize,...
        'Tag',['CHO_To_',num2str(i)]);
end        


% the m/z features
uicontrol('Parent',mzPanel,'Style','text','Units','Normalized',...
    'Position',[.02 .77 .4 .03],'String','m / z value','FontSize',ftSize,...
    'FontWeight','bold','BackgroundColor',bgColor);
uicontrol('Parent',mzPanel,'Style','text','Units','Normalized','BackgroundColor',...    
    bgColor,'Position',[.02 .74 .06 .025],'String','From','FontSize',ftSize);
uicontrol('Parent',mzPanel,'Style','edit','Units','Normalized',...
    'Position',[.1 .74 .08 .025],'FontSize',ftSize,'Tag','MZ_From');
uicontrol('Parent',mzPanel,'Style','text','Units','Normalized','BackgroundColor',...    
    bgColor,'Position',[.2 .74 .06 .025],'String','to','FontSize',ftSize);
uicontrol('Parent',mzPanel,'Style','edit','Units','Normalized',...
    'Position',[.3 .74 .08 .025],'FontSize',ftSize,'Tag','MZ_To');

% the handles of rule objects
hRules = zeros(length(ruleList),1);
% the rule list, two columns, use "ruleList"
uicontrol('Parent',mzPanel,'Style','text','Units','Normalized',...
    'Position',[.02 .7 .4 .03],'String','Chemical Transformation Rules',...
    'FontSize',ftSize,'FontWeight','bold','BackgroundColor',bgColor);
% select all, using normal checkbox, bold font
hTick = ...
    uicontrol('Parent',mzPanel,'Style','checkbox','Units','Normalized',...
        'Position',[.02 .69-.022 .18 .025],'Value',0','String','Select / Reject all',...
        'FontSize',ftSize-1,'FontWeight','bold','Tooltipstring','Select / Reject all rules',...
        'BackgroundColor',bgColor,'CallBack',@checkboxFun,'Tag','tickAll');
% select and/or actions
hAnd = uicontrol('Parent',mzPanel,'Style','popupmenu','Units','Normalized',...
        'Position',[.3 .69-.022 .08 .025],'Value',1,'String',{'OR','AND'},...
        'FontSize',ftSize-1,'FontWeight','bold','Tooltipstring','Rules OR / AND');
% other rules checkbox
halfValue = ceil(length(ruleList)/2);
for i=1:halfValue
    hRules(i) = ...
      uicontrol('Parent',mzPanel,'Style','checkbox','Units','Normalized',...
        'Position',[.02 .66-i*.022 .18 .025],'Value',0,...
        'String',ruleList{i},'FontSize',ftSize-1,'Tag',['rule_',num2str(i)],...
        'Tooltipstring',ruleList{i},'HorizontalAlignment','left',...
        'BackgroundColor',bgColor,'CallBack',@checkboxFun);
end
for i=1:length(ruleList)-ceil(length(ruleList)/2)
    hRules(halfValue+i) = ...
        uicontrol('Parent',mzPanel,'Style','checkbox','Units','Normalized',...
            'Position',[.21 .66-i*.022 .18 .025],'Value',0,'Tag',['rule_',num2str(halfValue)],...
            'String',ruleList{i+ceil(length(ruleList)/2)},'FontSize',ftSize-1,...
            'Tooltipstring',ruleList{i+ceil(length(ruleList)/2)},...
            'BackgroundColor',bgColor,'CallBack',@checkboxFun);
end
        
% the time point checkbox in the right panel
uicontrol('Parent',mzPanel,'Style','text','Units','Normalized',...
    'Position',[.5 .9 .45 .03],'String','Time  Series  Points','FontSize',ftSize,...
    'FontWeight','bold','BackgroundColor',bgColor);
hTS = zeros(max(cellfun(@length,dataAll(:,5))),1);
for i=1:max(cellfun(@length,dataAll(:,5))) % number of time points
    lineNumber = ceil(i/5); iLocal = i - (lineNumber-1)*5; 
    hTS(i) = ...
        uicontrol('Parent',mzPanel,'Style','checkbox','Value',0,'Units',...
            'Normalized','Position',[.5+.09*(iLocal-1) .9-lineNumber*.03 .08 .025],...
            'String',['TP ',num2str(i)],'Tag',['TS_',num2str(i)],'FontSize',ftSize,...
            'BackgroundColor',bgColor,'HorizontalAlignment','left',...
            'CallBack',@checkboxFun,'Tooltipstring',['Time Point ',num2str(i)]);
end

% the separater
uicontrol('Parent',mzPanel,'Style','text','Units','Normalized','BackgroundColor',...
    bgColor,'Position',[.5 .9-lineNumber*.03-.03 .45 .01],'String',...
    repmat(char(126),1,1000));

% the show/plot/export buttons in the right panel
execStr = {'Show','Export'};  % do not use plot button NOW ----- 
execHeight = .9 - lineNumber*.03 - .1;
hShow = zeros(2,1);
for i=1:2
    hShow(i) = uicontrol('Parent',mzPanel,'Style','pushbutton','BackgroundColor',...
            bgButton,'ForegroundColor','b','Units','Normalized','Position',...
            [.57+(i-1)*.15 execHeight .1 .04],'String',execStr{i},'FontSize',...
            ftSize,'FontWeight','bold','CallBack',@buttonFun);
end

% information text
hInfo = uicontrol('Parent',mzPanel,'Style','text','BackgroundColor',bgColor,...
    'Units','Normalized','Position',[.55 execHeight-.05 .3 .02],'FontSize',...
    ftSize-1,'FontAngle','italic','String','Infomation will be shown here !');
        

% ================   Nested functions    ====================

    % 1. checkboxFun  --  respond to checkbox status
    function checkboxFun(subObj,subEvt)
        tagName = get(subObj,'Tag');
        if strcmp(tagName,'tickAll') == 1 % already 1 -> select all rules
            tickValue = get(subObj,'Value');
            set(hTick,'Value',tickValue);
            for k=1:length(hRules)
                set(hRules(k),'Value',tickValue);
            end  
        elseif strncmp(tagName,'rule_',5) == 1
            tickValue = get(subObj,'Value');
            set(hTick,'Value',0);
            set(hRules(str2double(tagName(6:end))),'Value',tickValue);
        elseif strncmp(tagName,'TS_',3) == 1
            tickValue = get(subObj,'Value');
            set(hTS(str2double(tagName(4:end))),'Value',tickValue);
        end
    end

    % ---------------------------------------------------------------
    
    % 2. buttonFun    --  respond to show/plot/export buttons
    function buttonFun(subObj,subEvt)
        strName = get(subObj,'String'); % show/plot/export
        if strcmp(strName,'Show') == 1
            % scan all status (CHO, mz, rules, TS)
            % 
            % ...........................................
            % 1. C/H/O,  tag = 'CHO_From_' / 'CHO_To_' 
            CHO_From = zeros(1,length(CHO));  % local variables
            CHO_To   = 10000*ones(1,length(CHO));
            
            for k=1:length(CHO_From)
                choValue1 =  get(findobj('Tag',['CHO_From_',num2str(k)]),'String');
                if ~isempty(choValue1) ...
                        && isnumeric(str2num(choValue1)) ...
                        && length(str2num(choValue1)) == 1 ...
                        && str2double(choValue1) <= CHO_To(k) ...
                        && str2double(choValue1) >= CHO_From(k)
                    CHO_From(k) = str2double(choValue1);
                else
                    set(findobj('Tag',['CHO_From_',num2str(k)]),'String','');
                end
                choValue2 = get(findobj('Tag',['CHO_To_',num2str(k)]),'String');
                if ~isempty(choValue2) ...
                        && isnumeric(str2num(choValue2)) ...
                        && length(str2num(choValue2)) == 1 ...
                        && str2double(choValue2) <= CHO_To(k) ...
                        && str2double(choValue2) >= CHO_From(k)
                    CHO_To(k) = str2double(choValue2);
                else
                    set(findobj('Tag',['CHO_To_',num2str(k)]),'String','');
                end
            end
            % correct wrong value (e.g., value_from > value_to) ??? ---- 
            %
            % then select the idx, default is all
            flgCHO = zeros(size(data,1),length(CHO));
            for k=1:length(CHO)
                flgCHO(:,k) = (data(:,k) >= CHO_From(k)) & (data(:,k) <= CHO_To(k));
            end
            zidx_CHO = find(all(flgCHO,2));
            
            % .................................................
            % 2. mz Value, tag = MZ_From / MZ_To
            MZ_From = 0; MZ_To = 1000000;
            mzValue1 = get(findobj('Tag','MZ_From'),'String');
            mzValue2 = get(findobj('Tag','MZ_To'),'String');
            if ~isempty(mzValue1) ...
                    && isnumeric(str2num(mzValue1)) ...
                    && length(str2num(mzValue1)) == 1 ...
                    && str2double(mzValue1) <= MZ_To ...
                    && str2double(mzValue1) >= MZ_From
                MZ_From = str2double(mzValue1);
            else
                set(findobj('Tag','MZ_From'),'String','');
            end
            if ~isempty(mzValue2) ...
                    && isnumeric(str2num(mzValue2)) ...
                    && length(str2num(mzValue2)) == 1 ...
                    && str2double(mzValue2) <= MZ_To ...
                    && str2double(mzValue2) >= MZ_From
                MZ_To = str2double(mzValue2);
            else
                set(findobj('Tag','MZ_To'),'String','');
            end
            % then select the idx
            zidx_MZ = find(mzList >= MZ_From  & mzList <= MZ_To); 
            % overlapping with zidx_CHO, with error control 
            zidx_Net = intersect(zidx_CHO,zidx_MZ);
            if isempty(zidx_Net) % if wrong, send the wrong signal and return
                set(hInfo,'String','No paths are found !'); 
                % clean the table
                if findobj('Tag','tableView')
                    set(findobj('Tag','tableView'),'Data',[]);
                end
                return;
            end
            
            % ....................................................
            % 3. days, tag = 'TS_', handles = hTS, using global index
            tsValue = get(hTS,'Value');
            if length(tsValue) > 1
                tsValue = cell2mat(get(hTS,'Value'));
            end
            tsIdx = find(tsValue==1);
            if isempty(tsIdx)
                set(hInfo,'String','No time points are selected !'); 
                % clean the table
                if findobj('Tag','tableView')
                    set(findobj('Tag','tableView'),'Data',[]);
                end
                return;
            end
            zidx_ts = zeros(length(mzList),sum(tsValue));
            for k=1:length(tsIdx)
                zidx_ts(:,k) = cell2mat(cellfun(@(x) any(x==k),...
                    dataAll(:,5),'UniformOutput',0));
            end
            zidx_TS = find(all(zidx_ts,2));  % ALL
            zidx_Final = intersect(zidx_Net,zidx_TS); % sorted
            if isempty(zidx_Final)
                set(hInfo,'String','No paths are found !'); 
                % clean the table
                if findobj('Tag','tableView')
                    set(findobj('Tag','tableView'),'Data',[]);
                end
                return;
            end
            
            % ....................................................
            % 4. rules, tag = rule_, handles = hRules, using global index
            % 1) use sub-net ?? will be faster but more complex in coding
            % 2) use global index, slower but more concise
            % considering the frequency of such actions, use global
            ruleValue = cell2mat(get(hRules,'Value'));
            ruleIdx = find(ruleValue==1);
            if isempty(ruleIdx)
                set(hInfo,'String','No rules are selected !'); 
                % clean the table
                if findobj('Tag','tableView')
                    set(findobj('Tag','tableView'),'Data',[]);
                end
                return;
            end
            
            % select sub-network
            if get(hAnd,'Value') == 1     % ANY = 1, ALL = 2;
                idxSub2 = find(cellfun(@(x) any(ismember(ruleIdx,x)), rulePath));
            else
                idxSub2 = find(cellfun(@(x) all(ismember(ruleIdx,x)), rulePath));
            end
                
            % ...................................................
            % now the final index has been obtained -> subResult
            % this index is the mz index

            % get the network
            idxSub_x = []; idxSub_y = []; idxSub1 = []; 
            for k=1:length(zidx_Final)
                idxSub_x = [idxSub_x; find(x_final == zidx_Final(k))];
                idxSub_y = [idxSub_y; find(y_final == zidx_Final(k))];
            end           
            if ~isempty(idxSub_x) && ~isempty(idxSub_y)
                idxSub1 = intersect(idxSub_x, idxSub_y);
            end   
            
            % ######### All filtering finishes ##########
            
            %idxSub = unique([idxSub1; idxSub2]);
            idxSub = intersect(idxSub1,idxSub2);
            
            % show the table
            if isempty(idxSub)
                set(hInfo,'String','No paths are found !'); 
                % clean the table
                if findobj('Tag','tableView')
                    set(findobj('Tag','tableView'),'Data',[]);
                end
                return;
            end
            subResult = allPath(idxSub(:));  % structure, NOT cell
            subResultCell = struct2cell(subResult)';  % cell
            % associate subResult to the show button
            set(hShow(1),'UserData',subResult);
            % then display
            set(hInfo,'String',['Totally ',num2str(length(subResult)),...
                ' paths are found !']);
            
            % uitable
            hTable = uitable('Parent',mzPanel,'Units','Normalized','Position',...
                [.47 .05 .48 execHeight-0.13],'FontSize',.9*ftSize,'ColumnName',...
                {'From (m/z)','From (CHO)','To (m/z)','To (CHO)','Path'},...
                'Data', subResultCell(:,[1 2 3 4 7]),'Tag','tableView',...
                'CellSelectionCallback',@plotFun);
        % export the table
        elseif strcmp(strName,'Export') == 1
            subResultStruct = get(hShow(1),'UserData');
            if ~isempty(subResultStruct)
                savePath = preSavePath;
                currentPath = pwd;
                cd(savePath);
                [fileName,pathName,flgStatus] = uiputfile('*.xlsx',...
                    'Please specify the file name');
                cd(currentPath);
                if flgStatus == 1 
                    subTableHeader = {'MZ_From','CHO_From','MZ_To','CHO_To','Rules',...
                        'MZ_Pathway','CHO_Pathway','TimeSeries_Pathway'};
                    nRow_Table = size(subResultStruct,1);
                    subTable = cell(nRow_Table,8);
                    subTable(:,1) = arrayfun(@(x) x.mzFrom, subResultStruct,'UniformOutput',0);
                    subTable(:,2) = arrayfun(@(x) x.choFrom, subResultStruct,'UniformOutput',0);
                    subTable(:,3) = arrayfun(@(x) x.mzTo, subResultStruct,'UniformOutput',0);
                    subTable(:,4) = arrayfun(@(x) x.choTo, subResultStruct,'UniformOutput',0);
                    subTable(:,6) = arrayfun(@(x) x.dispPath, subResultStruct,'UniformOutput',0);
                    for k1=1:size(subResultStruct,1)
                        for k2=1:length(subResultStruct(k1).rules)
                            subTable{k1,5} = [subTable{k1,5},subResultStruct(k1).rules{k2},' | '];
                        end
                        subTable{k1,5}(end-2:end) = [];
                        for k2=1:length(subResultStruct(k1).choPath)
                            subTable{k1,7} = [subTable{k1,7}, subResultStruct(k1).choPath{k2},' -> '];
                            subTable{k1,8} = [subTable{k1,8}, num2str(subResultStruct(k1).TS(k2)),' -> '];
                        end
                        subTable{k1,7}(end-3:end) = []; 
                        subTable{k1,8}(end-3:end) = [];
                    end
                    subTable = [subTableHeader; subTable];
                    try
                        xlswrite([pathName,fileName],subTable);
                        msgbox('  Done  !');
                    catch err
                        hWarnXLS = warndlg(['Writing to Excel table fails: ',err.message]);
                        uiwait(hWarnXLS);
                    end
                end
            end  % export end          
        end % buttons end
    end  % subfunction end

    % 3. plotFun --- plot reaction chains
    function plotFun(objTable,evtTable)
        if strcmp(get(hInfo,'String'),'No paths are found !') || ...
           strcmp(get(hInfo,'String'),'No time points are selected !') || ...
           strcmp(get(hInfo,'String'),'No rules are selected !')
            return;
        end
        tableData = get(hShow(1),'UserData');
        idxCell = evtTable.Indices(1,:);    % single cell allowed
        idxRow = idxCell(1); idxCol = idxCell(2);
        cellData = tableData(idxRow);
%         if idxCol == 5                      % only plotting path
%             cellData = tableData(idxRow);   % structure, single item
%         else
%             return;
%         end
        % plot pathway chains, set 'Units' as pixels
        % for pixel size <--> font size, see:
        % http://websemantics.co.uk/resources/font_size_conversion_chart/
        %
        % alternatively and more simple, set 'Units' as characters
        % doc uicontrol, see properties
        % a 1920*1080 pixels screen ~= 390*85 characters
        % PLOT IS A FUNCTION OF SCREEN SIZE AND FONT SIZE AND CHAIN LENGTH
        
        % prepare for plotting
        rowMiddle = [];                            % m/z
        posMz = zeros(1,length(cellData.mzPath));
        for k=1:length(cellData.mzPath)
            posMz(k) = length(rowMiddle) + 1;
            if k ~= length(cellData.mzPath)
                rowMiddle = [rowMiddle, cellData.mzPath{k},' ----------> ']; % arrow length = 13
            else
                rowMiddle = [rowMiddle, cellData.mzPath{k}];
            end
        end
        rowLower = repmat(' ',1,length(rowMiddle));  % CHO 
        rowUpper = rowLower;                         % Rules
        rowBottom = rowLower;                        % Time points
        for k=1:length(cellData.mzPath)
            rowLower(posMz(k):posMz(k)+length(cellData.choPath{k})+1) = ...
                ['(',cellData.choPath{k},')'];
            
            % ------  NOTICE !!!  ------
            % the TP should include all existing time points
            %++ Wrong ++
            %rowBottom(posMz(k):posMz(k)+length(num2str(cellData.TS(k)))+6) = ...
            %    ['[ TP ',num2str(cellData.TS(k)),' ]'];
            %++ Correct ++ Use 'dataAll' ++
            
            % if multiple mz exist(theo.mass can be the same), only plot the first one
            idxMZ = find(strcmp(cellData.mzPath{k},mzName), 1 );
            
            tpStr = 'TP [';
            for m=1:length(dataAll{idxMZ,5})
                tpStr = [tpStr,num2str(dataAll{idxMZ,5}(m)),'/'];
            end
            tpStr(end) = ']';
            rowBottom(posMz(k):posMz(k)+length(tpStr)-1) = tpStr;
            % --------------------------    
 
            if k ~= length(cellData.mzPath)
                maxRuleWidth = floor((length(cellData.mzPath{k}) + ... 
                    length(cellData.mzPath{k+1}))/2) + 11;
                if length(cellData.rules{k}) > maxRuleWidth
                    rowUpper(posMz(k)+floor(length(cellData.mzPath{k})): ...
                        posMz(k)+floor(length(cellData.mzPath{k}))+maxRuleWidth-1) ...
                           = cellData.rules{k}(1:maxRuleWidth);
                else
                    leftPos = posMz(k) + length(cellData.mzPath{k}) + 6 ...
                                       - round(length(cellData.rules{k})/2);
                    rowUpper(leftPos:leftPos+length(cellData.rules{k})-1) = ...
                                         cellData.rules{k};
                end
            end
        end
        % plot settings
        % ftColor_rule/mz/cho can be set upon time points
        % window size can be set upon length of rows' text
        % ftSize, ft font name can also be adjsuted
        ftSizeSmall = floor(.9*ftSize);
        wdHeight1 = scrSize(4)*(execHeight-0.08);
        wdHeight2 = 0.87*scrSize(4) - wdHeight1;
        lenTotalStr = sum(cellfun(@length,cellData.mzPath)) + 13*length(cellData.rules);
        wdWidthCoeff = min(0.4*lenTotalStr/100, 0.9);
        pathFigure = figure(...
            'Position',[.05*midPos wdHeight1 wdWidthCoeff*scrSize(3) wdHeight2],...
            'Interruptible','on','Name',['Path: ',cellData.dispPath],...
            'NextPlot','new','NumberTitle','off','Resize','on','MenuBar',...
            'figure', 'Toolbar','none','HandleVisibility','callback');
        pathPanel = uipanel('Parent',pathFigure,'Units','normalized',...
            'Position',[.01 .03 .98 .95]);
        % plot the chain
        uicontrol('Parent',pathPanel,'Style','text','Units','Normalized',...
            'Position',[.05 .8 .9 .1],'String',rowUpper,'HorizontalAlignment',...
            'center','ForegroundColor','b','FontSize',ftSizeSmall);
        uicontrol('Parent',pathPanel,'Style','text','Units','Normalized',...
            'Position',[.05 .65 .9 .1],'String',rowMiddle,'HorizontalAlignment',...
            'center','ForegroundColor','r','FontSize',ftSizeSmall);
        uicontrol('Parent',pathPanel,'Style','text','Units','Normalized',...
            'Position',[.05 .5 .9 .1],'String',rowLower,'HorizontalAlignment',...
            'center','ForegroundColor','k','FontSize',ftSizeSmall);
        uicontrol('Parent',pathPanel,'Style','text','Units','Normalized',...
            'Position',[.05 .35 .9 .1],'String',rowBottom,'HorizontalAlignment',...
            'center','ForegroundColor',[0 77 0]./255,'FontSize',ftSizeSmall);
    end

% ============================================================        
end % end of main function
        
