function COVAIN_netInferrence(obj,evt)
%

h1 = get(obj,'Parent'); % hPanel_NetInfer
h2 = get(h1,'Parent');  % h_dataAnalysis
h3 = get(h2,'Parent');  % hMain

dataStruct = guidata(h3);
if dataStruct.loadNumber == 0
    return;
end
currentData = dataStruct.dataset(dataStruct.current).dataInfo;
nameSub = currentData.subs;
corrThresh = currentData.options.corrThresh;

option = get(findobj(h1,'Tag','list_Infer'),'Value');

switch option
    case 1
        % check corrStat availability
        if currentData.dataStat_OK ~= 1
            hWarn1 = warndlg('Correlation data not available');
            uiwait(hWarn1);
            uicontrol(findobj(h3,'Tag','button_doCorr'));
        else
            corrStat = currentData.corrStat; 
            corrStat_pval = currentData.corrStat_pval;
            %fdrP = mafdr(corrStat_pval(:),'BHFDR','true');
            %fdrP = reshape(fdrP,length(nameSub),length(nameSub));
            %stoi = fdrP < 0.05 & abs(corrStat) > corrThresh;
            stoi = corrStat_pval < 0.05 & abs(corrStat) > corrThresh;
            % cannot be symmetric @ 2017.05.21
            stoi(~tril(ones(size(stoi)))) = 0;
            currentData.SparseMatrix = sparse(stoi);
        end
    case 2
        % check corrTS availability
        if currentData.dataTS_OK ~= 1
            hWarn2 = warndlg('Correlation TS data not available');
            uiwait(hWarn2);
            uicontrol(findobj(h3,'Tag','button_corrTS'));
        else
            corrTS = currentData.corrTS; 
            corrTS_pval = currentData.corrTS_pval;
            %fdrP = mafdr(corrTS_pval(:),'BHFDR','true');
            %fdrP = reshape(fdrP,length(nameSub),length(nameSub));
            %stoi = fdrP < 0.05 & abs(corrTS) > corrThresh;
            stoi = corrTS_pval < 0.05 & abs(corrTS) > corrThresh;
            % cannot be symmetric @ 2017.05.21
            stoi(~tril(ones(size(stoi)))) = 0;
            currentData.SparseMatrix = sparse(stoi);
        end
    case 3
        % check Granger availability
        if currentData.Granger_OK ~= 1
            hWarn3 = warndlg('Granger data not available');
            uiwait(hWarn3);
            uicontrol(findobj(h3,'Tag','button_Granger'));
        else
            stoi = currentData.Granger;
            currentData.SparseMatrix = sparse(stoi);
        end
end

% update guidata
dataStruct.dataset(dataStruct.current).dataInfo = currentData;
guidata(h3,dataStruct);


if isempty(currentData.SparseMatrix)
    warndlg('No Input. Do nothing.');
else
    if exist('edge_betweenness') & exist('fruchterman_reingold_force_directed_layout')
        if sum(stoi(:)) < 20000
            answerNet = questdlg('View the network(fast) and do mudular analysis(slow)?',...
                'Network Analysis','No','View the network only','Do both','View the network only');
            if strncmp(answerNet,'Vi',2)
                net = double((stoi + stoi')~=0);
                for i=1:length(net)
                    net(i,i) = 0;
                end
                COVAIN_netView(net,nameSub,'View',0);
            elseif strncmp(answerNet,'Do',2);
                net = double((stoi + stoi')~=0);
                for i=1:length(net)
                    net(i,i) = 0;
                end
                COVAIN_netView(net,nameSub,'Modu',0);
            else
                delete(answerNet);
            end
        else
            hWarnX = warndlg('The network is too large to be viusalized by Matlab! Please use the exported .sif network file in Cytoscape.');
            uiwait(hWarnX);
        end
    else
        questX = questdlg('You need to download two additional packages, or save and then use the exported .sif network file in Cytoscape. Download now?','','Yes','No','Yes');
        if strcmp(questX,'No')
            return;
        end
        urlA = 'https://www.mathworks.com/matlabcentral/fileexchange/10922-matlabbgl';
        urlB = 'http://strategic.mit.edu/downloads.php?page=matlab_networks';
        web(urlA,'-browser');web(urlB,'-browser');
        doc addpath;
    end
    % write to network files work done by save button
end


% % old network visualization
% graphObj = biograph(currentData.SparseMatrix,nameSub','LayoutType','equilibrium');
%         view(graphObj);
