function COVAIN_netView(net,netLabel,typeOut,nClus)
% standalone function for network visualization and statistics
% net is a symmetric adjacency matrix
% Xiaoliang Sun @ 2015-06-21

hTop = findobj('Tag','covainPanel_TOP');
dataStruct = guidata(hTop); 
parVer = dataStruct.parVer;
if dataStruct.loadNumber > 0
    currentData = dataStruct.dataset(dataStruct.current).dataInfo; 
    savePath = currentData.savePath;
else
    savePath = [pwd,'\'];
end

deg = sum(net); idxK = setdiff(1:length(net),find(deg==0));
net(deg==0,:) = []; net(:,deg==0) = [];
c = {'k','b','m','c','g','y','r'};
netS = sparse(net);
X = fruchterman_reingold_force_directed_layout(netS,'iterations',300);
 
siz = get(0,'MonitorPositions');
if size(siz,1) >= 2 % two or more screens
    idxSiz = find(siz(:,3)-siz(:,1)==max(siz(:,3)-siz(:,1)));
    siz = siz(idxSiz(end),:);
end
siz_width = siz(3) - siz(1) + 1; siz_height = siz(4) - siz(2) + 1;
fig_width = 0.8*siz_width; fig_height = 0.8*siz_height;
fig_pos = [siz(1)+0.05*fig_width, siz(2)+0.05*fig_height,fig_width,fig_height];
hFig = figure('Position',fig_pos,'Name','Network');

% two types of network graph
if strcmp(typeOut,'View')
    subplot(1,4,[2 3 4]);
    gplot(netS,X,'w');hold on; set(gca,'Color',[0.7 0.7 0.7]);
    text(X(:,1),X(:,2)*1.05, netLabel(idxK),'FontSize',9,'Interpreter','none'); 
    plot(X(:,1),X(:,2),'o','MarkerFaceColor','c','MarkerSize',7); hold off;
    set(gca,'XTick',[],'YTick',[],'box','on');
    set(gca,'XLim',1.02*get(gca,'XLim'),'YLim',1.02*get(gca,'Ylim'));
    betw = betweenness_centrality(netS);
    cc = clustering_coefficients(netS);
    localNames = netLabel(idxK);
    clusGroup = ones(length(idxK),1);
    deg = deg(idxK);
elseif strcmp(typeOut,'Modu')
    [~,z2] = graphconncomp(sparse(net));
    % idxZ = find(z2==mode(z2));
    % net = net(idxZ,idxZ);
    if nClus > 0
        nClus = min([nClus,length(unique(z2))]);
        a = newmangirvan2(net,nClus); 
    else % decide the best number of clusters
        nM = zeros(1,min(50,size(net,1)));
        AA = cell(length(nClus),1);
        parfor i=1:length(nM)
            [aa,~,nM(i)] = newmangirvan2(net,i);
            AA{i} = aa;
        end
        nClus = find(nM == max(nM),1,'last');
        a = AA{nClus};
    end
    % visualize network
    len = cellfun(@length,a);
    [~,idxA] = sort(len,'descend'); a = a(idxA);
    subplot(1,4,[2 3 4]);
    gplot(netS,X,'w');hold on; set(gca,'Color',[0.7 0.7 0.7]);
    for i=1:min(length(a),14)
        if i<=7
            plot(X(a{i},1),X(a{i},2),'o','MarkerFaceColor',c{i},'MarkerSize',7);
        else
            plot(X(a{i},1),X(a{i},2),'d','MarkerFaceColor',c{i-7},'MarkerSize',7);
        end
        text(X(a{i},1),X(a{i},2)*1.05,netLabel(idxK(a{i})),'FontSize',8,'Interpreter','none');
    end
    idxAll = zeros(length(idxK),1); ct = 1; clusGroup = ones(length(idxK),1);
    for i=1:nClus
        idxAll(ct:ct+length(a{i})-1) = a{i};
        clusGroup(ct:ct+length(a{i})-1) = i;
        ct = ct + length(a{i});
    end
    set(gca,'XTick',[],'YTick',[],'box','on','FontSize',11);
    set(gca,'XLim',1.02*get(gca,'XLim'),'YLim',1.02*get(gca,'Ylim'));
    hold off;
    legendStr = cell(1,min(length(a),14)); legendStr{1} = 'edges';
    for j=1:min(length(a),14)
        legendStr{j+1} = ['Modules ',num2str(j)];
    end
    legend(legendStr,'Location','northeastoutside'); 
    % network stats: name, betw, cluscoeff, deg, clustGroup, & others
    betwA = betweenness_centrality(netS); betw = betwA(idxAll);
    ccA = clustering_coefficients(netS); cc = ccA(idxAll);
    namesA = netLabel(idxK); localNames = namesA(idxAll);
    deg = deg(idxK(idxAll));
end

% dispaly the net stat table
netHead = {'Name','Degree','Betweenness','Clustering Coefficient','Module'};
netExport = [netHead; localNames, num2cell([deg', betw, cc, clusGroup])];
for i=1:length(netHead)
    netHead{i} = ['<HTML><p style="font-weight: bold; color: black;">',...
            netHead{1,i},'</p><HTML>'];
end
netData = [netHead; localNames, num2cell([deg', betw, cc, clusGroup])];
uitable('Parent',hFig,'Units','Normalized','RowName',[],...
    'Position',[.03 .11 .28 .45],'Data',netData,'FontSize',9,...
    'UserData',netExport);

% power-law fitting
axes('Position',[.05 .65 .26 .28]);
COVAIN_netFit(net);
 
% export table
uicontrol('Position',[0.92 0.11 0.06 0.06],'Style','pushbutton',...
    'String','Export','Units','Normalized','Parent',hFig,...
    'Callback',@buttonFun,'FontSize',12,'BackgroundColor',[153 204 153]/255);

    function buttonFun(objA,evtA)
        netNumber = randi(10000,1);
        exportName = [savePath,'network_node_',num2str(netNumber),'.xlsx'];
        xlswrite(exportName,netExport);
        msgbox(['Table data has been exported to ', exportName]);
    end
end










