function COVAIN_options(obj,evt)

h = findobj('Tag','covainPanel_TOP');
dataStruct = guidata(h);
if dataStruct.loadNumber == 0
    hWarn = warndlg('Please load a dataset first.');
    uiwait(hWarn);
    uicontrol(findobj(h,'Tag','button_load'));
    return;
end
currentData = dataStruct.dataset(dataStruct.current).dataInfo;
options = currentData.options; % only for viewing

% record previous state
valueMissing_1 = strcmp(options.fillMissing,'minimal');
valueMissing_2 = ~strcmp(options.fillMissing,'minimal');
valueLog_1 = strcmp(options.log,'Log10');
valueLog_2 = ~strcmp(options.log,'Log10');
valueCorr_1 = strcmp(options.corr,'Pearson');
valueCorr_2 = ~strcmp(options.corr,'Pearson');
valueThresh_1 = (options.corrThresh == 0.50);
valueThresh_2 = (options.corrThresh == 0.80);
valueThresh_3 = (options.corrThresh == 0.90);
stringGranger = num2str(options.granger);
stringCluster = num2str(options.cluster);
stringFluc = num2str(options.sigma);
valueFluc_1 = strcmp(options.noiseType,'Same');
valueFluc_2 = ~strcmp(options.noiseType,'Same');
valueGrangerP = num2str(options.grangerP);
valueRevMethod_1 = strcmp(options.revMethod,'TLS');
valueRevMethod_2 = ~strcmp(options.revMethod,'TLS');
stringShrinkage = num2str(options.shrinkage);

hOptionsFig = figure('Position',[100,150,500,600],...
    'Interruptible','on',...
    'Name','Choose options',...
    'NextPlot','new',...
    'NumberTitle','off',...
    'Resize','on',...
    'MenuBar','none', ...
    'Toolbar','none', ...
    'Tag','optionsFig',...
    'HandleVisibility','callback');

% missing value fill
hOptions_panel_missing = uipanel('Parent',hOptionsFig,...
    'Title','Missing value fill',...
    'Units','normalized',...
    'Position',[.02 .85 .6 .09],...
    'Tag','panel_options_missing',...
    'FontSize',11);
hButtionGroup_options_missing = uibuttongroup('Parent',hOptions_panel_missing,...
    'Title',[],...
    'Units','normalized',...
    'Position',[0 0 1 1],...
    'Tag','group_options_missing',...
    'Interruptible','off');
hRadio_options_missing1 = uicontrol('Parent',hButtionGroup_options_missing,...
    'Style','radioButton',...
    'String','Minimal value',...
    'Units','normalized',...
    'Position',[0 0 .45 .80],...
    'Tag','radio_options_missing1',...
    'Value',valueMissing_1);
hRadio_options_missing2 = uicontrol('Parent',hButtionGroup_options_missing,...
    'Style','radioButton',...
    'String','Prior distribution',...
    'Units','normalized',...
    'Position',[.5 0 .45 .80],...
    'Tag','radio_options_missing2',...
    'Value',valueMissing_2);

% log transformation
hOptions_panel_log = uipanel('Parent',hOptionsFig,...
    'Title','Log transformation',...
    'Units','normalized',...
    'Position',[.02 .73 .6 .09],...
    'Tag','panel_options_log',...
    'FontSize',11);
hButtionGroup_options_log = uibuttongroup('Parent',hOptions_panel_log,...
    'Title',[],...
    'Units','normalized',...
    'Position',[0 0 1 1],...
    'Tag','group_options_log',...
    'Interruptible','off');
hRadio_options_log1 = uicontrol('Parent',hButtionGroup_options_log,...
    'Style','radioButton',...
    'String','Log 10',...
    'Units','normalized',...
    'Position',[0 0 .45 .80],...
    'Tag','radio_options_log10',...
    'Value',valueLog_1);
hRadio_options_log2 = uicontrol('Parent',hButtionGroup_options_log,...
    'Style','radioButton',...
    'String','Log 2',...
    'Units','normalized',...
    'Position',[.5 0 .45 .80],...
    'Tag','radio_options_log2',...
    'Value',valueLog_2);

% correlation methods
hOptions_panel_corr = uipanel('Parent',hOptionsFig,...
    'Title','Correlation',...
    'Units','normalized',...
    'Position',[.02 .61 .6 .09],...
    'Tag','panel_options_corr',...
    'FontSize',11);
hButtionGroup_options_corr = uibuttongroup('Parent',hOptions_panel_corr,...
    'Title',[],...
    'Units','normalized',...
    'Position',[0 0 1 1],...
    'Tag','group_options_corr',...
    'Interruptible','off');
hRadio_options_corr1 = uicontrol('Parent',hButtionGroup_options_corr,...
    'Style','radioButton',...
    'String','Pearson',...
    'Units','normalized',...
    'Position',[0 0 .45 .80],...
    'Tag','radio_options_corr1',...
    'Value',valueCorr_1);
hRadio_options_corr2 = uicontrol('Parent',hButtionGroup_options_corr,...
    'Style','radioButton',...
    'String','Spearman',...
    'Units','normalized',...
    'Position',[.5 0 .45 .80],...
    'Tag','radio_options_corr2',...
    'Value',valueCorr_2);

% correlation coefficient threshold
hOptions_panel_corrThresh = uipanel('Parent',hOptionsFig,...
    'Title','Correlation coefficients threshold for network inference',...
    'Units','normalized',...
    'Position',[.02 .48 .8 .09],...
    'Tag','panel_options_corrThresh',...
    'FontSize',11);
hButtionGroup_options_corrThresh = uibuttongroup('Parent',hOptions_panel_corrThresh,...
    'Title',[],...
    'Units','normalized',...
    'Position',[0 0 1 1],...
    'Tag','group_options_corrThresh',...
    'Interruptible','off');
hRadio_options_corrThresh1 = uicontrol('Parent',hButtionGroup_options_corrThresh,...
    'Style','radioButton',...
    'String','0.50',...
    'Units','normalized',...
    'Position',[0 0 .3 .80],...
    'Tag','radio_options_corrThresh1',...
    'Value',valueThresh_1);
hRadio_options_corrThresh2 = uicontrol('Parent',hButtionGroup_options_corrThresh,...
    'Style','radioButton',...
    'String','0.80',...
    'Units','normalized',...
    'Position',[.33 0 .3 .80],...
    'Tag','radio_options_corrThresh2',...
    'Value',valueThresh_2);
hRadio_options_corrThresh3 = uicontrol('Parent',hButtionGroup_options_corrThresh,...
    'Style','radioButton',...
    'String','0.90',...
    'Units','normalized',...
    'Position',[.66 0 .3 .80],...
    'Tag','radio_options_corrThresh3',...
    'Value',valueThresh_3);

% granger time lag and p-value
hOptions_panel_granger = uipanel('Parent',hOptionsFig,...
    'Title','Granger lag time',...
    'Units','normalized',...
    'Position',[.02 .36 .3 .09],...
    'Tag','panel_options_granger',...
    'FontSize',11);
hEdit_options_granger = uicontrol('Parent',hOptions_panel_granger,...
    'Style','edit',...
    'String',stringGranger,...
    'Units','normalized',...
    'Position',[0.4 .10 .2 .80],...
    'Tag','edit_granger',...
    'Max',1,...
    'Min',0);
hOptions_panel_granger2 = uipanel('Parent',hOptionsFig,...
    'Title','Granger significance p value',...
    'Units','normalized',...
    'Position',[.4 .36 .42 .09],...
    'Tag','panel_options_granger2',...
    'FontSize',11);
hEdit_options_granger2 = uicontrol('Parent',hOptions_panel_granger2,...
    'Style','edit',...
    'String',valueGrangerP,...
    'Units','normalized',...
    'Position',[0.4 .10 .4 .80],...
    'Tag','edit_granger2',...
    'Max',1,...
    'Min',0);

% fluctuation matrix noise level
hOptions_panel_flucType = uipanel('Parent',hOptionsFig,...
    'Title','Noise type',...
    'Units','normalized',...
    'Position',[.02 .24 .63 .09],...
    'Tag','panel_options_flucType',...
    'FontSize',11);
hButtionGroup_options_flucType = uibuttongroup('Parent',hOptions_panel_flucType,...
    'Title',[],...
    'Units','normalized',...
    'Position',[0 0 1 1],...
    'Tag','group_options_flucType',...
    'Interruptible','off');
hRadio_options_fluc1 = uicontrol('Parent',hButtionGroup_options_flucType,...
    'Style','radioButton',...
    'String','Same diagonal noise',...
    'Units','normalized',...
    'Position',[0 0 .45 .80],...
    'Tag','radio_options_fluc1',...
    'Value',valueFluc_1);
hRadio_options_fluc2 = uicontrol('Parent',hButtionGroup_options_flucType,...
    'Style','radioButton',...
    'String','Random diagonal noise',...
    'Units','normalized',...
    'Position',[.5 0 .45 .80],...
    'Tag','radio_options_fluc2',...
    'Value',valueFluc_2);
hOptions_panel_flucLevel = uipanel('Parent',hOptionsFig,...
    'Title','Noise level',...
    'Units','normalized',...
    'Position',[.7 .24 .28 .09],...
    'Tag','panel_options_flucLevel',...
    'FontSize',11);
hEdit_options_flucLevel = uicontrol('Parent',hOptions_panel_flucLevel,...
    'Style','edit',...
    'String',stringFluc,...
    'Units','normalized',...
    'Position',[0.2 .10 .5 .80],...
    'Tag','edit_fluc',...
    'Max',1,...
    'Min',0);

% Reverse Jacobian methods
hOptions_panel_revMethod = uipanel('Parent',hOptionsFig,...
    'Title','Reverse Jacobian method',...
    'Units','normalized',...
    'Position',[0.02 .12 .55 .09],...
    'Tag','panel_options_revMethod',...
    'FontSize',11);
hButtionGroup_options_revMethod = uibuttongroup('Parent',hOptions_panel_revMethod,...
    'Title',[],...
    'Units','normalized',...
    'Position',[0 0 1 1],...
    'Tag','group_options_revMethod',...
    'Interruptible','off');
hRadio_options_rev1 = uicontrol('Parent',hButtionGroup_options_revMethod,...
    'Style','radioButton',...
    'String','Total least squares',...
    'Units','normalized',...
    'Position',[0 0 .45 .80],...
    'Tag','radio_options_rev1',...
    'Value',valueRevMethod_1);
hRadio_options_rev2 = uicontrol('Parent',hButtionGroup_options_revMethod,...
    'Style','radioButton',...
    'String','Ridge shrinkage',...
    'Units','normalized',...
    'Position',[.5 0 .45 .80],...
    'Tag','radio_options_rev2',...
    'Value',valueRevMethod_2);
hOptions_panel_ridgeLevel = uipanel('Parent',hOptionsFig,...
    'Title','Shrinkage coefficient',...
    'Units','normalized',...
    'Position',[.6 .12 .38 .09],...
    'Tag','panel_options_ridgeLevel',...
    'FontSize',11);
hEdit_options_ridgeLevel = uicontrol('Parent',hOptions_panel_ridgeLevel,...
    'Style','edit',...
    'String',stringShrinkage,...
    'Units','normalized',...
    'Position',[0.2 .10 .5 .80],...
    'Tag','edit_ridge',...
    'Max',1,...
    'Min',0);

% number of clusters
hOptions_panel_cluster = uipanel('Parent',hOptionsFig,...
    'Title','Number of clusters',...
    'Units','normalized',...
    'Position',[0.02 .01 .35 .09],...
    'Tag','panel_options_cluster',...
    'FontSize',11);

hEdit_options_cluster = uicontrol('Parent',hOptions_panel_cluster,...
    'Style','edit',...
    'String',stringCluster,...
    'Units','normalized',...
    'Position',[0.4 .10 .2 .80],...
    'Tag','edit_cluster',...
    'Max',1,...
    'Min',0);

hOK = uicontrol('Parent',hOptionsFig,'Style','pushbutton',...
                'Units','normalized','Position',[.55 .01 .3 .07],...
                'String','OK','Tag','OK','CallBack',@buttonOK,...
                'FontSize',11);
            
% options.corr = 'Pearson';
% options.corrThresh = 0.50;
% options.log = 'Log10';
% options.fillMissing = 'minimal';
% options.granger = 1;
% options.grangerP = 0.01;
% options.cluster = 4;
% options.sigma = 1;
% options.noiseType = 'Same';

% use nested function to update the options
    function buttonOK(objS,evtS)
        % initialization
        newOpt = options;
        flgWarn = ones(1,5);
        
        % scan all radio values
        if get(hRadio_options_corr1,'Value')==1
            newOpt.corr = 'Pearson';
        else
            newOpt.corr = 'Spearman';
        end
        
        if get(hRadio_options_corrThresh1,'Value')==1
            newOpt.corrThresh = 0.50;
        elseif get(hRadio_options_corrThresh2,'Value')==1
            newOpt.corrThresh = 0.80;
        else
            newOpt.corrThresh = 0.90;
        end
        
        if get(hRadio_options_log1,'Value')==1
            newOpt.log = 'Log10';
        else
            newOpt.log = 'Log2';
        end
        
        if get(hRadio_options_missing1,'Value')==1
            newOpt.fillMissing = 'minimal';
        else
            newOpt.fillMissing = 'prior';
        end
        
        if get(hRadio_options_fluc1,'Value')==1
            newOpt.noiseType = 'Same';
        else
            newOpt.noiseType = 'Random';
        end
        
        % check the input validity: granger lag time & p-value and others
        gLag = str2num(get(hEdit_options_granger,'String'));
        if isempty(gLag) 
            newOpt.granger = 1;
            set(hEdit_options_granger,'String',num2str(1));
        elseif length(gLag) > 1
            newOpt.granger = 1;
            set(hEdit_options_granger,'String',num2str(1));
        elseif gLag > 3 || gLag < 1
            newOpt.granger = 1;
            set(hEdit_options_granger,'String',num2str(1));
        else
            newOpt.granger = gLag;
            flgWarn(1) = 0;
        end
        
        gPval = str2num(get(hEdit_options_granger2,'String'));
        if isempty(gPval)
            newOpt.grangerP = 0.1;
            set(hEdit_options_granger2,'String',num2str(0.01));
        elseif length(gPval) > 1
            newOpt.grangerP = 0.1;
            set(hEdit_options_granger2,'String',num2str(0.01));
        elseif gPval < 0 || gPval > 1
            newOpt.grangerP = 0.1;
            set(hEdit_options_granger2,'String',num2str(0.01));
        else
            newOpt.grangerP = gPval;
            flgWarn(2) = 0;
        end
        
        sigma = str2num(get(hEdit_options_flucLevel,'String'));
        if isempty(sigma)
            newOpt.sigma = 1;
            set(hEdit_options_flucLevel,'String',num2str(1));
        elseif length(sigma) > 1
            newOpt.sigma = 1;
            set(hEdit_options_flucLevel,'String',num2str(1));
        else
            newOpt.sigma = sigma;
            flgWarn(3) = 0;
        end
        
        if get(hRadio_options_rev1,'Value')==1
            newOpt.noiseType = 'TLS';
        else
            newOpt.noiseType = 'Ridge';
        end
        
        ridgeLevel = str2num(get(hEdit_options_ridgeLevel,'String'));
        if isempty(ridgeLevel)
            newOpt.shrinkage = 0.2;
            set(hEdit_options_ridgeLevel,'String',num2str(0.2));
        else
            newOpt.shrinkage = ridgeLevel;
            flgWarn(4) = 0;
        end
        
        ncls = str2num(get(hEdit_options_cluster,'String'));
        if isempty(ncls)
            newOpt.cluster = 4;
            set(hEdit_options_cluster,'String',num2str(4));
        elseif length(ncls) > 1
            newOpt.cluster = 4;
            set(hEdit_options_cluster,'String',num2str(4));
        elseif ncls <= 0
            newOpt.cluster = 4;
            set(hEdit_options_cluster,'String',num2str(4));
        else
            newOpt.cluster = ncls;
            flgWarn(5) = 0;
        end
        
        % update the guidata
        currentData.options = newOpt;
        dataStruct.dataset(dataStruct.current).dataInfo = currentData;
        guidata(h,dataStruct);
        
        % close the figure
        if all(flgWarn==0)
            delete(hOptionsFig);
        end
    end
end
        
        
        
        
        