function COVAIN_plotData(obj,evt)
%
% barplot all data with error
% Use and revise the following third-party functions:
% 1. barweb:
%    http://www.mathworks.com/matlabcentral/fileexchange/10803
% 2. errorbar_tick:
%    http://www.mathworks.com/matlabcentral/fileexchange/22826

h1 = get(obj,'Parent'); % hPanel_dataInfo
h2 = get(h1,'Parent');  % hMain

dataStruct = guidata(h2);
if dataStruct.loadNumber == 0
    return;
end
currentData = dataStruct.dataset(dataStruct.current).dataInfo;

nRow = currentData.nRow;
data = currentData.data;
nameSubs = currentData.subs;
nameCond = currentData.cond;
ind = currentData.ind1;
ct = currentData.count;

if nRow >= 100
    hWarn = warndlg('The data is too large to plot!');
    uiwait(hWarn); return;
end

N = ceil(nRow/40);
for i=1:N
    figure;
    if N==1
        dataBlock = data;
        nameBlock = nameSubs;
    else
        if i~=N
            dataBlock = data((i-1)*40+1 : i*40,:);
            nameBlock = nameSubs((i-1)*40+1 : i*40,:);
        else
            dataBlock = data((i-1)*40+1 : nRow,:);
            nameBlock = nameSubs((i-1)*40+1 : nRow,:);
        end
    end
    mean_dataL = zeros(size(dataBlock,1),length(nameCond));
    std_dataL = zeros(size(dataBlock,1),length(nameCond));
    for j=1:length(ct)
        dataL = dataBlock(:,ind(j):ind(j)+ct(j)-1);
        mean_dataL(:,j) = mean(dataL,2);
        std_dataL(:,j) = std(dataL,[],2);
    end
    
    %barweb(mean_dataL',std_dataL');
    bar_y = mean_dataL;
    bar_s = std_dataL;
    bar(bar_y'); % hold on; errorbar(bar_x,bar_y,bar_s,'rx');hold off;
    
    set(gca,'XTickLabel',nameCond);
    set(gca,'FontSize',12);
    
    flgLog = all([1 0 1] - get(findobj(h2,'Tag','button_log'),'BackgroundColor')==0);
    if flgLog == 1
        ylabel('Concentration (log_{10})','FontSize',14);
    else
        ylabel('Concentration)','FontSize',14);
    end
    
    xlabel(' Conditions','FontSize',14);
    legend(nameBlock,'Location','EastOutside');
    set(gcf,'Name','Errorbar plot');
end


% ==========  Nexted function 1 ===========
    function handles = barweb(barvalues, errors, width)
        % Get function arguments
        if nargin < 2
            error('Must have at least the first two arguments');
        elseif nargin == 2
            width = 1;
        end
        nSize = size(barvalues,2); % to determine errorbar line width
        change_axis = 0;
        ymax = 0;
        if size(barvalues,1) ~= size(errors,1) || size(barvalues,2) ~= size(errors,2)
            error('barvalues and errors matrix must be of same dimension');
        else
            if size(barvalues,2) == 1
                barvalues = barvalues';
                errors = errors';
            end
            if size(barvalues,1) == 1
                barvalues = [barvalues; zeros(1,length(barvalues))];
                errors = [errors; zeros(1,size(barvalues,2))];
                change_axis = 1;
            end
            numgroups = size(barvalues, 1); % number of groups
            numbars = size(barvalues, 2); % number of bars in a group
            if isempty(width)
                width = 1;
            end
            % Plot bars
            handles.bars = bar(barvalues, width,'edgecolor','k', 'linewidth', 2);
            hold on
            % Plot erros
            for ii = 1:numbars
                x = bsxfun(@plus, handles.bars(ii).XData, [handles.bars(ii).XOffset]');
                handles.errors(ii) = errorbar(x, barvalues(:,ii), errors(:,ii),...
                    'k', 'linestyle', 'none', 'linewidth', 2);
                ymax = max([ymax; barvalues(:,ii)+errors(:,ii)]);
            end
            
            xlim([0.5 numgroups-change_axis+0.5]);
            hold off
        end
    end

% ==========  Nested function 2 =========

    function errorbar_tick(h,w,xtype)
        % Check numbers of arguments
        error(nargchk(1,3,nargin))
        % Check for the use of V6 flag ( even if it is depreciated ;) )
        flagtype = get(h,'type');
        % Check number of arguments and provide missing values
        if nargin==1
            w = 80;
        end
        if nargin<3
            xtype = 'ratio';
        end
        % Calculate width of error bars
        if ~strcmpi(xtype,'units')
            dx = diff(get(gca,'XLim'));	% Retrieve x limits from current axis
            w = dx/w;                   % Errorbar width
        end
        % Plot error bars
        if strcmpi(flagtype,'hggroup') % ERRORBAR(...)
            hh=get(h,'children');		% Retrieve info from errorbar plot
            xx = get(hh(2),'xdata');		% Get xdata from errorbar plot
            xx(4:9:end) = xx(1:9:end)-w/2;	% Change xdata with respect to ratio
            xx(7:9:end) = xx(1:9:end)-w/2;
            xx(5:9:end) = xx(1:9:end)+w/2;
            xx(8:9:end) = xx(1:9:end)+w/2;
            set(hh(2),'xdata',xx(:))	% Change error bars on the figure
        else  % ERRORBAR('V6',...)
            xx = get(h(1),'xdata');		% Get xdata from errorbar plot
            xx(4:9:end) = xx(1:9:end)-w/2;	% Change xdata with respect to the chosen ratio
            xx(7:9:end) = xx(1:9:end)-w/2;
            xx(5:9:end) = xx(1:9:end)+w/2;
            xx(8:9:end) = xx(1:9:end)+w/2;
            set(h(1),'xdata',xx(:))	% Change error bars on the figure
        end
    end

% ==================  Nested function complete =================

end

