function COVAIN_reg(obj,evt)
% felSelReg


hTop = findobj('Tag','covainPanel_TOP');
dataStruct = guidata(hTop);
if dataStruct.loadNumber == 0
    return;
end
idxSpl = dataStruct.dataset(dataStruct.current).dataInfo.idxSpl;
dataT = dataStruct.dataset(dataStruct.current).dataInfo.data;
varName = dataStruct.dataset(dataStruct.current).dataInfo.subs;

% a GUI panel, size and color scheme following mzGA
% left screen for factors, right for regression results
scrSize = get(0,'ScreenSize');
midPos  = scrSize(3)*2/3; 
wdPos   = [0.02*midPos 0.1*scrSize(4) 0.9*midPos 0.8*scrSize(4)];
ftSize  = floor(12 * sqrt(scrSize(3)/1920)); % size 12 for 1920*1080 screen
bgColor = [153 204 153]/255; bgButton = [255 204 153]/255;

% generate the window
regWindowName = dataStruct.ID{dataStruct.current};
regWindow = figure('Position',wdPos,'Interruptible','on',...
            'Name',['Regression Analysis: ',regWindowName],...
            'NextPlot','new','NumberTitle','off',...
            'Resize','on','MenuBar','none', 'Toolbar','none', ...
            'Tag','mzWindow','HandleVisibility','callback');
% the main panel
regPanel = uipanel('Parent',regWindow,'Title',[],'Units','Normalized',...
            'Position', [0.01 0.01 0.98 0.98],'BackgroundColor',bgColor);
facStruct.table = []; facStruct.data = []; facStruct.name = [];
paraStruct.InModel = 0; paraStruct.pVal = 0.05; 
paraStruct.term = 1; paraStruct.r2 = 0.7;
hLoad = uicontrol('Parent',regPanel,'Style','pushbutton','Units',...
    'Normalized','Position',[.01 .90 .15 .05],'String','Load factor table',...
    'FontSize',ftSize,'FontWeight','bold','Backgroundcolor',bgButton,...
    'Callback',@loadFile,'UserData',facStruct);
hInModel = uicontrol('Parent',regPanel,'Style','text','Units',...
    'Normalized','Position',[.18 .90 .06 .035],'String','InModel',...
    'FontSize',ftSize,'FontWeight','bold','Backgroundcolor',bgColor);
hInModelEdit = uicontrol('Parent',regPanel,'Style','edit','Units',...
    'Normalized','Position',[.24 .90 .06 .05],'String',[],...
    'FontSize',ftSize,'FontWeight','bold','Backgroundcolor',bgButton,...
     'TooltipString','Indices of in model factors, such as 1,2');   
hPval = uicontrol('Parent',regPanel,'Style','text','Units',...
    'Normalized','Position',[.31 .90 .11 .035],'String','Coeff pValue <',...
    'FontSize',ftSize,'FontWeight','bold','Backgroundcolor',bgColor); 
hPvalEdit = uicontrol('Parent',regPanel,'Style','edit','Units',...
    'Normalized','Position',[.42 .90 .06 .05],'String','0.05',...
    'FontSize',ftSize,'FontWeight','bold','Backgroundcolor',bgButton);
hR2 = uicontrol('Parent',regPanel,'Style','text','Units',...
    'Normalized','Position',[.50 .90 .07 .035],'String','R^2 >=',...
    'FontSize',ftSize,'FontWeight','bold','Backgroundcolor',bgColor); 
hR2Edit = uicontrol('Parent',regPanel,'Style','edit','Units',...
    'Normalized','Position',[.57 .90 .06 .05],'String','0.7',...
    'FontSize',ftSize,'FontWeight','bold','Backgroundcolor',bgButton);
hTerm = uicontrol('Parent',regPanel,'Style','popupmenu','Units',...
    'Normalized','Position',[.65 .90 .15 .04],...
    'String',{'Without interaction','With interaction'},'Value',1,...
    'FontSize',ftSize,'FontWeight','bold','Backgroundcolor',bgButton);
hRun = uicontrol('Parent',regPanel,'Style','pushbutton','Units',...
    'Normalized','Position',[.82 .90 .07 .05],'String','RUN',...
    'FontSize',ftSize,'FontWeight','bold','Backgroundcolor',bgButton,...
    'UserData',paraStruct,'Callback',@runReg);
hExport = uicontrol('Parent',regPanel,'Style','pushbutton','Units',...
    'Normalized','Position',[.92 .90 .07 .05],'String','Save',...
    'FontSize',ftSize,'FontWeight','bold','Backgroundcolor',bgButton,...
    'CallBack',@exportData,'Visible','on');

% initially hidden table
hTableFac = uitable('Parent',regPanel,'Units','Normalized',...
    'Position',[.01 .05 .31 .80],'Visible','off','Data',[]);
% panel results
resultPanel = uipanel('Parent',regPanel,'Title','Regression Results',...
    'Units','normalized','FontSize',ftSize,'FontWeight','bold',...
    'Position',[.33 .05 .66 .80],'BorderWidth',2,'Visible','off');
hTableReg = uitable('Parent',resultPanel,'Units','Normalized',...
    'Position',[.27 .05 .70 .9],'Visible','off','Data',[]);
hListReg = uicontrol('Parent',resultPanel,'Style','listbox','Units',...
    'Normalized','Position',[.03 .05 .2 .85],'String',[],...
    'FontSize',ftSize-1,'FontWeight','bold','Backgroundcolor',bgButton,...
    'Visible','off','CallBack',@selFac);
hTextReg = uicontrol('Parent',resultPanel,'Style','text','Units',...
    'Normalized','Position',[.03 .90 .20 .07],'String','Select factor(s)',...
    'FontSize',ftSize,'FontWeight','bold','Visible','off');

% ---------------------------------------------
% load factors
    function loadFile(objT,evtT) % current only categorical 
        % read factors
        [fileName,filePath] = uigetfile({'*.xlsx;*.xls','All Excel tables'},'Load Factors');
        if isnumeric(fileName) % if nothing is loaded, exit
            return;
        else
            fullPath = [filePath,fileName];
        end
        [~,~,R] = xlsread(fullPath);
        if size(R,1) - 1 ~= length(idxSpl)
            warndlg('Sample size not compatible!'); return;
        end
        R(2:end,:) = R(idxSpl+1,:);
        facLocal = get(objT,'UserData');
        facLocal.table = R;
        % save data
        set(objT,'UserData',facLocal);
        fac2name(R);
        fac2num(R);
        dispFac(R);
    end
% ----------------------------------------------
% display table
    function dispFac(tableFac)
        set(hTableFac,'Data',tableFac(2:end,2:end),'RowName',tableFac(2:end,1),...
            'ColumnName',tableFac(1,2:end),'Visible','on');
    end
% ----------------------------------------------
% formulate fac names
    function fac2name(tableFac)
        R = tableFac;
        nFac = size(R,2) - 1;
        facName = cell(nFac + nFac*(nFac-1)/2,1); ct = nFac+1;
        facName(1:nFac) = R(1,2:end);
        for i=1:nFac-1
            for j=i+1:nFac
                facName{ct} = [R{1,i+1},'*',R{1,j+1}];
                ct = ct + 1;
            end
        end
        facLocal = get(hLoad,'UserData');
        facLocal.name = facName'; % row vector
        set(hLoad,'UserData',facLocal);
    end
% ----------------------------------------------
% discretize tableFac
    function fac2num(tableFac)
        tableFac = tableFac(2:end,2:end);
        [nRow,nCol] = size(tableFac);
        dataFac = zeros(nRow,nCol);
        for i=1:nCol
            u = unique(tableFac(:,i),'stable');
            for j=1:length(u)
                dataFac(strcmp(u{j},tableFac(:,i)),i) = j + i - 1;
            end
        end
        facLocal = get(hLoad,'UserData');
        facLocal.data = dataFac;
        set(hLoad,'UserData',facLocal);
    end
% ----------------------------------------------
% read options (InModel, pVal)
    function readInput
        facLocal = get(hLoad,'UserData');
        if isempty(facLocal.data)
            return;
        end
        tableFac = facLocal.data; nCol = size(tableFac,2);
        idxIn = str2num(get(hInModelEdit,'String'));
        if isnan(idxIn) | any(~ismember(idxIn,1:nCol))
            idxIn = paraStruct.InModel;
            set(hInModelEdit,'String',[]);
        end
        pVal = str2num(get(hPvalEdit,'String'));
        if isnan(pVal) | length(pVal)>1 | pVal <= 0 | pVal > 1 
            pVal = paraStruct.pval;
            set(hPvalEdit,'String','0.05');
        end    
        r2 = str2num(get(hR2Edit,'String'));
        if isnan(r2) | length(r2)>1 | r2 <= 0 | r2 > 1 
            r2 = paraStruct.r2;
            set(hR2Edit,'String','0.8');
        end 
        para.InModel = idxIn;
        para.pVal = pVal;
        para.term = get(hTerm,'Value');
        para.r2 = r2;
        set(hPval,'UserData',para);
    end
% ----------------------------------------------
% run regression
    function runReg(objT,evtT)
        facLocal = get(hLoad,'UserData');
        if isempty(facLocal.data)
            return;
        end
        readInput;
        para = get(hPval,'UserData');
        if isempty(para)
            return;
        end
        facName = facLocal.name; 
        idxKeep = para.InModel; pVal = para.pVal; r2 = para.r2;
        % now prepare the data matrix (because of interation terms)
        dataFac = facLocal.data; [nRow,nCol] = size(dataFac);
        facS = dataFac;
        facNameS = facLocal.table(2:end,2:end);
        if para.term == 1 % without interaction
            facM = []; facNameM = [];
            facName = facName(1:nCol);
        else
            idxM = nchoosek(1:nCol,2);    % interaction array of factors
            facM = zeros(nRow,size(idxM,1));
            facNameM = cell(nRow,size(idxM,1));
            for i=1:size(idxM,1)
                facM(:,i) = dataFac(:,idxM(i,1)).*dataFac(:,idxM(i,2));
                facNameM(:,i) = strcat(facNameS(:,idxM(i,1)),'*',facNameS(:,idxM(i,2)));
            end
            
        end
        facMatrix = [facS,facM]; % nSpl*nFac
        facNameF = [facNameS,facNameM];
        dataMatrix = dataT';     % nSpl*nVar
        regMatrix = ones(size(facMatrix,2),size(dataMatrix,2));
        fitQ = zeros(size(regMatrix,2),1);
        hWait = waitbar(0,'Please wait ...');
        for i=1:size(regMatrix,2)
            if idxKeep~=0
                [~,~,~,~,stats] = stepwisefit(facMatrix,dataMatrix(:,i),'inmodel',idxKeep,'display','off');
            else
                [~,~,~,~,stats] = stepwisefit(facMatrix,dataMatrix(:,i),'display','off');
            end
            pv = stats.PVAL; 
            if any(isnan(pv))
                pv(isnan(pv)) = 1; 
            end
            idxSig = pv<pVal; 
            if any(idxSig)
                yHat = facMatrix(:,idxSig)*stats.B(idxSig);
                fitQ(i) = corr(yHat,dataMatrix(:,i))^2;
            end
            regMatrix(:,i) = pv;
            waitbar(i/size(regMatrix,2));
        end
        waitbar(1,hWait,'Preparing results table ...');
        regMatrix = regMatrix';
        % display the results, nVar*nFac
        % sort regMatrix
        t = sum(regMatrix<pVal,2); idxSolid = (t > 0) & fitQ >= r2;     
        regMatrixS = regMatrix(idxSolid,:); varNameS = varName(idxSolid);
        dataMatrixS = dataMatrix(:,idxSolid)'; % nVar*nSpl
        % save results
        regStruct.pval = regMatrixS;
        regStruct.pThresh = pVal;
        regStruct.data = dataMatrixS;
        regStruct.varName = varNameS;
        regStruct.varIdx = find(idxSolid);
        regStruct.facName = facName;
        regStruct.facNameF = facNameF;
        regStruct.facTable = facLocal.table;
        regStruct.facData = dataFac;
        regStruct.facMatrix = facMatrix;
        set(objT,'UserData',regStruct);
        % activate the results table
        setRegTable(regStruct);
        delete(hWait);
    end
% ----------------------------------------------
% set regression result table
    function setRegTable(regS)
        set(resultPanel,'visible','on');        
        % get data
        pval = regS.pval; varNameL = regS.varName;
        facName = regS.facName; facTable = regS.facTable;
        pThresh = regS.pThresh;
        % get stats
        sigMatrix = pval<pThresh;
        nSigFac = sum(sigMatrix);
        if all(nSigFac(:)==0)
            return;
        end
        % filter out zero counts
        idxSig = nSigFac~=0;
        nSigFac = nSigFac(idxSig);
        facNameN = facName(idxSig); % name + number
        for i=1:length(facNameN)
            facNameN{i} = [facNameN{i},'(',sprintf('%d',nSigFac(i)),')'];
        end
        % formulate the listbox
        set(hTextReg,'Visible','on');
        set(hListReg,'String',facNameN','Min',1,'Max',length(facNameN),...
            'Value',1,'Visible','on');      
    end
% ----------------------------------------------
% display the table from variable selection, hTableReg
    function selFac(objT,evtT)
        % get index
        idxSel = get(objT,'Value');
        % get data
        regS = get(hRun,'UserData');
        pval = regS.pval; varNameL = regS.varName;
        facNameF = regS.facNameF; facName = regS.facName;
        data = regS.data; splName = regS.facTable(2:end,1); % col
        pThresh = regS.pThresh;
        % get stats
        sigMatrix = pval<pThresh;
        nSigFac = sum(sigMatrix);
        if all(nSigFac(:)==0)
            return;
        end
        % filter out zero counts
        idxSig = find(nSigFac~=0); % splIndex from ALL(not filtered)
        % execute selection
        flgRow = sigMatrix(:,idxSig(idxSel(1))); flgOK = 1;
        for i=1:length(idxSel)
            flgRow = and(flgRow,sigMatrix(:,idxSig(idxSel(i))));
            if all(flgRow==0)
                flgOK = 0; 
                warndlg('No data left.');
                break;
            end
        end
        if flgOK==0
            return;
        end
        dataTable = data(flgRow,:);
        rowName = varNameL(flgRow);
        colName = splName';
        set(hTableReg,'Visible','on','Data',dataTable,'RowName',...
            rowName,'ColumnName',colName);
        % formulate the new colName (only factors)
        t = facNameF(:,idxSig(idxSel(1)));
        for i=2:length(idxSel)
            t = strcat(t,' ',facNameF(:,idxSig(idxSel(i))));
        end
        colNameNew = t';
        % save data to handle
        dataRaw = cell(sum(flgRow)+1,size(dataTable,2)+1);
        dataRaw(2:end,2:end) = num2cell(dataTable);
        dataRaw(2:end,1) = rowName;
        dataRaw(1,2:end) = colNameNew;
        rawFileName = regWindowName;
        rawFileName = rawFileName(findstr('--',rawFileName)+2:end);
        for i=1:length(idxSel)
            if i==1
                rawFileName = [rawFileName,'(',facName{idxSig(idxSel(i))}];
            else
                rawFileName = [rawFileName,'+',facName{idxSig(idxSel(i))}];
            end
        end
        rawFileName = [rawFileName,')'];
        expStruct.dataRaw = dataRaw;
        expStruct.rawFileName = rawFileName;
        set(hExport,'UserData',expStruct);        
    end
% ----------------------------------------------
% export data
    function exportData(objT,evtT)
        expStruct = get(objT,'UserData');
        if isempty(expStruct)
            return;
        end
        dataRaw = expStruct.dataRaw;
        rawFileName = expStruct.rawFileName;
        COVAIN_loadIntData(dataRaw,rawFileName,hTop);
    end
% ----------------------------------------------
% end of the main function
end



