function dataStruct = COVAIN_save(obj,evt)
%

h1 = get(obj,'Parent'); % hPanel_Main
h2 = get(h1,'Parent');  % hMain

dataStruct = guidata(h2);
if dataStruct.loadNumber == 0
    return;
end
path1 = dataStruct.dataset(1).dataInfo.savePath;

% check file name state. If empty, use {rawFileName + date} as name
strName = get(findobj(h1,'Tag','edit_fileName'),'String');
if isempty(strName)==1 || strcmp(strName,'Name the results')==1
    strName = datestr(now); % not strNames!
    strName = strrep(strName,' ','-');
    strName = strrep(strName,':','-');
end

% % save workspace 
% %save([path1,strName,'-Results.mat'], 'dataStruct'); % old code
% [fileName,pathName,flgStatus] = uiputfile([path1,strName,'-Results.mat'],...
%                                     'Please specify the file name');
% if ~isempty(findstr('.mat',fileName)) 
%     fileNameFull = [pathName,fileName(1:end-4)]; % remove .mat
% else
%     fileNameFull = [pathName,fileName];
% end
% if flgStatus == 1
%     save(fileNameFull, 'dataStruct');
% end

% save workspace
pathName = uigetdir(path1,'Please choose a folder to save results');
if pathName == 0   % 
    hWarnP = warndlg('No folder is specified. Will use the default folder instead.');
    uiwait(hWarnP);
    pathName = path1;
else
    pathName = [pathName,'\'];
end
save([pathName,strName],'dataStruct');


% save excel files
warnStatus = 0;
for i=1:size(dataStruct.ID,2)
    
    strNames = dataStruct.ID{i};
    strNames(1:strfind(strNames,'--')+1) = [];
    colName = dataStruct.dataset(i).dataInfo.sampleName;
    rowName = dataStruct.dataset(i).dataInfo.subs;
    rowHead = [{' '};rowName];
    fileNameFull = [pathName,strNames];
    dataBlock = [colName;...
        num2cell(dataStruct.dataset(i).dataInfo.data)];
    
    % Processed data
    dataTable = [rowHead,dataBlock]; % 1st sheet
    try 
        xlswrite(fileNameFull,dataTable,1);
        warning off MATLAB:xlswrite:AddSheet
    catch err
        warnStatus = 1;
        hWarnX = warndlg(['Writing data matrix to Excel table fails: ',err.message]);
        uiwait(hWarnX);
    end
    % PCA
    pcaLoading = dataStruct.dataset(i).dataInfo.pcaLoading;
    if ~isempty(pcaLoading)
        pcaBlock = [{'PC 1','PC 2','PC 3','PC 4','PC 5'};num2cell(pcaLoading(:,1:5))];
        pcaTable = [rowHead,pcaBlock];      
        try
            xlswrite([fileNameFull,'.xlsx'],pcaTable,2);
            warning off MATLAB:xlswrite:AddSheet
        catch err
            warnStatus = 1;
            hWarnX = warndlg(['Writing PCA loadings to Excel table fails: ',err.message]);
            uiwait(hWarnX);
        end
    end
    % ICA
    icaLoading = dataStruct.dataset(i).dataInfo.icaLoading;
    if ~isempty(icaLoading)
        icaBlock = [{'IC 1','IC 2','IC 3','IC 4','IC 5'};num2cell(icaLoading(:,1:5))];
        icaTable = [rowHead,icaBlock];
        try
            xlswrite([fileNameFull,'.xlsx'],icaTable,3);
            warning off MATLAB:xlswrite:AddSheet
        catch err
            warnStatus = 1;
            hWarnX = warndlg(['Writing ICA loadings to Excel table fails: ',err.message]);
            uiwait(hWarnX);
        end
    end
    
%     corrStat = dataStruct.dataset(i).dataInfo.corrStat;
%     if ~isempty(corrStat)
%         corrStatBlock = [rowName';num2cell(corrStat)];
%         corrStatTable = [rowHead,corrStatBlock];
%         try
%             xlswrite(fileNameFull,corrStatTable,4);
%             warning off MATLAB:xlswrite:AddSheet
%         catch err
%             hWarnX = warndlg(['Writing to Excel table fails: ',err.message]);
%             uiwait(hWarnX);
%         end
%     end
    
    % produce Pajek's net file and Cytoscape .sif file   
    stoi1 = dataStruct.dataset(i).dataInfo.SparseMatrix;
    if ~isempty(stoi1)
        produceNetwork(dataStruct.dataset(i).dataInfo.subs,fileNameFull,stoi1);
    end
end


if warnStatus == 0
    msgbox('  Done !  ');
else
    msgbox(' Not all files have been saved. ');
end

% save my notes
myNotes = dataStruct.dataset(1).dataInfo.note;
if ~isempty(myNotes)
    fid_note = fopen([pathName,'MyNotes.txt'],'w');
    if fid_note > 0   % if file can be opened
        fprintf(fid_note,'%s',myNotes);
        fclose(fid_note);
    end
end

% ======= nested function ===================================
% produce pajek's .net file and Cytoscape .sif file
    function produceNetwork(cpdName,nFile,stoi)
        
%         % For correlation network only, not suitable for granger network
%         cpdIndex = find(any(stoi~=0,2)==1);
%         rxnIndex = find(any(stoi~=0,1)==1);
%         cpdNew = cpdName(cpdIndex);
%         stoiNew = stoi(cpdIndex,rxnIndex); %#ok<FNDSB> shall use "or" ----
%         if size(stoiNew,1) == size(stoiNew,2)
%             stoiNew = triu(stoiNew) + (stoiNew - stoiNew'); % reduce symmetric redundance
%         end

%         % ----------- Pajek started ------- temporarily disabled ----     
%         pFile = [nFile,'.net'];
%         fid = fopen(pFile,'w+');
%         % first row: Vertices(nodes) information
%         fprintf(fid,'%s','*Vertices    ');
%         fprintf(fid,'%d\n',length(cpdName));
%         for jj=1:length(cpdName)
%             vi = ['    ',num2str(jj),'  "',cpdName{jj},'"'];
%             fprintf(fid,'%s\n',vi);
%         end
%         % second part
%         fprintf(fid,'%s\n','*Arcs');
%         fprintf(fid,'%s\n','*Edges');
%         nodeIndex = find(stoi(:)~=0);
%         for jj=1:length(nodeIndex)
%             [node1,node2] = ind2sub(size(stoi),nodeIndex(jj));
%             fprintf(fid,'%s\n',['    ',num2str([node1,node2,1])]);
%         end
%         fclose(fid);
%         % ------------- Pajek completed ------------
        
        
        % -------------- Cytoscape started ---------
        cFile = [nFile,'.sif'];
        fid = fopen(cFile,'w+');
        nodeIndex = find(stoi(:)~=0);

        for jj=1:length(nodeIndex)
            [node1,node2] = ind2sub(size(stoi),nodeIndex(jj));
            name1 = cpdName{node1};
            name2 = cpdName{node2};
            
%             % revise their names
%             if ~isempty(str2double(name1(1)))
%                 name1 = ['m_',name1];
%             end
%             if ~isempty(str2double(name2(1)))
%                 name2 = ['m_',name2];
%             end
%             name1 = strrep(name1,'*','');
%             name2 = strrep(name2,'*','');
%             name1 = strrep(name1,',','_');
%             name2 = strrep(name2,',','_');   

            name1(strfind(name1,' ')) = '_';
            name2(strfind(name2,' ')) = '_';
            fprintf(fid,'%s\n',[name1,' mm ',name2]);
        end
        fclose(fid);
        % ------------ Cytoscape completed ----------
        
    end
% ================= nested function ================

end % end of main function




